<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\AccidentDetails; // Updated model for accidents
use App\Models\AccidentCoverage; // Updated model for accident coverage
use Carbon\Carbon;

class AccidentoverviewController extends Controller
{
  
        public function index()
        {
            $user = auth()->user();
        
            // Fetch the accident details for the authenticated user
            $accidentDetail = AccidentDetails::where('user_id', $user->id)->first();
        
            if (!$accidentDetail) {
                return view('user.accidentdetailsoverview', [
                    'package' => null,
                    'premium' => null,
                    'expiry_date' => null,
                    'autorenew' => null,
                    'coverages' => [],
                ]);
            }
        
            // Fetch the accident coverage details for the chosen package
            $accidentCoverage = AccidentCoverage::where('package', $accidentDetail->package)->first();
        
            if (!$accidentCoverage) {
                return view('user.accidentdetails', [
                    'package' => $accidentDetail->package,
                    'premium' => null,
                    'expiry_date' => Carbon::parse($accidentDetail->expiry_date)->format('d/m/Y'),
                    'autorenew' => $accidentDetail->autorenew,
                    'coverages' => [],
                ]);
            }
    
            // Pass the coverages as an array to the view
            $coverages = [
                'Death' => $accidentCoverage->death,
                'Permanent Total Disability' => $accidentCoverage->permanent_total_disability,
                'Temporary Total Disability' => $accidentCoverage->temporary_total_disability,
                'Medical Expenses' => $accidentCoverage->medical_expenses,
                'Last Expense' => $accidentCoverage->last_expense,
                'Artificial Limbs' => $accidentCoverage->artificial_limbs,
                'Dental' => $accidentCoverage->dental,
                'Optical' => $accidentCoverage->optical,
                'Wheelchair' => $accidentCoverage->wheelchair,
                'Hearing Aid' => $accidentCoverage->hearing_aid,
                'Local Evacuation' => $accidentCoverage->local_evacuation,
                'Ambulance Expenses' => $accidentCoverage->ambulance_expenses,
                'Rehabilitation' => $accidentCoverage->rehabilitation,
                'Rehabilitation' => $accidentCoverage->rehabilitation,
                'file_path' => $accidentCoverage->file_path
            ];
    

            //dd($accidentCoverage);

            // Get the premium payable for this package
            $premium = $accidentCoverage->premium_payable;
    
            return view('user.accidentdetailsoverview', [
                'package' => $accidentDetail->package,
                'premium' => $premium,
                'expiry_date' => Carbon::parse($accidentDetail->expiry_date)->format('d/m/Y'),
                'autorenew' => $accidentDetail->autorenew,
                'coverages' => $coverages,
            ]);
        }
    }
    

