<?php

namespace App\Http\Controllers;

use App\Models\Notification;
use Illuminate\Http\Request;
use App\Models\RentersDetail;
use App\Models\GolfersDetail;
use App\Models\TravelDetail;
use App\Models\DomesticsDetail;
use App\Models\MedicalDetail;
use App\Models\PetsDetail;
use App\Models\AccidentDetails;
use App\Models\ResidentialProperty;

use Carbon\Carbon;
use Illuminate\Support\Facades\Storage;

class ActiveCoversController extends Controller
{
    public function index()
    {
        // Fetch the authenticated user
        $user = auth()->user();

        // Fetch active covers from all tables, ensuring payment is paid
        $activeRenters = RentersDetail::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();


            $activeRenters = ResidentialProperty::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();

        $activeGolfers = GolfersDetail::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();

        $activeTravel = TravelDetail::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();

        $activeDomestics = DomesticsDetail::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();

        $activeMedical = MedicalDetail::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();

        // Fetch active accident covers
        $activeAccidents = AccidentDetails::where('user_id', $user->id)
            ->where('activity', 1)
            ->where('payment', 'paid')
            ->get();

        // Fetch notifications for the user
        $notificationCount = Notification::where('user_id', $user->id)->value('notification_count');
        $notificationCount = $notificationCount ?? 0;

        // Function to calculate time remaining and handle auto-renew status
        $calculateCountdown = function ($expiryDate, $autorenew) {
            $now = Carbon::now();
            $expiry = Carbon::parse($expiryDate);

            if ($expiry->isPast()) {
                return 'Expired';
            }

            $daysRemaining = $now->diffInDays($expiry);
            $countdown = $autorenew ? "Auto-renews in $daysRemaining days" : "$daysRemaining days remaining";
            $actionText = $autorenew ? "Cancel auto-renew" : "Enable auto-renew";

            return ['countdown' => $countdown, 'actionText' => $actionText];
        };

        // Check if the selfie path exists
        $selfiePath = $user->userDetail ? $user->userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;

        return view('user.activecovers', [
            'user' => $user,
            'activeRenters' => $activeRenters->map(function ($cover) use ($calculateCountdown) {
                $coverDetails = $calculateCountdown($cover->expiry_date, $cover->autorenew);
                if (is_array($coverDetails)) {
                    $cover->countdown = $coverDetails['countdown'];
                    $cover->actionText = $coverDetails['actionText'];
                } else {
                    $cover->countdown = $coverDetails;
                    $cover->actionText = 'Expired';
                }
                return $cover;
            }),
            'activeGolfers' => $activeGolfers->map(function ($cover) use ($calculateCountdown) {
                $coverDetails = $calculateCountdown($cover->expiry_date, $cover->autorenew);
                if (is_array($coverDetails)) {
                    $cover->countdown = $coverDetails['countdown'];
                    $cover->actionText = $coverDetails['actionText'];
                } else {
                    $cover->countdown = $coverDetails;
                    $cover->actionText = 'Expired';
                }
                return $cover;
            }),
            'activeTravel' => $activeTravel->map(function ($cover) use ($calculateCountdown) {
                $coverDetails = $calculateCountdown($cover->expiry_date, $cover->autorenew);
                if (is_array($coverDetails)) {
                    $cover->countdown = $coverDetails['countdown'];
                    $cover->actionText = $coverDetails['actionText'];
                } else {
                    $cover->countdown = $coverDetails;
                    $cover->actionText = 'Expired';
                }
                return $cover;
            }),
            'activeDomestics' => $activeDomestics->map(function ($cover) use ($calculateCountdown) {
                $coverDetails = $calculateCountdown($cover->expiry_date, $cover->autorenew);
                $cover->countdown = $coverDetails;
                $cover->actionText = $coverDetails;
                return $cover;
            }),
            'activeMedical' => $activeMedical->map(function ($cover) use ($calculateCountdown) {
                $coverDetails = $calculateCountdown($cover->expiry_date, $cover->autorenew);
                $cover->countdown = $coverDetails['countdown'];
                $cover->actionText = $coverDetails['actionText'];
                return $cover;
            }),
            'activeAccidents' => $activeAccidents->map(function ($cover) use ($calculateCountdown) {
                $coverDetails = $calculateCountdown($cover->expiry_date, $cover->autorenew);
                if (is_array($coverDetails)) {
                    $cover->countdown = $coverDetails['countdown'];
                    $cover->actionText = $coverDetails['actionText'];
                } else {
                    $cover->countdown = $coverDetails;
                    $cover->actionText = 'Expired';
                }
                
                return $cover;
            }),
            'selfiePath' => $selfiePath,
            'selfieExists' => $selfieExists,
            'notificationCount' => $notificationCount,
        ]);
    }

    public function toggleAutoRenew(Request $request)
    {
        $coverType = $request->input('cover_type');
        $coverId = $request->input('cover_id');

        // Determine the model based on cover type
        $model = $this->getCoverModel($coverType);

        if ($model) {
            $cover = $model::where('id', $coverId)->first();
            if ($cover) {
                $cover->autorenew = $cover->autorenew ? 0 : 1;
                $cover->save();
            }
        }

        return redirect()->back()->with('status', 'Auto-renew status updated successfully.');
    }

    // Helper method to get the model based on cover type
    private function getCoverModel($coverType)
    {
        switch ($coverType) {
            case 'renters':
                return RentersDetail::class;
            case 'golfers':
                return GolfersDetail::class;
            case 'travel':
                return TravelDetail::class;
            case 'domestics':
                return DomesticsDetail::class;
            case 'medical':
                return MedicalDetail::class;
            case 'accidents':
                return AccidentDetails::class;
            case 'pets':
                return PetsDetail::class;
            default:
                return null;
        }
    }
}
