<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;
use App\Models\UserDetail;
use Illuminate\Support\Facades\Session;
use GuzzleHttp\Client;
use App\Models\Conversation;
use App\Models\Claim;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Str;

use thiagoalessio\TesseractOCR\TesseractOCR;
use Illuminate\Support\Facades\Storage;

class ChatbotController extends Controller
{
    private $apiKey;
    private $model;

    public function __construct()
    {
        $this->apiKey = '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';
        $this->model = 'llama-3.1-8b-instant';
    }

    public function index()
    {
        $user = Auth::user();
        $firstName = $user->first_name;
       
        $userDetail = UserDetail::where('user_id', $user->id)->first();
        $selfiePath = $userDetail ? $userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;
        return view('user.princeclaim', compact('firstName', 'selfiePath', 'selfieExists'));
      

    }

    public function send(Request $request)
    {
        $userMessage = $request->input('message');
        $insuranceType = $request->input('insuranceType');
        $botResponse = $this->getBotResponse($userMessage, $insuranceType);
        return response()->json(['message' => $botResponse]);
    }

    private function getBotResponse($message, $insuranceType)
    {
        $url = "https://api.groq.com/openai/v1/chat/completions";
        
        $chat = $this->getChatHistory($insuranceType);
        $chat[] = [
            'role' => 'user',
            'content' => $message
        ];
    
        $data = [
            'model' => $this->model,
            'messages' => $chat,
            'temperature' => 1,
            'max_tokens' => 1024,
            'top_p' => 1,
            'stream' => false,
            'stop' => null
        ];
    
        $response = Http::withHeaders([
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json'
        ])->post($url, $data);
    
        if ($response->successful()) {
            $result = $response->json();
            if (isset($result['choices'][0]['message']['content'])) {
                $botResponse = $result['choices'][0]['message']['content'];
                $chat[] = [
                    'role' => 'assistant',
                    'content' => $botResponse
                ];
                $this->saveChatHistory($chat, $insuranceType);
                return $botResponse;
            }
        }
    
        return "Sorry, I didn't understand. Please rephrase or avoid sensitive terms.";
    }

    private function getChatHistory($insuranceType)
    {
        if (!Session::has('chat_history_' . $insuranceType)) {
            $initialChat = $this->initializeChat($insuranceType);
            Session::put('chat_history_' . $insuranceType, $initialChat);
        }
        return Session::get('chat_history_' . $insuranceType);
    }

    private function saveChatHistory($chat, $insuranceType)
    {
        Session::put('chat_history_' . $insuranceType, $chat);
    }

    private function initializeChat($insuranceType)
    {
        $systemPrompt = $this->getSystemPrompt($insuranceType);
        return [
            [
                'role' => 'system',
                'content' => $systemPrompt
            ]
        ];
    }

    private function getSystemPrompt($insuranceType)
    {
        switch ($insuranceType) {
            case 'Golfers':
                return "You are Prince, a friendly and efficient assistant for Crownscope Insurance Brokers. When triggered by any initial message, introduce yourself and provide the following list of claim types:
    
    1. Loss/Damage to Golf Equipment
    2. Loss/Damage to Personal Effects
    3. Third-Party Liability
    4. Personal Accident
    5. Hole-in-One
    
    Handle each claim step-by-step as follows:
    
    **Loss/Damage to Golf Equipment:**
    - Ask for the story of what happened.
    - Request images of the damaged items.
    - Ask for receipts.
    
    **Loss/Damage to Personal Effects:**
    - Ask for the story of what happened.
    - Request images of the police report.
    - Ask for receipts.
    
    **Third-Party Liability:**
    - Ask for details of the incident.
    - Request any supporting evidence.
    
    **Personal Accident:**
    - Express sympathy and ask what happened.
    - Request receipts.
    - Ask for images of the doctor’s remarks.
    
    **Hole-in-One:**
    - Show excitement and ask how they feel.
    - Request receipts for any party attended.
    
    Always suggest clear next steps, thank users, and maintain a friendly tone. Keep responses concise—2-3 lines max, and ensure each request is handled one at a time. Once they have provided all the details, let them know they will receive a quotation within 48 hours.";
            
            case 'Medical':
                return "You are Prince, a friendly and efficient assistant for Crownscope Insurance Brokers.

                        When triggered by any initial message, introduce yourself and ask if it's an inpatient claim and if they are okay. Then, request the following details:

                        The story of what happened.
                        What the doctor said.
                        Any supporting documents.
                        Remind them to provide as much information as possible. Once they have provided all the details, let them know they will receive a quotation within 48 hours.Always suggest clear next steps, thank users, and maintain a friendly tone. Keep responses concise—2-3 lines max, and ensure each request is handled one at a time.";
            case 'Travel':
                return "You are Prince, an expert in travel insurance claims for Crownscope Insurance Brokers.

                        First, ask:

                        Where did you go?
                        Are you okay and did you enjoy your trip?
                        Then, request:

                        The story of what happened.
                        Any supporting documents related to your claim.
                        Finally, let them know:

                        You will receive a quotation within 48 hours once all details are provided. Always suggest clear next steps, thank users, and maintain a friendly tone. Keep responses concise—2-3 lines max, and ensure each request is handled one at a time.";
            case 'Personal Accident':
                return "You are Prince, an expert in personal accident insurance claims for Crownscope Insurance Brokers.

                    First, ask:

                    Are you okay?
                    Can you share what happened?
                    Then, request:

                    Details from your doctor about your condition.
                    Any supporting documents related to your accident.
                    Always remind them to provide as much information as possible. Let them know:

                    You will receive a quotation within 48 hours once all details are provided. Always suggest clear next steps, thank users, and maintain a friendly tone. Keep responses concise—2-3 lines max, and ensure each request is handled one at a time.";
            case 'Domestic Package':
                return "You are Prince, an expert in domestic package insurance claims for Crownscope Insurance Brokers.

                    First, ask:

                    Where did you go on your domestic trip?
                    Are you okay and did you enjoy your trip?
                    Then, request:

                    The story of what happened.
                    Any supporting documents related to your claim.
                    Always remind them to provide as much information as possible. Let them know:

                    You will receive a quotation within 48 hours once all details are provided.Always suggest clear next steps, thank users, and maintain a friendly tone. Keep responses concise—2-3 lines max, and ensure each request is handled one at a time.";
            default:
                return "You are Prince, a general insurance assistant for Crownscope Insurance Brokers. Provide basic information about our insurance products and guide users to select the appropriate type of insurance for their needs.";
        }
    }

    public function upload(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:jpg,jpeg,png,bmp,tiff|max:2048',
        ]);

        $file = $request->file('file');
        $fileName = uniqid() . '_' . time() . '.' . $file->getClientOriginalExtension();
        $filePath = public_path('uploads/' . $fileName);
        $file->move(public_path('uploads'), $fileName);

        try {
            $fileRead = (new TesseractOCR($filePath))->lang('eng')->run();
            $botResponse = $this->getBotResponse($fileRead, $request->input('insuranceType'));

            return response()->json([
                'message' => $botResponse,
                'uploaded_image_url' => asset('uploads/' . $fileName)
            ]);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function clearSession(Request $request)
    {
        $insuranceType = $request->input('insuranceType');
        Session::forget('chat_history_' . $insuranceType);
        return response()->json(['message' => 'Chat history cleared']);
    }

    public function save(Request $request)
    {
        try {
            $request->validate([
                'claim_type' => 'required|string',
                'conversation' => 'required|json',
            ]);
    
            // Check if the claim_type exists and its status
            $existingClaim = Claim::where('policy', $request->claim_type)
                ->first();
    
            $shouldSaveConversation = false;
    
            if ($existingClaim) {
                // Check if the existing claim's status is closed or settled
                if (in_array($existingClaim->status, ['closed', 'settled'])) {
                    $shouldSaveConversation = true;
                }
            } else {
                // If claim type does not exist, set flag to save conversation
                $shouldSaveConversation = true;
            }
    
            if ($shouldSaveConversation) {
                // Save the conversation
                $conversation = Conversation::create([
                    'user_id' => auth()->id(),
                    'claim_type' => $request->claim_type,
                    'conversation' => json_decode($request->conversation, true),
                ]);
    
                // Generate claim number
                $claimNumber = $this->generateClaimNumber($request->claim_type);
    
                // Create a new claim
                $claim = Claim::create([
                    'policy' => $request->claim_type,
                    'claim_number' => $claimNumber,
                    'date_filed' => now(),
                    'last_updated' => now(),
                    'status' => 'open',
                    'customer' => auth()->user()->first_name, // Assuming you have a name field in your users table
                    'user_id' => auth()->id(),
                    'amount' => 1000, // Default amount
                    'conversation_id' => $conversation->id, // Link to the conversation
                ]);
    
                return response()->json([
                    'message' => 'Claim and conversation saved successfully',
                    'claim_number' => $claimNumber,
                ]);
            } else {
                return response()->json([
                    'message' => 'The claim type exists but is not closed or settled.',
                ], 400);
            }
        } catch (\Exception $e) {
            // Log the error for debugging
            Log::error('Error saving claim: ' . $e->getMessage());
            return response()->json([
                'message' => 'An error occurred while processing your claim.',
                'error' => $e->getMessage(),
            ], 500);
        }
    
    

        
    }
    
    private function generateClaimNumber($claimType)
    {
        $prefix = Str::substr($claimType, 0, 3); // Take first 3 letters of claim type
        $date = now()->format('Ymd');
        $random = Str::random(6);
    
        return strtoupper($prefix) . '/' . $date . '/' . $random;
    }
    
    public function show($encoded_claim_number)
    {
        // Decode the Base64 encoded claim_number
        $claim_number = base64_decode($encoded_claim_number);
    
        // Find the claim by claim_number
        $claim = Claim::where('claim_number', $claim_number)->firstOrFail();
    
        // Use conversation_id from claim to find the conversation
        $conversation = Conversation::where('id', $claim->conversation_id)->firstOrFail();
    
        // Pass the conversation to the view
        return view('admin.conversations', compact('conversation'));
    }
    
    
    

}