<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Session;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\Storage;
use App\Models\UserDetail;
use thiagoalessio\TesseractOCR\TesseractOCR;

class ChatbottController extends Controller
{
    private $apiKey;
    private $model;

    public function __construct()
    {
        $this->apiKey = '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';
        $this->model = 'llama-3.1-8b-instant';
    }

    public function index()
{
    $user = Auth::user();
    $userName = $user->name;

    // Fetch the user's details
    $userDetail = UserDetail::where('user_id', $user->id)->first();

    // Check if the selfie path exists
    $selfiePath = $userDetail ? $userDetail->selfie_path : null;
    $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;

    return view('user.chatbott', compact('userName', 'selfiePath', 'selfieExists'));
}


    public function send(Request $request)
    {
        $userMessage = $request->input('message');
        $botResponse = $this->getBotResponse($userMessage);

        return response()->json(['message' => $botResponse]);
    }

    private function getBotResponse($message)
    {
        $url = "https://api.groq.com/openai/v1/chat/completions";
    
        $chat = $this->getChatHistory();
        $chat[] = [
            'role' => 'user',
            'content' => $message
        ];
    
        $data = [
            'model' => $this->model,
            'messages' => $chat,
            'temperature' => 1,
            'max_tokens' => 1024,
            'top_p' => 1,
            'stream' => false,
            'stop' => null
        ];
    
        $response = Http::withHeaders([
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json'
        ])->post($url, $data);
    
        if ($response->successful()) {
            $result = $response->json();
            if (isset($result['choices'][0]['message']['content'])) {
                $botResponse = $result['choices'][0]['message']['content'];
                $chat[] = [
                    'role' => 'assistant',
                    'content' => $botResponse
                ];
                $this->saveChatHistory($chat);
                return $botResponse;
            }
        } else {
            // Attempt to extract and return text from the error response
            $errorText = $response->body();
            return "Model Output: {$errorText}";
        }
    
        return "Sorry, I didn't understand. Please rephrase or avoid sensitive terms.";
    }

    private function getChatHistory()
    {
        if (!Session::has('chat_history')) {
            $initialChat = $this->initializeChat();
            Session::put('chat_history', $initialChat);
        }
        return Session::get('chat_history');
    }

    private function saveChatHistory($chat)
    {
        Session::put('chat_history', $chat);
    }

    private function initializeChat()
    {
        return [
            [
                'role' => 'system',
                'content' => "You are Prince, a cheerful AI assistant for Crownscope Insurance. Your goal is to handle user payment and package subscription processes efficiently. Here's how you should proceed:

Receiving Details:

Expect user details: name, phone number, amount, and package.
If these details are missing, respond: Sorry, I can't find your information.
Handling Paid Package Details:

If the user provides details of a paid package:
Inform them of their current subscription, due date, and remaining days.
Ask if they are interested in upgrading their package.
If they want to upgrade, inform them that support will contact them.
Handling Unpaid Package Details:

If the user provides unpaid package details:
Note: You cannot change your details here. Please use the settings page for updates.
List the details received and ask the user to confirm if everything is correct.
Clearly state that the final format will only be shown if the user confirms their details.
If the user confirms, output the details in the following format nb numbers only in the value and nothing more:

~pnumber:value
~amount:value"
            ]
        ];
    }

    public function upload(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:jpg,jpeg,png,bmp,tiff|max:2048',
        ]);

        $file = $request->file('file');
        $fileName = uniqid() . '_' . time() . '.' . $file->getClientOriginalExtension();
        $filePath = public_path('uploads/' . $fileName);
        $file->move(public_path('uploads'), $fileName);

        try {
            $fileRead = (new TesseractOCR($filePath))->lang('eng')->run();
            $botResponse = $this->getBotResponse($fileRead);

            return response()->json([
                'message' => $botResponse,
                'uploaded_image_url' => asset('uploads/' . $fileName)
            ]);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function clearHistory()
{
    Session::forget('chat_history');
    return response()->json(['message' => 'Chat history cleared.']);
}

}
