<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
class CustomerController extends Controller
{
    /**
     * Export selected users to a CSV file.
     *
     * @param Request $request
     * @return \Illuminate\Http\Response
     */
    
     public function export(Request $request)
{
    $ids = $request->input('ids');

    if (empty($ids)) {
        return response()->json([
            'success' => false,
            'message' => 'No users selected for export.'
        ], 400);
    }

    // Fetch users based on selected IDs
    $users = User::whereIn('id', $ids)->get();

    if ($users->isEmpty()) {
        return response()->json([
            'success' => false,
            'message' => 'No users found for the provided IDs.'
        ], 404);
    }

    // Prepare CSV header
    $csvData = "Name,Email,Phone,Account Created\n";

    // Add user data to CSV
    foreach ($users as $user) {
        $csvData .= sprintf(
            "%s %s,%s,\"%s\",%s\n", // Wrap phone in double quotes
            $user->first_name,
            $user->last_name,
            $user->email,
            $user->phone,
            $user->created_at->format('d F Y')
        );
    }

    // Define the file name
    $filename = "customers_" . now()->format('Ymd_His') . ".csv";

    // Return CSV as a download response
    return Response::make($csvData, 200, [
        'Content-Type' => 'text/csv',
        'Content-Disposition' => "attachment; filename=$filename",
    ]);
}


    /**
     * Delete selected users from the database.
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function delete(Request $request)
    {
        $ids = $request->input('ids');

        // Delete users based on selected IDs
        User::whereIn('id', $ids)->delete();

        return response()->json([
            'success' => true,
            'message' => 'Selected users deleted successfully.',
        ]);
    }

    /**
     * Import users from an uploaded CSV file.
     *
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function import(Request $request)
    {
        // Validate uploaded file
        $request->validate([
            'file' => 'required|mimes:csv,txt|max:2048',
        ]);
    
        $file = $request->file('file');
        $fileData = array_map('str_getcsv', file($file->getRealPath()));
    
        // Skip the header row and process each row
        foreach ($fileData as $index => $row) {
            if ($index === 0) continue; // Skip header row
    
            // Split full name into first and last name
            $nameParts = explode(' ', $row[0] ?? ''); // Assuming the full name is in the first column
            $firstName = $nameParts[0] ?? null;
            $lastName = isset($nameParts[1]) ? implode(' ', array_slice($nameParts, 1)) : null;
    
            // Create or update users based on email
            User::updateOrCreate(
                ['email' => $row[1]], // Use email as the unique identifier
                [
                    'first_name'  => $firstName,
                    'last_name'   => $lastName,
                    'phone'       => $row[2] ?? null,
                    'password'    => Hash::make('12345678'), // Set default password
                    'is_verified' => 1, // Mark user as verified
                    'updated_at'  => now(),
                    'created_at'  => now(), // Ensure timestamps are set
                ]
            );
        }
    
        return redirect()->back()->with('success', 'Contacts imported successfully.');
    }
}
