<?php

namespace App\Http\Controllers;
use Illuminate\Support\Facades\DB;


use App\Models\UserDetail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Notification;
use App\Models\RentersDetail;
use App\Models\GolfersDetail;
use App\Models\TravelDetail;
use App\Models\MedicalDetail;
use App\Models\PetsDetail;
use App\Models\MpesaSTK;
use App\Models\StripePayment;
use App\Models\User;
use App\Models\Claim;
use App\Models\Note;
use App\Models\AccidentDetails;
use App\Models\Activity;
use Illuminate\Support\Facades\Http;
use App\Models\ResidentialProperty;
use App\Models\Paystack;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;

class DashboardController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
   
    public function index()
    {
        // Storage link logic
        $source = storage_path('app/public');
        $destination = public_path('storage');
    
        // Check if the destination directory exists, if not create it
        if (!File::exists($destination)) {
            File::makeDirectory($destination, 0755, true);
        }
    
        // Copy directories and their contents
        $directory = opendir($source);
        @mkdir($destination);
    
        while ($file = readdir($directory)) {
            if ($file == '.' || $file == '..') {
                continue;
            }
    
            $srcFile = $source . '/' . $file;
            $destFile = $destination . '/' . $file;
    
            if (is_dir($srcFile)) {
                $this->copyDirectoryInline($srcFile, $destFile);
            } else {
                copy($srcFile, $destFile);
            }
        }
    
        closedir($directory);
    
        // The rest of the index method logic
        $user = auth()->user();
        $userDetail = UserDetail::where('user_id', $user->id)->first();
        $selfiePath = $userDetail ? $userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;
        $notificationCount1 = Notification::where('user_id', $user->id)->value('notification_count') ?? 0;
        $phoneNumber = $user->phone;
        $paystackPayments = Paystack::where('user_id', $user->id)->get();
        $mpesaPayments = MpesaSTK::where('PhoneNumber', $phoneNumber)->get();
        $mpesaTotal = $mpesaPayments->sum('Amount');
        $paystackTotal = $paystackPayments->sum('amount');
        $user->wallet += $paystackTotal + $mpesaTotal;
        $user->save();
    
        foreach ($paystackPayments as $paystackPayment) {
            $paystackPayment->amount = 0;
            $paystackPayment->save();
        }
    
        foreach ($mpesaPayments as $mpesaPayment) {
            $mpesaPayment->amount = 0;
            $mpesaPayment->save();
        }
    
        $tablesToUpdate = [
            'RentersDetail' => RentersDetail::class,
            'GolfersDetail' => GolfersDetail::class,
            'TravelDetail' => TravelDetail::class,
            'MedicalDetail' => MedicalDetail::class,
            'ResidentialProperty' => ResidentialProperty::class,
        ];
    
        foreach ($tablesToUpdate as $table => $model) {
            $items = $model::where('user_id', $user->id)->get();
            foreach ($items as $item) {
                if ($item->payment === 'paid') {
                    continue;
                }
    
                if ($user->wallet >= $item->premium) {
                    $user->wallet -= $item->premium;
                    $user->save();
                    $item->payment = 'paid';
                    $item->save();
                } else {
                    $item->payment = 'pending';
                    $item->save();
                }
            }
        }
    
        $activeRentersCount = RentersDetail::where('user_id', $user->id)->where('payment', 'paid')->count();
        $activeGolfersCount = GolfersDetail::where('user_id', $user->id)->where('payment', 'paid')->count();
        $activeTravelCount = TravelDetail::where('user_id', $user->id)->where('payment', 'paid')->count();
        $activeMedicalCount = MedicalDetail::where('user_id', $user->id)->where('payment', 'paid')->count();
        $activeResidentialPropertyCount = ResidentialProperty::where('user_id', $user->id)->where('payment', 'paid')->count();
    
        $totalActiveCovers = $activeRentersCount + $activeGolfersCount + $activeTravelCount + $activeMedicalCount + $activeResidentialPropertyCount;
    
        $claimCount = Claim::where('user_id', $user->id)->where('status', 'open')->count();
    
        return view('user.dashboard', [
            'user' => $user,
            'userDetail' => $userDetail,
            'selfiePath' => $selfiePath,
            'selfieExists' => $selfieExists,
            'notificationCount1' => $notificationCount1,
            'totalActiveCovers' => $totalActiveCovers,
            'claimCount' => $claimCount,
        ]);
    }
    
    private function copyDirectoryInline($source, $destination)
    {
        $directory = opendir($source);
        @mkdir($destination);
    
        while ($file = readdir($directory)) {
            if ($file == '.' || $file == '..') {
                continue;
            }
    
            $srcFile = $source . '/' . $file;
            $destFile = $destination . '/' . $file;
    
            if (is_dir($srcFile)) {
                $this->copyDirectoryInline($srcFile, $destFile);
            } else {
                copy($srcFile, $destFile);
            }
        }
    
        closedir($directory);
    }
    

    
    
public function adminHome()
{
    // Total gross premium to date, only where payment is marked as 'paid'
    $totalGrossPremium = ResidentialProperty::where('payment', 'paid')->sum('premium') +
        RentersDetail::where('payment', 'paid')->sum('premium') +
        GolfersDetail::where('payment', 'paid')->sum('premium') +
        AccidentDetails::where('payment', 'paid')->sum('premium') +
        TravelDetail::where('payment', 'paid')->sum('premium') +
        MedicalDetail::where('payment', 'paid')->sum('premium');

    // Claim settlement amount to date (where status is 'settled')
    $totalClaimSettlement = Claim::where('status', 'settled')->sum('amount');

    // Number of claims settled
    $claimsSettledCount = Claim::where('status', 'settled')->count();

    // Net premium (assuming net premium is total gross premium minus settled claims)
    $netPremium = $totalGrossPremium - $totalClaimSettlement;

// Sales Performance Data
$salesPerformanceData = [
    'Residential Property' => ResidentialProperty::where('payment', 'paid')->sum('premium'),
    //'Renters' => RentersDetail::where('payment', 'paid')->sum('premium'),
    'Golfers' => GolfersDetail::where('payment', 'paid')->sum('premium'),
    'Accident' => AccidentDetails::where('payment', 'paid')->sum('premium'),
    'Travel' => TravelDetail::where('payment', 'paid')->sum('premium'),
    'Medical' => MedicalDetail::where('payment', 'paid')->sum('premium')
];

// Monthly Sales Data
$monthlySalesData = [];
for ($month = 1; $month <= 12; $month++) {
    $monthlySalesData[Carbon::create()->month($month)->format('M')] = ResidentialProperty::whereMonth('created_at', $month)->where('payment', 'paid')->sum('premium')
        + RentersDetail::whereMonth('created_at', $month)->where('payment', 'paid')->sum('premium')
        + GolfersDetail::whereMonth('created_at', $month)->where('payment', 'paid')->sum('premium')
        + AccidentDetails::whereMonth('created_at', $month)->where('payment', 'paid')->sum('premium')
        + TravelDetail::whereMonth('created_at', $month)->where('payment', 'paid')->sum('premium')
        + MedicalDetail::whereMonth('created_at', $month)->where('payment', 'paid')->sum('premium');
}


$claimsByPolicyData = [
    'Residential Property' => Claim::where('policy', 'Residential Property')->count(),
    //'Renters' => Claim::where('policy', 'Renters')->count(),
    'Golfers' => Claim::where('policy', 'Golfers')->count(),
    'Accident' => Claim::where('policy', 'Accident')->count(),
    'Travel' => Claim::where('policy', 'Travel')->count(),
    'Medical' => Claim::where('policy', 'Medical')->count()
];


// Claims Open vs Closed Data
$openClaims = [];
$closedClaims = [];
for ($month = 1; $month <= 12; $month++) {
    $openClaims[Carbon::create()->month($month)->format('M')] = Claim::where('status', 'open')->whereMonth('date_filed', $month)->count();
    $closedClaims[Carbon::create()->month($month)->format('M')] = Claim::where('status', 'closed')->whereMonth('date_filed', $month)->count();
}


// Latest Notifications
$latestClaims = Claim::latest()->take(3)->get();
$pendingClaims = Claim::where('status', 'pending')->get();

// Group pending claims by policy type
$claimsPendingSummary = $pendingClaims->groupBy('policy')->map->count();





$user = Auth::user();

$userDetails = UserDetail::where('user_id', $user->id)->first();

if ($userDetails) {
    $notificationData = [
        'user_id' => $user->id,
        'kra_pin' => $userDetails->kra_pin ? 1 : 0,
        'selfie' => $userDetails->selfie_path ? 1 : 0,
        'id_card_front' => $userDetails->national_id_front_path ? 1 : 0,
        'id_card_back' => $userDetails->national_id_back_path ? 1 : 0,
        'home_address' => $userDetails->home_address ? 1 : 0,
        'dob' => $userDetails->date_of_birth ? 1 : 0,
        'created_at' => now(),
        'updated_at' => now(),
    ];
} else {
    $notificationData = [
        'user_id' => $user->id,
        'kra_pin' => 0,
        'selfie' => 0,
        'id_card_front' => 0,
        'id_card_back' => 0,
        'home_address' => 0,
        'dob' => 0,
        'created_at' => now(),
        'updated_at' => now(),
    ];
}

$notification = Notification::where('user_id', $user->id)->first();
if ($notification) {
    $notification->update($notificationData);
} else {
    Notification::create($notificationData);
}




    return view('admin.index', compact(
        'totalGrossPremium', 
        'totalClaimSettlement', 
        'claimsSettledCount', 
        'netPremium',
        'salesPerformanceData', 
        'monthlySalesData', 
        'claimsByPolicyData', 
        'openClaims', 
        'closedClaims',
        'latestClaims',
        'claimsPendingSummary'

    ));
}

    public function adminCustomer()
    {
        $users = User::all();

        // Fetching user details
        $userDetails = UserDetail::all()->keyBy('user_id');

        // Pass the data to the view
        return view('admin.customers', compact('users', 'userDetails'));
        
      
    
  
    }
    
    public function adminClaims()
    {
        $claims = Claim::all();

        // Pass the claims data to the view
        return view('admin.claims', compact('claims'));
    }
    public function adminPolicy()
    {


        // Fetch data from all relevant tables
        $rentersDetails = RentersDetail::with('user')->get();
        $golfersDetails = GolfersDetail::with('user')->get();
        $travelDetails = TravelDetail::with('user')->get();
        $medicalDetails = MedicalDetail::with('user')->get();
        $residentialProperties = ResidentialProperty::with('user')->get();

        // Combine all data into one array for the view
        $covers = $rentersDetails->merge($golfersDetails)
            ->merge($travelDetails)
            ->merge($residentialProperties)
            ->merge($medicalDetails);

           // dd($covers);
        return view('admin.policy',compact('covers'));
    }
    public function adminRenewals()
    {
        return view('admin.renewals');
    }
    public function adminUserview($user_id)
    {
        // Fetch data for the specified user from all relevant tables, adding cover type and filtering out records without status
        $accidentDetails = AccidentDetails::where('user_id', $user_id)->get()->filter(function ($item) {
            return $item && $item->status !== null; // Only include items with a status
        })->map(function ($item) {
            $item->cover_type = 'Accident';
            return $item;
        });
    
        $golfersDetails = GolfersDetail::where('user_id', $user_id)->get()->filter(function ($item) {
            return $item && $item->status !== null;
        })->map(function ($item) {
            $item->cover_type = 'Golfers';
            return $item;
        });
    
        $travelDetails = TravelDetail::where('user_id', $user_id)->get()->filter(function ($item) {
            return $item && $item->status !== null;
        })->map(function ($item) {
            $item->cover_type = 'Travel';
            return $item;
        });
    
        $medicalDetails = MedicalDetail::where('user_id', $user_id)->get()->filter(function ($item) {
            return $item && $item->status !== null;
        })->map(function ($item) {
            $item->cover_type = 'Medical';
            return $item;
        });
    
        $residentialProperties = ResidentialProperty::where('user_id', $user_id)->get()->filter(function ($item) {
            return $item && $item->status !== null;
        })->map(function ($item) {
            $item->cover_type = 'Residential Property';
            return $item;
        });
    
        // Combine all data into one collection
        $covers = $accidentDetails
            ->merge($golfersDetails)
            ->merge($travelDetails)
            ->merge($residentialProperties)
            ->merge($medicalDetails);
    
        // Additional data for view
        $recentActivities = DB::table('activity_log')
            ->where('subject_id', $user_id)
            ->where('created_at', '>=', Carbon::now()->subDay())
            ->orderBy('created_at', 'desc')
            ->get()
            ->map(function ($activity) {
                $activity->properties = json_decode($activity->properties, true);
                return $activity;
            });
    
        $user = User::find($user_id);
        $userDetails = UserDetail::where('user_id', $user_id)->first();
    
        // Handling location extraction and missing details actions
        $location = null;
        if ($userDetails && $userDetails->home_address) {
            $coordinates = explode(',', $userDetails->home_address);
            $latitude = trim(explode(':', $coordinates[0])[1]);
            $longitude = trim(explode(':', $coordinates[1])[1]);
            $location = ['latitude' => $latitude, 'longitude' => $longitude];
        }
    
        $actionsNeeded = [];
        if ($userDetails) {
            if (!$userDetails->kra_pin) $actionsNeeded[] = 'User to update KRA PIN';
            if (!$userDetails->home_address) $actionsNeeded[] = 'User to provide home address';
            if (!$userDetails->selfie_path) $actionsNeeded[] = 'User to provide selfie';
            if (!$userDetails->national_id_front_path) $actionsNeeded[] = 'User to provide national ID';
        } else {
            $actionsNeeded[] = 'User to provide all necessary details';
        }
        $latestClaims1 = Claim::where('user_id', $user_id)->latest()->take(3)->get();
        // Fetch only open claims for the specified user
        $claims = Claim::where('user_id', $user_id)->where('status', 'open')->get();
        $beneficiaries = $travelDetails->flatMap(fn($detail) => json_decode($detail->traveller_details, true) ?? []);
    
        // Fetch notes for the specified user
        $notes = Note::where('user_id', $user_id)->orderBy('created_at', 'desc')->get();
    
        // Pass data to the view
        return view('admin.userview', compact('user','latestClaims1', 'claims', 'userDetails', 'location', 'covers', 'recentActivities', 'actionsNeeded', 'beneficiaries', 'notes'));
    }
    
    
    
}

