<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\GolfersDetail;
use App\Models\GolfersDetailOfCover;
use Carbon\Carbon;

class GolfersoverviewController extends Controller
{
    public function index()
    {
        $user = auth()->user();
    
        // Fetch the golfer's detail for the authenticated user
        $golfersDetail = GolfersDetail::where('user_id', $user->id)->first();
    
        if (!$golfersDetail) {
            return view('user.golfersoverview', [
                'package' => null,
                'premium' => null,
                'expiry_date' => null,
                'autorenew' => null,
                'coverages' => [],
            ]);
        }
    
        // Fetch exclusions for the chosen package
        $exclusions = GolfersDetailOfCover::where('plan_name', $golfersDetail->package)
            ->select('exclusion_type', 'exclusion_description')
            ->distinct()
            ->get();
    
        // Fetch the golfer's detail of cover based on the chosen package
        // Explicitly include the file_path column
        $golfersDetailOfCover = GolfersDetailOfCover::where('plan_name', $golfersDetail->package)
            ->select('coverage_name', 'amount', 'description', 'file_path', 'premium')
            ->get();
    
        $premium = $golfersDetailOfCover->first() ? $golfersDetailOfCover->first()->premium : null;
    
        return view('user.golfersoverview', [
            'package' => $golfersDetail->package,
            'premium' => $premium,
            'expiry_date' => Carbon::parse($golfersDetail->expiry_date)->format('d/m/Y'),
            'autorenew' => $golfersDetail->autorenew,
            'coverages' => $golfersDetailOfCover,
            'exclusions' => $exclusions,
        ]);
    }}
