<?php


namespace App\Http\Controllers;
use App\Models\GolfersDetail;
use Illuminate\Http\Request;
use App\Models\UserDetail;
use Carbon\Carbon;
use Illuminate\Support\Facades\Storage;
class  GolfersprinceController extends Controller
{
    public function index()
    {
        // Fetch the authenticated user
        $user = auth()->user();
    
        // Fetch the user's details
        $userDetail = UserDetail::where('user_id', $user->id)->first();
    
        // Check if the selfie path exists
        $selfiePath = $userDetail ? $userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;
    
        // Format the user's phone number
        $formattedPhoneNumber = $this->formatPhoneNumber($user->phone ?? '');
    
        // Pass data to the view
        return view('user.golfersprince', [
            'user' => $user,
            'phoneNumber' => $formattedPhoneNumber, // Pass the formatted phone number to the view
            'selfiePath' => $selfiePath, // Pass the selfie path to the view
            'selfieExists' => $selfieExists, // Pass the selfie existence status to the view
        ]);
    }

    /**
     * Format phone number from international to local format.
     *
     * @param string $phoneNumber
     * @return string
     */
    private function formatPhoneNumber($phoneNumber)
    {
        // Remove any non-numeric characters (except leading +)
        $cleanedNumber = preg_replace('/[^\d]/', '', $phoneNumber);

        // Remove the international dialing code if present (e.g., +254)
        if (substr($cleanedNumber, 0, 1) == '0') {
            // Phone number is already in local format
            return $cleanedNumber;
        } elseif (substr($cleanedNumber, 0, 3) == '254') {
            // Remove country code (254) for local format
            return '0' . substr($cleanedNumber, 3);
        }

        // Return the cleaned number if no special formatting is required
        return $cleanedNumber;
    }
    public function storeGolfersDetails(Request $request)
    {
        $user = auth()->user();
    
        $existingDetails = GolfersDetail::where('user_id', $user->id)->first();
    
        if ($existingDetails) {
            return response()->json(['redirect' => route('dashboard')]);
        }
    
        $golfersDetail = new GolfersDetail();
        $golfersDetail->user_id = $user->id;
        $golfersDetail->activity = 1;
        $golfersDetail->cover_type  = 'Golfers';
        $golfersDetail->status = 'Active';
        $golfersDetail->expiry_date = Carbon::now()->addDays(30)->format('Y-m-d');
        $golfersDetail->autorenew = 0;
        $golfersDetail->package = $request->selectedPackage;
        $golfersDetail->premium = $request->amount;
        $golfersDetail->save();
    
        return response()->json(['data' => $golfersDetail]);
    }
    
    
    }

    
