<?php


namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\MedicalDetail;
use Carbon\Carbon;
use App\Models\UserDetail;

use Illuminate\Support\Facades\Storage;
class  MedicalprinceController extends Controller
{
    public function index()
    {
        // Fetch the authenticated user
        $user = auth()->user();
    
        // Fetch the user's details
        $userDetail = UserDetail::where('user_id', $user->id)->first();
    
        // Check if the selfie path exists
        $selfiePath = $userDetail ? $userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;
    
        // Format the user's phone number
        $formattedPhoneNumber = $this->formatPhoneNumber($user->phone ?? '');
    
        // Pass data to the view
        return view('user.medicalprince', [
            'user' => $user,
            'phoneNumber' => $formattedPhoneNumber, // Pass the formatted phone number to the view
            'selfiePath' => $selfiePath, // Pass the selfie path to the view
            'selfieExists' => $selfieExists, // Pass the selfie existence status to the view
        ]);
    }
    
    /**
     * Format phone number from international to local format.
     *
     * @param string $phoneNumber
     * @return string
     */
    private function formatPhoneNumber($phoneNumber)
    {
        // Remove any non-numeric characters (except leading +)
        $cleanedNumber = preg_replace('/[^\d]/', '', $phoneNumber);

        // Remove the international dialing code if present (e.g., +254)
        if (substr($cleanedNumber, 0, 1) == '0') {
            // Phone number is already in local format
            return $cleanedNumber;
        } elseif (substr($cleanedNumber, 0, 3) == '254') {
            // Remove country code (254) for local format
            return '0' . substr($cleanedNumber, 3);
        }

        // Return the cleaned number if no special formatting is required
        return $cleanedNumber;
    }

    public function storeMedicalData(Request $request)
    {
        // Validate incoming request
        $validated = $request->validate([
            'amount' => 'required|numeric',
            'coverLimit' => 'required|string',
            'additionalAdults' => 'required|integer',
            'additionalChildren' => 'required|integer',
            'additionalAdultDetails' => 'nullable|string',
            'files.*' => 'nullable|file|mimes:jpeg,png,jpg,gif,pdf|max:2048',
        ]);
    
        $user = auth()->user();
    
        // Check if the user already has medical details
        $existingDetails = MedicalDetail::where('user_id', $user->id)->first();
    
        if ($existingDetails) {
            // Redirect to the billing page if details exist
            return response()->json(['redirect' => route('dashboard')]);
        }
    
        // Handle file uploads if present
        $filePaths = [];
        if ($request->hasFile('files')) {
            foreach ($request->file('files') as $file) {
                if ($file->isValid()) {
                    $fileName = time() . '_' . $file->getClientOriginalName();
                    $filePath = $file->storeAs('national_ids', $fileName, 'public');
                    $filePaths[] = $filePath;
                }
            }
        }
    
        // Create a new MedicalDetail instance
        $medicalDetail = new MedicalDetail();
    
        // Set the details from the validated data
        $medicalDetail->amount = $validated['amount'];
        $medicalDetail->cover_limit = $validated['coverLimit'];
        $medicalDetail->additional_adults = $validated['additionalAdults'];
        $medicalDetail->additional_children = $validated['additionalChildren'];
        $medicalDetail->additional_adult_details = $validated['additionalAdultDetails'];
        $medicalDetail->national_id_image = json_encode($filePaths); // Store file paths as JSON
    
        // Set additional details
        $medicalDetail->user_id = $user->id;
        $medicalDetail->activity = 1;
        $medicalDetail->cover_type = 'medical';
        $medicalDetail->status = 'Active';
        $medicalDetail->expiry_date = Carbon::now()->addDays(30)->format('Y-m-d');
        $medicalDetail->autorenew = 0;
    
        // Save the data
        $medicalDetail->save();
    
        // Return a response indicating success
        return response()->json([
            'success' => true,
            'message' => 'Medical detail saved successfully!',
            'file_paths' => array_map(function($path) {
                return asset('storage/' . $path);
            }, $filePaths),
        ]);
    }
    
}