<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Notification;
use Illuminate\Support\Facades\Storage;
use App\Models\UserDetail;
use App\Models\RentersDetail;
use Carbon\Carbon;

use App\Models\GolfersDetail;
use App\Models\TravelDetail;
use App\Models\MedicalDetail;

use App\Models\StripePayment;
use App\Models\ResidentialProperty;

class NotificationController extends Controller
{

    public function index()
    {
        // Fetch the authenticated user
        $user = auth()->user();
        
        // Fetch the user's details
        $userDetail = UserDetail::where('user_id', $user->id)->first();
        
        // Check if the selfie path exists
        $selfiePath = $userDetail ? $userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('storage/', '', $selfiePath)) : false;
        
        // Fetch notifications for the user
        $notifications = Notification::where('user_id', $user->id)->first();
        $notificationCount = $notifications ? $notifications->count() : 0;
        
        // Fetch cover_type, status, and updated_at from renters_details table
        $rentersDetail = RentersDetail::where('user_id', $user->id)->first();
        $coverType = $rentersDetail ? $rentersDetail->cover_type : 'No policy';
        $status = $rentersDetail ? $rentersDetail->status : 'No status';
        $updatedAt = $rentersDetail ? $rentersDetail->updated_at : null;
        $expiryDate = $rentersDetail ? Carbon::parse($rentersDetail->expiry_date) : null;
        $autorenew = $rentersDetail ? $rentersDetail->autorenew : '1';



        $paymentStatuses = [
            'renters' => 'unavailable',  // Default state if no record is found
            'golfers' => 'unavailable',  // Default state if no record is found
            'travel' => 'unavailable',   // Default state if no record is found
            'medical' => 'unavailable',  // Default state if no record is found
            'residential' => 'unavailable',  // Default state if no record is found
        ];
        
        // Check payment status for RentersDetail
        $rentersDetail = RentersDetail::where('user_id', $user->id)->first();
        if ($rentersDetail) {
            $paymentStatuses['renters'] = ($rentersDetail->payment === 'paid') ? 'paid' : 'pending';
        }
        
        // Check payment status for GolfersDetail
        $golfersDetail = GolfersDetail::where('user_id', $user->id)->first();
        if ($golfersDetail) {
            $paymentStatuses['golfers'] = ($golfersDetail->payment === 'paid') ? 'paid' : 'pending';
        }
        
        // Check payment status for TravelDetail
        $travelDetail = TravelDetail::where('user_id', $user->id)->first();
        if ($travelDetail) {
            $paymentStatuses['travel'] = ($travelDetail->payment === 'paid') ? 'paid' : 'pending';
        }
        
        // Check payment status for MedicalDetail
        $medicalDetail = MedicalDetail::where('user_id', $user->id)->first();
        if ($medicalDetail) {
            $paymentStatuses['medical'] = ($medicalDetail->payment === 'paid') ? 'paid' : 'pending';
        }
        
        // Check payment status for ResidentialProperty
        $residentialProperty = ResidentialProperty::where('user_id', $user->id)->first();
        if ($residentialProperty) {
            $paymentStatuses['residential'] = ($residentialProperty->payment === 'paid') ? 'paid' : 'pending';
        }
        
    
       // Logic to notify the user based on payment status
foreach ($paymentStatuses as $coverType => $status) {
    if ($status === 'pending') {
        // Notify the user about pending payment
        session()->flash('payment_pending', "Payment is pending for your $coverType coverage.");
    } elseif ($status === 'unavailable') {
        // Notify the user that their details are not found
        session()->flash('payment_unavailable', "No payment details found for your $coverType coverage. Please check your information.");
    }
}







        
        // Format the updated_at timestamp
        $formattedDate = $updatedAt ? $updatedAt->format('j F Y H:i') : 'No date available';
        $daysRemaining = $expiryDate ? $expiryDate->diffInDays(Carbon::now()) : null;
    
        // Initialize missingFields array
        $missingFields = [];

// Check if notifications exist and if certain fields are missing
if ($notifications) {
    if (is_null($notifications->kra_pin) || $notifications->kra_pin != 1) $missingFields[] = 'KRA PIN';
    if (is_null($notifications->selfie) || $notifications->selfie != 1) $missingFields[] = 'Selfie Path';
    if (is_null($notifications->id_card) || $notifications->id_card != 1) $missingFields[] = 'National ID Path';
    if (is_null($notifications->home_address) || $notifications->home_address != 1) $missingFields[] = 'Home Address';
    if (is_null($notifications->dob) || $notifications->dob != 1) $missingFields[] = 'Date of Birth';
}
    
        // Store notification count in session
        session()->put('notificationCount', $notificationCount);
        
        // Pass the user, user details, cover type, notifications data, status, and formatted date to the view
        return view('user.notifications', [
            'user' => $user,
            'userDetail' => $userDetail,
            'selfiePath' => $selfiePath,
            'selfieExists' => $selfieExists,
            'notifications' => $notifications,
            'notificationCount' => $notificationCount,
            'missingFields' => $missingFields,
            'coverType' => $coverType,
            'status' => $status,
            'formattedDate' => $formattedDate,
            'daysRemaining' => $daysRemaining,
            'autorenew' => $autorenew,
            'paymentStatuses' => $paymentStatuses,
        ]);
    }
    
    public function toggleAutoRenew()
{
    // Fetch the authenticated user
    $user = auth()->user();
    
    // Fetch the renter's details
    $rentersDetail = RentersDetail::where('user_id', $user->id)->first();

    // Toggle the autorenew value
    if ($rentersDetail) {
        $rentersDetail->autorenew = $rentersDetail->autorenew === '1' ? '0' : '1';
        $rentersDetail->save();
    }

    // Redirect back to the notifications page
    return redirect()->route('notifications.index');
}
    public function create()
    {
        return view('notifications.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'kra_pin' => 'required|string|max:255',
            'selfie' => 'required|image|max:2048',
            'id_card' => 'required|image|max:2048',
            'home_address' => 'required|string|max:255',
            'dob' => 'required|date',
        ]);

        $selfiePath = $request->file('selfie')->store('public/selfies');
        $idCardPath = $request->file('id_card')->store('public/id_cards');

        Notification::create([
            'kra_pin' => $request->kra_pin,
            'selfie' => $selfiePath,
            'id_card' => $idCardPath,
            'home_address' => $request->home_address,
            'dob' => $request->dob,
        ]);

        return redirect()->route('user.notifications')->with('success', 'Notification created successfully.');
    }
    public function updateNotificationCount(Request $request)
    {
        $count = $request->input('count');
        $userId = auth()->id(); // Assuming you're using Laravel's built-in authentication

        // Update the notification count in the database
        $notification = Notification::updateOrCreate(
            ['user_id' => $userId],
            ['notification_count' => $count]
        );

        return response()->json(['success' => true, 'count' => $notification->notification_count]);
    }

}
