<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Models\User;

class PersonController extends Controller
{
    /**
     * Add a new person to the users table.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function addPerson(Request $request)
{
    try {
        // Validate the incoming request data
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email',
            'phone' => 'required|string|max:20|unique:users,phone',
            'kra_pin' => 'nullable|string|max:20',
        ]);

        // Split the name into first name and last name
        $nameParts = explode(' ', $request->input('name'));
        $firstName = $nameParts[0] ?? null;
        $lastName = isset($nameParts[1]) ? implode(' ', array_slice($nameParts, 1)) : null;

        // Create the new user record
        User::create([
            'first_name' => $firstName,
            'last_name' => $lastName,
            'email' => $request->input('email'),
            'phone' => $request->input('phone'),
            'password' => Hash::make('12345678'), // Set default password
            'is_verified' => 1, // Mark as verified
        ]);

        // Return a JSON response indicating success
        return response()->json(['success' => true, 'message' => 'Person added successfully']);
    } catch (\Exception $e) {
        // Return a generic error message
        return response()->json([
            'success' => false,
            'message' => 'An error occurred while adding the person. Please check the inputs and try again.'
        ], 500);
    }
}

}
