<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\GolfersDetail;
use Illuminate\Support\Facades\Auth;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\Storage;

class ReceiptController extends Controller
{
    public function generateReceipt()
    {
        // Get the authenticated user
        $user = Auth::user();
        $golferDetail = GolfersDetail::where('user_id', $user->id)->firstOrFail();

        // Fetch Golfer Details based on the authenticated user
  // Prepare logo image
  $logoPath = public_path('receiptlogo/logo.png');
  $logoData = base64_encode(file_get_contents($logoPath));
  $logoSrc = 'data:image/png;base64,' . $logoData;

  // Prepare PAID stamp image
  $stampPath = public_path('receiptlogo/paid.png');
  $stampData = base64_encode(file_get_contents($stampPath));
  $stampSrc = 'data:image/png;base64,' . $stampData;

  // Prepare data for the view
  $data = [
      'golfer' => $golferDetail,
      'user' => $user,
      'logoSrc' => $logoSrc,
      'stampSrc' => $stampSrc
  ];
        // Load the HTML and generate the PDF
        $pdf = Pdf::loadView('receipts.template', $data);

        // Define the file name and path
        $fileName = 'receipt_' . $golferDetail->id . '.pdf';
        $filePath = 'public/receipts/' . $fileName;

        // Save the PDF to storage
        Storage::put($filePath, $pdf->output());

        // Update the filename column in the golfers_details table
        $golferDetail->update(['filename' => $fileName]);

        // Optionally return a response if needed
        return response()->json(['message' => 'Receipt generated and filename updated successfully.']);
    }
}
