<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class ResidentialPropertyController extends Controller
{
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'ownership_status' => 'required|string',
            'occupancy_status' => 'required|string',
            'property_value' => 'required|numeric',
            'rent_amount' => 'nullable|string',  // Allow both numbers and strings
            'furniture_value' => 'nullable|string',  // Allow both numbers and strings
            'electrical_appliances_value' => 'nullable|string',  // Allow both numbers and strings
            'paintings_value' => 'nullable|string',  // Allow both numbers and strings
            'kitchenware_value' => 'nullable|string',  // Allow both numbers and strings
            'household_linen_value' => 'nullable|string',  // Allow both numbers and strings
            'photography_equipment_value' => 'nullable|string',  // Allow both numbers and strings
            'jewellery_value' => 'nullable|string',  // Allow both numbers and strings
            'phones_quantity' => 'nullable|integer',
            'laptops_quantity' => 'nullable|integer',
            'tablets_quantity' => 'nullable|integer',
            'music_players_quantity' => 'nullable|integer',
            'cameras_quantity' => 'nullable|integer',
            'phone_1_model' => 'nullable|string',
            'phone_1_value' => 'nullable|string',  // Allow both numbers and strings
            'phone_2_model' => 'nullable|string',
            'phone_2_value' => 'nullable|string',  // Allow both numbers and strings
            'phone_3_model' => 'nullable|string',
            'phone_3_value' => 'nullable|string',  // Allow both numbers and strings
            'laptop_1_model' => 'nullable|string',
            'laptop_1_value' => 'nullable|string',  // Allow both numbers and strings
            'laptop_2_model' => 'nullable|string',
            'laptop_2_value' => 'nullable|string',  // Allow both numbers and strings
            'gardeners_count' => 'nullable|integer',
            'indoor_workers_count' => 'nullable|integer',
            'watchmen_count' => 'nullable|integer',
            'gardener_salary' => 'nullable|string',  // Allow both numbers and strings
            'indoor_workers_salary' => 'nullable|string',  // Allow both numbers and strings
            'watchman_salary' => 'nullable|string',  // Allow both numbers and strings
            'liability_increase_choice' => 'nullable|string',
            'owners_liability_amount' => 'nullable|string',  // Allow both numbers and strings
            'occupiers_liability_amount' => 'nullable|string',  // Allow both numbers and strings
            'additional_cover' => 'nullable|json',
          
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $data = $validator->validated();
        $data['user_id'] = auth()->id();

        try {
            $id = DB::table('residential_properties')->insertGetId($data);

            return response()->json([
                'success' => true,
                'message' => 'Residential property details saved successfully',
                'property_id' => $id
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Error saving residential property details',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
