<?php


namespace App\Http\Controllers;
use Illuminate\Support\Facades\Log;
use Illuminate\Http\Request;
use App\Models\TravelDetail;  
use Carbon\Carbon;
class TravelController extends Controller
{
    
    public function index()
    {
        $user = auth()->user();
        return view('user.travelprince', compact('user'));
    }



    
    public function storeTravelData(Request $request)
    {

        Log::info('Request data:', $request->all());
        // Validate incoming request
        $validated = $request->validate([
            'amount' => 'nullable|numeric',
            'destination' => 'nullable|string',
            'departureDate' => 'nullable|date',
            'returnDate' => 'nullable|date',
            'adults' => 'nullable|integer|min:1',
            'children' => 'nullable|integer|min:0',
            'travellerDetails' => 'nullable|array',
            'travellerDetails.*.name' => 'nullable|string',
            'travellerDetails.*.birthdate' => 'nullable|date',
            'travellerDetails.*.passport' => 'nullable|string',
            'files.*' => 'nullable|file|mimes:jpeg,png,jpg,gif,pdf|max:2048', // For potential file uploads
        ]);
    
        $user = auth()->user();
    
        // Check if the user already has travel details
        $existingDetails = TravelDetail::where('user_id', $user->id)->first();
    
        if ($existingDetails) {
            // Redirect to the billing page if details exist
            return response()->json(['redirect' => route('billing')]);
        }
    
        // Handle file uploads if present
        $filePaths = [];
        if ($request->hasFile('files')) {
            foreach ($request->file('files') as $file) {
                if ($file->isValid()) {
                    $fileName = time() . '_' . $file->getClientOriginalName();
                    $filePath = $file->storeAs('travel_documents', $fileName, 'public');
                    $filePaths[] = $filePath;
                }
            }
        }
    
        // Create a new TravelDetail instance
        $travelDetail = new TravelDetail();
    
        // Set details from the validated data
        $travelDetail->amount = $validated['amount'];
        $travelDetail->destination = $validated['destination'];
        $travelDetail->departure_date = $validated['departureDate'];
        $travelDetail->return_date = $validated['returnDate'];
        $travelDetail->adults = $validated['adults'];
        $travelDetail->children = $validated['children'];
        $travelDetail->traveller_details = json_encode($validated['travellerDetails']);
        $travelDetail->documents = json_encode($filePaths); // Store file paths as JSON if needed
    
        // Set additional details
        $travelDetail->user_id = $user->id;
        $travelDetail->activity = 1;
        $travelDetail->cover_type = 'travel';
        $travelDetail->status = 'Active';
        $travelDetail->expiry_date = Carbon::parse($validated['returnDate'])->format('Y-m-d');
        $travelDetail->autorenew = 0;
        $travelDetail->payment = 'pending';
    
        // Save the data
        $travelDetail->save();
    
        // Return a response indicating success or redirect
        return response()->json([
            'success' => true,
            'message' => 'Travel insurance details saved successfully!',
            'file_paths' => array_map(function($path) {
                return asset('storage/' . $path);
            }, $filePaths),
            'redirect' => route('billing'), // Redirect to the billing page after saving
        ]);
    }
    
}