<?php

namespace App\Http\Controllers;

use App\Models\UserDetail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use App\Models\Notification;
use Illuminate\Support\Facades\Log;

use Illuminate\Support\Facades\Auth;

class UserDetailController extends Controller
{
    public function store(Request $request)
    {
       // Log::info('Incoming Request Data:', $request->all());
   
        // Validate the incoming request data
    $validator = Validator::make($request->all(), [
        'kra_pin' => 'nullable|string',
        'selfie' => 'nullable|image|max:2048', // 2MB Max for selfie
        'front_id' => 'nullable|mimes:jpg,jpeg,png|max:2048', // Allow only images for front_id
        'back_id' => 'nullable|mimes:jpg,jpeg,png|max:2048', // Allow only images for back_id
        'home_address' => 'nullable|string',
        'date_of_birth' => 'nullable|date',
        'pre_existing_conditions' => 'nullable|string',
    ]);
    
        if ($validator->fails()) {
           
            return response()->json([
                'errors' => $validator->errors()
            ], 422);
        }
    
        $selfieUrl = $request->hasFile('selfie') ? Storage::url($request->file('selfie')->store('public/selfies')) : null;
        $nationalIdFrontUrl = $request->hasFile('front_id') ? Storage::url($request->file('front_id')->store('public/national_ids')) : null;
        $nationalIdBackUrl = $request->hasFile('back_id') ? Storage::url($request->file('back_id')->store('public/national_ids')) : null;
    
        $userDetail = UserDetail::create([
            'user_id' => auth()->id(),
            'kra_pin' => $request->input('kra_pin'),
            'selfie_path' => $selfieUrl,
            'national_id_front_path' => $nationalIdFrontUrl,
            'national_id_back_path' => $nationalIdBackUrl,
            'home_address' => $request->input('home_address'),
            'date_of_birth' => $request->input('date_of_birth'),
            'pre_existing_conditions' => $request->input('pre_existing_conditions'),
        ]);
    
        return response()->json(['message' => 'User details saved successfully', 'data' => $userDetail], 201);
    }
    

    public function updateNationalID(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'front_id' => 'nullable|image|max:2048',
            'back_id' => 'nullable|image|max:2048',
        ]);
    
        if ($validator->fails()) {
            return response()->json([
                'errors' => $validator->errors()
            ], 422);
        }
    
        $userDetail = UserDetail::where('user_id', auth()->id())->first();
    
        if ($request->hasFile('front_id')) {
            if ($userDetail->national_id_front_path) {
                Storage::delete(str_replace('/storage', 'public', $userDetail->national_id_front_path));
            }
    
            $nationalIdFrontPath = $request->file('front_id')->store('public/national_ids');
            $nationalIdFrontUrl = Storage::url($nationalIdFrontPath);
            $userDetail->national_id_front_path = $nationalIdFrontUrl;
        }
    
        if ($request->hasFile('back_id')) {
            if ($userDetail->national_id_back_path) {
                Storage::delete(str_replace('/storage', 'public', $userDetail->national_id_back_path));
            }
    
            $nationalIdBackPath = $request->file('back_id')->store('public/national_ids');
            $nationalIdBackUrl = Storage::url($nationalIdBackPath);
            $userDetail->national_id_back_path = $nationalIdBackUrl;
        }
    
        $userDetail->save();
    
        return response()->json(['message' => 'National ID updated successfully', 'data' => $userDetail], 200);
    }
    
    public function updateProfilePicture(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'selfie' => 'required|image|max:2048',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $userDetail = UserDetail::where('user_id', auth()->id())->first();

        if (!$userDetail) {
            $userDetail = new UserDetail();
            $userDetail->user_id = auth()->id();
        }

        if ($request->hasFile('selfie')) {
            if ($userDetail->selfie_path) {
                Storage::delete(str_replace('/storage', 'public', $userDetail->selfie_path));
            }
            $selfiePath = $request->file('selfie')->store('public/selfies');
            $selfieUrl = Storage::url($selfiePath);
            $userDetail->selfie_path = $selfieUrl;
        }

        $userDetail->save();

        return response()->json(['message' => 'Selfie updated successfully', 'data' => $userDetail], 200);
    }

    public function checkAndNotify()
    {
        $user = Auth::user();

        $userDetails = UserDetail::where('user_id', $user->id)->first();

        if ($userDetails) {
            $notificationData = [
                'user_id' => $user->id,
                'kra_pin' => $userDetails->kra_pin ? 1 : 0,
                'selfie' => $userDetails->selfie_path ? 1 : 0,
                'id_card_front' => $userDetails->national_id_front_path ? 1 : 0,
                'id_card_back' => $userDetails->national_id_back_path ? 1 : 0,
                'home_address' => $userDetails->home_address ? 1 : 0,
                'dob' => $userDetails->date_of_birth ? 1 : 0,
                'created_at' => now(),
                'updated_at' => now(),
            ];
        } else {
            $notificationData = [
                'user_id' => $user->id,
                'kra_pin' => 0,
                'selfie' => 0,
                'id_card_front' => 0,
                'id_card_back' => 0,
                'home_address' => 0,
                'dob' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ];
        }

        $notification = Notification::where('user_id', $user->id)->first();
        if ($notification) {
            $notification->update($notificationData);
        } else {
            Notification::create($notificationData);
        }

        return response()->json(['message' => 'Notification updated successfully.']);
    }
}
