<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User; // Make sure to import your User model
use App\Models\UserCover;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;
class UserpackagesController extends Controller
{
    private $apiKey;
    private $model;

    public function __construct()
    {
        $this->apiKey = 'AIzaSyAOda9eX5eTYQFkSjBU--hAljEG7202XyY';
        $this->model = 'gemini-1.5-flash-latest';
    }


    public function index()
    {
        $userId = auth()->id();
        
        // Retrieve the user's first name from the users table
        $user = DB::table('users')->where('id', $userId)->first();
        $name = $user->first_name; // Dynamically get the first name
        
        // Retrieve additional user details from the UserCover table
        $userCover = UserCover::where('userid', $userId)->first();
        
        // Handle null case if no record found
        if (!$userCover) {
            $phoneNumber = null;
            $amountToBePaid = null;
            $packageSelected = null;
            $isPaid = null;
        } else {
            $phoneNumber = $userCover->phone;
            $amountToBePaid = $userCover->amount;
            $packageSelected = $userCover->packages;
            $isPaid = $userCover->isPaid;
        }
    
        // Pass the data to the view
        return view('homebot', compact('name', 'isPaid', 'phoneNumber', 'amountToBePaid', 'packageSelected'));
    }
    



    public function send(Request $request)
    {
        $userMessage = $request->input('message');
        $botResponse = $this->getBotResponse($userMessage);

        return response()->json(['message' => $botResponse]);
    }

    private function getBotResponse($message)
    {
        $url = "https://generativelanguage.googleapis.com/v1beta/models/{$this->model}:generateContent?key={$this->apiKey}";
    
        $chat = $this->getChatHistory();
        $chat[] = [
            'role' => 'user',
            'parts' => [['text' => $message]]
        ];
    
        $data = [
            'contents' => $chat,
            'generationConfig' => [
                'temperature' => 1,
                'topP' => 0.95,
                'topK' => 64,
                'maxOutputTokens' => 8192,
            ],
        ];
    
        $response = Http::post($url, $data);
    
        if ($response->successful()) {
            $result = $response->json();
            if (isset($result['candidates'][0]['content']['parts'][0]['text'])) {
                $botResponse = $result['candidates'][0]['content']['parts'][0]['text'];
                $chat[] = [
                    'role' => 'model',
                    'parts' => [['text' => $botResponse]]
                ];
                $this->saveChatHistory($chat);
                return $botResponse;
            }
        } else {
            // Attempt to extract and return text from the error response
            $errorText = '';
            if (isset($response->json()['candidates'][0]['content']['parts'][0]['text'])) {
                $errorText = $response->json()['candidates'][0]['content']['parts'][0]['text'];
            }
            // Optionally, you can further filter out unwanted parts of the error response here
            return "Model Output: {$errorText}";
        }
    
        return "Sorry, I didn’t understand. Please rephrase or avoid sensitive terms.";
    }
    

    private function getChatHistory()
    {
        if (!Session::has('chat_history')) {
            $initialChat = $this->initializeChat();
            Session::put('chat_history', $initialChat);
        }
        return Session::get('chat_history');
    }

    private function saveChatHistory($chat)
    {
        Session::put('chat_history', $chat);
    }

    private function initializeChat()
    {
        return [
            [
                'role' => 'user',
                'parts' => [[
                    'text' => "You are Prince, a cheerful AI assistant for Crownscope Insurance. Your goal is to handle user payment and package subscription processes efficiently. Here’s how you should proceed:

Receiving Details:

Expect to receive user details, including their name, pnumber, amount, and selected package.
If these details are not provided, respond with: (Sorry, I can't find your information.)
Handling Paid Package Details:

If the user provides details of a package that has already been paid for, inform them of their current subscription, the due date, and the remaining days. 
Ask User if they are interested to upgrade their package
If the user wants to upgrade their package, inform them that support will contact them.
Handling Unpaid Package Details:

If the user provides unpaid package details:
Include a note in your first response: (Note: You cannot change your details here. Please use the settings page for updates.)
List the details received and ask the user to confirm if everything is correct.
Clearly state that the final format will only be shown if the user confirms their details.
If the user confirms, output the details in the following format and ensure this format is strictly reserved for confirmed details only:

~pnumber:
~amount:
Under no circumstances should this format be used before the user has explicitly confirmed their details.
Keep your tone cheerful and your responses short to make the process engaging and smooth for the users. Be strict about confirming details before proceeding to output the final format."
                ]]
            ]
            
        ];
    }








}
