<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Claim;
use Illuminate\Support\Facades\Log;
class adminClaimController extends Controller
{
    /**
     * Add a new claim to the claims table.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\JsonResponse
     */
  

    public function addClaim(Request $request)
    {
        try {
            // Validate the incoming request data
            $request->validate([
                'policy' => 'required|string|max:255',
                'claimNumber' => 'required|string|max:255|unique:claims,claim_number',
                'dateFiled' => 'required|date',
                'lastUpdated' => 'required|date',
                'status' => 'required|string|in:open,closed,settled',
                'userId' => 'required|integer',// Ensure userId exists in the users table
                'customer' => 'required|string|max:255', // Validate the customer field
            ]);
            
            // Create the new claim record
            Claim::create([
                'policy'          => $request->input('policy'),
                'claim_number'    => $request->input('claimNumber'),
                'date_filed'      => $request->input('dateFiled'),
                'last_updated'    => $request->input('lastUpdated'),
                'status'          => $request->input('status'),
                'user_id'         => $request->input('userId'),
                //'user_id'         => 1000,             // Hardcoded user ID
                'amount'          => 1000,             // Hardcoded amount
                'conversation_id' => 12,
                'customer'        => $request->input('customer'), // Include the customer field
            ]);
            
    
            return response()->json(['success' => true, 'message' => 'Claim added successfully']);
        } catch (\Exception $e) {
            // Log the full error message and stack trace
            Log::error('Error while adding claim: ' . $e->getMessage(), [
                'trace' => $e->getTraceAsString(),
                'request_data' => $request->all(),
            ]);
    
            // Return a generic error response to the user
            return response()->json([
                'success' => false,
                'message' => 'An error occurred while adding the claim. Please check the inputs and try again.',
            ], 500);
        }
    }
    
    
    /**
     * Export selected claims as a CSV file.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function exportClaims(Request $request)
    {
        try {
            $ids = $request->input('ids');

            if (empty($ids)) {
                return response()->json([
                    'success' => false,
                    'message' => 'No claims selected for export.'
                ], 400);
            }

            // Fetch selected claims
            $claims = Claim::whereIn('id', $ids)->get();

            // Prepare CSV header
            $csvData = "Policy,Claim Number,Date Filed,Last Updated,Status,Customer\n";

            // Add claim data to CSV
            foreach ($claims as $claim) {
                $csvData .= sprintf(
                    "%s,%s,%s,%s,%s,%s\n",
                    $claim->policy,
                    $claim->claim_number,
                    $claim->date_filed->format('d F Y'),
                    $claim->last_updated->format('d F Y'),
                    $claim->status,
                    $claim->customer
                );
            }

            // Define the file name
            $filename = "claims_" . now()->format('Ymd_His') . ".csv";

            // Return CSV as a download response
            return response($csvData, 200, [
                'Content-Type' => 'text/csv',
                'Content-Disposition' => "attachment; filename=$filename",
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'An error occurred while exporting claims.'
            ], 500);
        }
    }

    /**
     * Delete selected claims from the database.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function deleteClaims(Request $request)
    {
        try {
            $ids = $request->input('ids');

            if (empty($ids)) {
                return response()->json([
                    'success' => false,
                    'message' => 'No claims selected for deletion.'
                ], 400);
            }

            // Delete claims based on selected IDs
            Claim::whereIn('id', $ids)->delete();

            return response()->json([
                'success' => true,
                'message' => 'Selected claims deleted successfully.'
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'An error occurred while deleting claims.'
            ], 500);
        }
    }


    public function importClaims(Request $request)
{
    // Validate the uploaded file
    $request->validate([
        'file' => 'required|mimes:csv,txt|max:2048',
    ]);

    $file = $request->file('file');
    $fileData = array_map('str_getcsv', file($file->getRealPath()));

    // Process each row (skip header row)
    foreach ($fileData as $index => $row) {
        if ($index === 0) continue; // Skip header row

        // Ensure a conversation record exists with id 1000
    

        // Create or update claims based on the claim number (assumed to be unique)
        Claim::updateOrCreate(
            ['claim_number' => $row[1]], // Assuming the claim number is in the second column
            [
                'policy'       => $row[0] ?? null,  // Policy in the first column
                'claim_number' => $row[1] ?? null,  // Claim number in the second column
                'date_filed'   => $row[2] ?? null,  // Date filed in the third column
                'last_updated' => $row[3] ?? null,  // Last updated date in the fourth column
                'status'       => $row[4] ?? null,  // Status in the fifth column
                'customer'     => $row[5] ?? null,  // Customer name in the sixth column
                'user_id'         => 1000,             // Hardcoded user ID
                'amount'          => 1000,             // Hardcoded amount
                'conversation_id' => 12,             // Hardcoded conversation ID

            ]
        );
    }

    return redirect()->back()->with('success', 'Claims imported successfully.');
}

}
