<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\UserDetail;
use App\Models\User; // Import the User model
use App\Models\RentersDetail;

class PayRentersController extends Controller
{
    public function index()
    {
        // Fetch the details for the authenticated user
        $userId = auth()->id();
        $userDetails = UserDetail::where('user_id', $userId)->first();
        $user = User::find($userId); // Fetch user to get the phone number
        $rentersDetails = RentersDetail::where('user_id', $userId)->first();

        // Decode the double-escaped JSON string
        $familyDetails = $this->decodeDoubleEscapedJson($rentersDetails->family_details);

        // Function to format the phone number
        $formattedPhoneNumber = $this->formatPhoneNumber($user->phone ?? '');

        // Pass the details to the view
        return view('user.paymentrenters', [
            'homeAddress' => $userDetails->home_address ?? null,
            'phoneNumber' => $formattedPhoneNumber,
            'rent' => $rentersDetails,
            'familyDetails' => $familyDetails // Pass decoded family details to view
        ]);
    }

    /**
     * Decode a double-escaped JSON string.
     *
     * @param string $jsonString
     * @return array
     */
    private function decodeDoubleEscapedJson($jsonString)
    {
        // First decode the double-escaped JSON
        $decodedString = stripslashes($jsonString);
        // Then decode the actual JSON
        return json_decode($decodedString, true) ?? [];
    }

    /**
     * Format phone number from international to local format.
     *
     * @param string $phoneNumber
     * @return string
     */
    private function formatPhoneNumber($phoneNumber)
    {
        // Remove any non-numeric characters (except leading +)
        $cleanedNumber = preg_replace('/[^\d]/', '', $phoneNumber);

        // Remove the international dialing code if present (e.g., +254)
        if (substr($cleanedNumber, 0, 1) == '0') {
            // Phone number is already in local format
            return $cleanedNumber;
        } elseif (substr($cleanedNumber, 0, 3) == '254') {
            // Remove country code (254) for local format
            return '0' . substr($cleanedNumber, 3);
        }

        // Return the cleaned number if no special formatting is required
        return $cleanedNumber;
    }
}
