<?php

namespace App\Http\Controllers;

use App\Models\RentersDetail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\UserDetail;
use Carbon\Carbon;
use Illuminate\Support\Facades\Storage;
class princecoverController extends Controller
{
    public function index()
    {
        // Fetch the authenticated user
        $user = auth()->user();
    
        // Fetch the user's details
        $userDetail = UserDetail::where('user_id', $user->id)->first();
    
        // Check if the selfie path exists
        $selfiePath = $userDetail ? $userDetail->selfie_path : null;
        $selfieExists = $selfiePath ? Storage::disk('public')->exists(str_replace('/storage/', '', $selfiePath)) : false;
    
        // Extract latitude and longitude from home_address
        $latitude = null;
        $longitude = null;
        if ($userDetail && $userDetail->home_address) {
            preg_match('/Latitude:\s*(-?\d+\.\d+),\s*Longitude:\s*(-?\d+\.\d+)/', $userDetail->home_address, $matches);
            if (isset($matches[1]) && isset($matches[2])) {
                $latitude = $matches[1];
                $longitude = $matches[2];
            }
        }
    
        return view('user.princecover', compact('user', 'selfiePath', 'selfieExists', 'latitude', 'longitude'));
    }
    


    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'ownership_status' => 'nullable|string',
            'cohabitants' => 'nullable|string',
            'family_details' => [
                'nullable',
                function ($attribute, $value, $fail) {
                    if ($value && is_string($value)) {
                        json_decode($value);
                        if (json_last_error() !== JSON_ERROR_NONE) {
                            $fail($attribute.' is not a valid JSON string.');
                        }
                    }
                }
            ],
            'valuables' => 'nullable|string',
            //'building_type' => 'nullable',
        ]);
    
        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'errors' => $validator->errors(),
            ], 422);
        }
    
        $validatedData = $validator->validated();
    
        // Ensure family_details is a JSON string
        if (isset($validatedData['family_details']) && is_array($validatedData['family_details'])) {
            $validatedData['family_details'] = json_encode($validatedData['family_details']);
        }
    
        // Create a new RentersDetail record
    $rentersDetail = RentersDetail::create([
        'user_id' => auth()->id(),
        'activity' => 1,
        'cover_type' => 'Renters',
        'status' => 'Active',
        'expiry_date' => Carbon::now()->addDays(30)->format('Y-m-d'),
        'autorenew' => 0,
        'ownership_status' => $request->input('ownership_status'),
        'cohabitants' => $request->input('cohabitants'),
        'family_details' => isset($validatedData['family_details']) ? json_encode($request->input('family_details')) : null,
        'valuables' => $request->input('valuables'),
        // 'building_type' => $request->input('building_type'), // Uncomment if you need this field
    ]);

    // Return a JSON response
    return response()->json([
        'message' => 'Renters details saved successfully',
        'data' => $rentersDetail,
    ], 201);
}}