<?php

namespace App\Http\ViewComposers; // Ensure this is the correct namespace for your application structure

use Illuminate\View\View;  // Required to type-hint the View class in the compose method
use Illuminate\Support\Facades\Cache;  // Required for using the Cache facade
use App\Models\Claim;  // Assuming your Claim model is located in the App\Models namespace

class NotificationComposer
{
    public function compose(View $view)
    {
        $latestClaims = Cache::remember('latestClaims', 60, function () {
            return Claim::latest()->take(20)->get();
        });
    
        $pendingClaims = Cache::remember('pendingClaims', 60, function () {
            return Claim::where('status', 'pending')->get();
        });
    
        $claimsPendingSummary = $pendingClaims->groupBy('policy')->map->count();
    
        // Calculate the total notification count (example below)
        $notificationCount = $latestClaims->count() + $pendingClaims->count(); // adjust this logic as needed
    
        $view->with('latestClaims', $latestClaims)
             ->with('claimsPendingSummary', $claimsPendingSummary)
             ->with('notificationCount', $notificationCount); // Pass this count to your view
    }
    
}
