<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\Activitylog\Traits\LogsActivity;
use Spatie\Activitylog\LogOptions;

class RentersDetail extends Model
{
    use HasFactory, LogsActivity;

    protected $table = 'renters_details';

    // Mass-assignable attributes
    protected $fillable = [
        'user_id',
        'activity',
        'cover_type',
        'status',
        'expiry_date',
        'autorenew',
        'ownership_status',
        'cohabitants',
        'family_details',
        'valuables',
        'building_type',
    ];

    // Cast attributes to native types
    protected $casts = [
        'family_details' => 'array', // Cast JSON to array
        'expiry_date' => 'date',     // Cast to date
        'autorenew' => 'boolean',    // Cast to boolean
    ];

    public function getActivitylogOptions(): LogOptions
    {
        return LogOptions::defaults()
            ->logOnly([
                'user_id',
                'activity',
                'cover_type',
                'status',
                'expiry_date',
                'autorenew',
                'ownership_status',
                'cohabitants',
                'family_details',
                'valuables',
                'building_type',
            ])
            ->logOnlyDirty()
            ->dontSubmitEmptyLogs();
    }

    // Define the relationship with the User model
    public function user()
    {
        return $this->belongsTo(User::class, 'user_id', 'id');
    }
}
