<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use App\Models\User;
use App\Models\GolfersDetail;
use Illuminate\Support\Facades\Storage;
class PaymentConfirmationNotification extends Notification
{
    use Queueable;

    protected $user;
    protected $golfersDetail;

    /**
     * Create a new notification instance.
     */
    public function __construct(User $user)
    {
        $this->user = $user;
        $this->golfersDetail = GolfersDetail::where('user_id', $user->id)->firstOrFail();
    }

    /**
     * Get the notification's delivery channels.
     *
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }

    /**
     * Get the mail representation of the notification.
     */
    public function toMail(object $notifiable): MailMessage
    {
        $mailData = [
            'first_name' => $this->user->first_name,
            'email' => $this->user->email,
            'policy' => $this->golfersDetail->cover_type,
            'package' => $this->golfersDetail->package,
            'filename' => $this->golfersDetail->filename,
            'premium' => $this->golfersDetail->premium . ' shillings',
            'policy_number' => $this->golfersDetail->id,
        ];
// Get the filename from the GolfersDetail model
$filePath = 'public/receipts/' . $this->golfersDetail->filename;
        return (new MailMessage)
            ->subject('Payment Confirmation')
            ->view('emails.payment_confirmation', ['data' => $mailData])
            ->attach(Storage::path($filePath), [
                'as' => 'Payment_Receipt.pdf', // You can change the 'as' value or use the filename from the model
                'mime' => 'application/pdf',
            ]);
    }

    /**
     * Get the array representation of the notification.
     *
     * @return array<string, mixed>
     */
    public function toArray(object $notifiable): array
    {
        return [];
    }
}
