"use client";

import { VoiceProvider } from "@humeai/voice-react";
import Messages from "./Messages";
import Controls from "./Controls";
import StartCall from "./StartCall";
import { useRef } from "react";

export default function ClientComponent({
  accessToken,
  configId,
}: {
  accessToken: string;
  configId?: string;
}) {
  const timeout = useRef<number | null>(null);
  const ref = useRef<HTMLDivElement | null>(null);

  return (
    <div className="relative grow flex flex-col mx-auto w-full overflow-hidden h-[0px]">
      <VoiceProvider
        auth={{ type: "accessToken", value: accessToken }}
        configId={configId}
        onMessage={() => {
          if (timeout.current) {
            window.clearTimeout(timeout.current);
          }

          timeout.current = window.setTimeout(() => {
            if (ref.current) {
              const scrollHeight = ref.current.scrollHeight;

              ref.current.scrollTo({
                top: scrollHeight,
                behavior: "smooth",
              });
            }
          }, 200);
        }}
      >
        <Messages /> {/* The ref is now correctly handled */}
        
        <StartCall />
      </VoiceProvider>
    </div>
  );
}
