"use client";
import { useState, useEffect, forwardRef } from 'react';
import { useVoice } from "@humeai/voice-react";
import { motion, AnimatePresence } from "framer-motion";
import { Phone, Mic, MicOff } from "lucide-react";
import { Toggle } from "./ui/toggle";
import MicFFT from "./MicFFT";
import { cn } from "@/utils";
import React from 'react';

const IOSCallInterface = () => {
  const { disconnect, status, isMuted, unmute, mute, micFft } = useVoice();
  const [callDuration, setCallDuration] = useState(0);

  useEffect(() => {
    const timer = setInterval(() => {
      setCallDuration((prev) => prev + 1);
    }, 1000);
    return () => clearInterval(timer);
  }, []);

  const formatTime = (seconds: number) => {
    const mins = Math.floor(seconds / 60);
    const secs = seconds % 60;
    return `${mins}:${secs.toString().padStart(2, '0')}`;
  };

  return (
    <div className="relative mx-auto bg-black text-white h-full w-full flex flex-col justify-between items-center p-6">
      {/* Top section */}
      <div className="text-center mt-8">
        <h2 className="text-2xl font-semibold mb-2">Prince</h2>
        <p className="text-lg opacity-75">{formatTime(callDuration)}</p>
      </div>

      {/* Middle section */}
      <div className="flex justify-center items-center">
        <div className="w-32 h-32 bg-gray-700 rounded-full flex items-center justify-center">
          <span className="text-4xl">PC</span>
        </div>
      </div>

      {/* Bottom section */}
      <AnimatePresence>
        {status.value === "connected" && (
          <motion.div
            initial={{ y: "100%", opacity: 0 }}
            animate={{ y: 0, opacity: 1 }}
            exit={{ y: "100%", opacity: 0 }}
            className="p-4 bg-gray-800 rounded-lg shadow-sm flex flex-col items-center gap-4 w-full max-w-md"
          >
            <div className="flex justify-around w-full mb-4">
              <Toggle
                pressed={!isMuted}
                onPressedChange={() => {
                  if (isMuted) {
                    unmute();
                  } else {
                    mute();
                  }
                }}
                className="bg-gray-600 rounded-full p-4"
              >
                {isMuted ? <MicOff size={24} /> : <Mic size={24} />}
              </Toggle>

              <div className="relative grid h-12 w-48 shrink grow-0">
                <MicFFT fft={micFft} className="fill-current" />
              </div>
            </div>

            <button
              className="w-full bg-red-500 text-white py-3 rounded-full flex items-center justify-center"
              onClick={() => disconnect()}
            >
              <Phone size={24} />
              <span className="ml-2">End Call</span>
            </button>
          </motion.div>
        )}
      </AnimatePresence>
    </div>
  );
};

const PhoneFrameCallInterface = () => {
  return (
    <div className="relative mx-auto border-gray-800 dark:border-gray-800 bg-gray-800 border-[14px] rounded-[2.5rem] h-screen max-h-screen w-full max-w-full">
      <div className="h-[32px] w-[3px] bg-gray-800 dark:bg-gray-800 absolute -left-[17px] top-[72px] rounded-l-lg"></div>
      <div className="h-[46px] w-[3px] bg-gray-800 dark:bg-gray-800 absolute -left-[17px] top-[124px] rounded-l-lg"></div>
      <div className="h-[46px] w-[3px] bg-gray-800 dark:bg-gray-800 absolute -left-[17px] top-[178px] rounded-l-lg"></div>
      <div className="h-[64px] w-[3px] bg-gray-800 dark:bg-gray-800 absolute -right-[17px] top-[142px] rounded-r-lg"></div>
      <div className="rounded-[2rem] overflow-hidden w-full h-full bg-white dark:bg-gray-800">
        <div className="absolute top-0 inset-x-0">
          <div className="h-6 w-40 bg-black dark:bg-gray-800 mx-auto rounded-b-[1rem]"></div>
        </div>
        <IOSCallInterface />
      </div>
    </div>
  );
};

const Messages = forwardRef<HTMLDivElement, React.HTMLProps<HTMLDivElement>>((props, ref) => {
  return (
    <div ref={ref} {...props}>
      {/* Your Messages component content */}
    </div>
  );
});

export default PhoneFrameCallInterface;
export { Messages };
