const video = document.getElementById('video');
const capturedImageContainer = document.getElementById('capturedImageContainer');

Promise.all([
  faceapi.nets.tinyFaceDetector.loadFromUri('/models'),
  faceapi.nets.faceLandmark68Net.loadFromUri('/models'),
  faceapi.nets.faceRecognitionNet.loadFromUri('/models'),
  faceapi.nets.faceExpressionNet.loadFromUri('/models')
]).then(startVideo);

function startVideo() {
  navigator.getUserMedia(
    { video: {} },
    stream => video.srcObject = stream,
    err => console.error(err)
  );
}

video.addEventListener('play', () => {
  const canvas = faceapi.createCanvasFromMedia(video);
  document.body.append(canvas);
  const displaySize = { width: video.width, height: video.height };
  faceapi.matchDimensions(canvas, displaySize);

  const captureButton = document.createElement('button');
  captureButton.id = 'captureButton';
  captureButton.textContent = 'Capture Image';
  captureButton.style.display = 'none';
  document.body.appendChild(captureButton);

  setInterval(async () => {
    try {
      const detections = await faceapi.detectAllFaces(video, new faceapi.TinyFaceDetectorOptions()).withFaceLandmarks().withFaceExpressions();
      const resizedDetections = faceapi.resizeResults(detections, displaySize);
      canvas.getContext('2d').clearRect(0, 0, canvas.width, canvas.height);
      faceapi.draw.drawDetections(canvas, resizedDetections);
      faceapi.draw.drawFaceLandmarks(canvas, resizedDetections);
      faceapi.draw.drawFaceExpressions(canvas, resizedDetections);

      if (resizedDetections.length > 0) {
        const accuracy = resizedDetections[0].detection.score;
        if (accuracy > 0.9) {
          captureButton.style.display = 'block';
        } else {
          captureButton.style.display = 'none';
        }
      } else {
        captureButton.style.display = 'none';
      }
    } catch (error) {
      console.error('Error in face detection:', error);
    }
  }, 100);

  captureButton.addEventListener('click', () => {
    try {
      const canvas = document.createElement('canvas');
      canvas.width = video.width;
      canvas.height = video.height;
      canvas.getContext('2d').drawImage(video, 0, 0, canvas.width, canvas.height);
      const capturedImage = canvas.toDataURL('image/jpeg');
      const img = document.createElement('img');
      img.id = 'capturedImage';
      img.src = capturedImage;
      capturedImageContainer.innerHTML = '';
      capturedImageContainer.appendChild(img);
    } catch (error) {
      console.error('Error in capturing image:', error);
    }
  });
});