

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <title>Golf Insurance Claims Chatbot</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Lato:wght@400&family=Open+Sans:wght@700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Lato', sans-serif;
        }
        .title {
            font-family: 'Open Sans', sans-serif;
            font-size: 24px;
        }
        .chat-container {
            width: 400px;
            height: 600px;
            background-color: #f0f4f8;
            border-radius: 20px;
            box-shadow: 0 10px 25px rgba(0,0,0,0.1);
            padding: 16px;
            display: flex;
            flex-direction: column;
        }
        .chat-box {
            height: calc(100% - 150px);
            overflow-y: auto;
            scrollbar-width: thin;
            scrollbar-color: #cbd5e0 #f0f4f8;
            background-color: #fff;
            border-radius: 8px;
            padding: 16px;
            margin-bottom: 16px;
        }
        .chat-box::-webkit-scrollbar {
            width: 8px;
        }
        .chat-box::-webkit-scrollbar-track {
            background: #f0f4f8;
        }
        .chat-box::-webkit-scrollbar-thumb {
            background-color: #cbd5e0;
            border-radius: 20px;
        }
        .bot-message, .user-message {
            max-width: 80%;
            padding: 12px 16px;
            border-radius: 18px;
            margin-bottom: 10px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.05);
        }
        .bot-message {
            background-color: #ffffff;
            border-bottom-left-radius: 4px;
        }
        .user-message {
            background-color: #AB1F74;
            color: white;
            border-bottom-right-radius: 4px;
            margin-left: auto;
        }
        .file-input {
            display: none;
        }
        .file-label {
            cursor: pointer;
        }
        #fileName {
            max-width: 150px;
            overflow: hidden;
            text-overflow: ellipsis;
            white-space: nowrap;
        }
        .typing-indicator {
            background-color: #e2e8f0;
            will-change: transform;
            width: auto;
            border-radius: 50px;
            padding: 10px;
            display: table;
            margin: 0 auto;
            position: relative;
            animation: 2s bulge infinite ease-out;
        }
        .typing-indicator::before,
        .typing-indicator::after {
            content: '';
            position: absolute;
            bottom: -2px;
            left: -2px;
            height: 20px;
            width: 20px;
            border-radius: 50%;
            background-color: #e2e8f0;
        }
        .typing-indicator::after {
            height: 10px;
            width: 10px;
            left: -10px;
            bottom: -10px;
        }
        .typing-indicator span {
            height: 15px;
            width: 15px;
            float: left;
            margin: 0 1px;
            background-color: #9879ff;
            display: block;
            border-radius: 50%;
            opacity: 0.4;
        }
        .typing-indicator span:nth-of-type(1) {
            animation: 1s blink infinite 0.3333s;
        }
        .typing-indicator span:nth-of-type(2) {
            animation: 1s blink infinite 0.6666s;
        }
        .typing-indicator span:nth-of-type(3) {
            animation: 1s blink infinite 0.9999s;
        }
        @keyframes blink {
            50% {
                opacity: 1;
            }
        }
        @keyframes bulge {
            50% {
                transform: scale(1.05);
            }
        }
    </style>
</head>
<body class="bg-gray-100 flex items-center justify-center min-h-screen p-4">
    <div class="chat-container">
        <h2 class="title text-center text-gray-800 mb-4">Golf Insurance Claims</h2>
        <div class="chat-box" id="chat-box"></div>
        <form id="chatForm" class="flex items-center space-x-2 mt-2">
            <label for="fileInput" class="file-label bg-gray-200 text-gray-600 px-3 py-2 rounded-full hover:bg-gray-300 transition duration-300">
                <i class="fas fa-plus"></i>
            </label>
            <input type="file" id="fileInput" name="file" class="file-input" accept="image/*">
            <span id="fileName" class="text-sm text-gray-600"></span>
            <input type="text" id="userMessage" class="flex-grow px-4 py-2 rounded-full border border-gray-300 focus:outline-none focus:ring-2 focus:ring-blue-500" placeholder="Type a message...">
            <button type="submit" id="sendButton" class="bg-blue-500 text-white px-6 py-2 rounded-full hover:bg-blue-600 transition duration-300">Send</button>
        </form>
    </div>

    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script>
  $(document).ready(function() {
    // Ensure CSRF token is set for all AJAX requests
    $.ajaxSetup({
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        }
    });

    // Initial greeting
    $('#chat-box').append('<div class="bot-message">Hello  this is prince your personalized ai assistant</div>');

    // Extract and clear package details from the URL
    const urlParams = new URLSearchParams(window.location.search);
    const packageName = urlParams.get('package');
    const price = urlParams.get('price');
    
    // Send package details to chatbot if available
    if (packageName && price) {
        const message = `Selected package: ${packageName} at price  ${price}`;
        sendMessage(message);
        
        // Clear URL parameters
        urlParams.delete('package');
        urlParams.delete('price');
        window.history.replaceState({}, document.title, window.location.pathname);
    }

    $('#chatForm').submit(function(e) {
        e.preventDefault();
        sendMessage();
    });

    $('#userMessage').on('keypress', function(e) {
        if (e.which == 13) {
            e.preventDefault();
            sendMessage();
        }
    });

    $('#fileInput').change(function(e) {
        const fileName = e.target.files[0].name;
        $('#fileName').text(fileName);
        $('#userMessage').prop('disabled', true).attr('placeholder', 'File selected for upload');
    });

    function sendMessage(message) {
        if (typeof message === 'undefined') {
            message = $('#userMessage').val().trim();
        }
        var file = $('#fileInput')[0].files[0];

        if (!message && !file) return;

        if (file) {
            uploadFile(file, message);
        } else {
            sendTextMessage(message);
        }

        $('#userMessage').val('');
        $('#fileInput').val('');
        $('#fileName').text('');
        $('#userMessage').prop('disabled', false).attr('placeholder', 'Type a message...');
    }

    function sendTextMessage(message) {
        $('#chat-box').append('<div class="user-message">' + message + '</div>');
        scrollChatToBottom();
        showTypingIndicator();

        $.ajax({
            url: '{{ route("chatbot.send") }}',
            method: 'POST',
            data: {
                message: message
            },
            success: function(response) {
                console.log("Response received: ", response);
                hideTypingIndicator();
                $('#chat-box').append('<div class="bot-message">' + response.message + '</div>');
                checkForPrince(response.message);
                if (response.options) {
                    response.options.forEach(option => {
                        $('#chat-box').append('<button class="bg-blue-100 text-blue-800 px-2 py-1 rounded-full text-sm mr-2 mb-2 option-button">' + option + '</button>');
                    });
                }
                scrollChatToBottom();
            },
            error: function() {
                hideTypingIndicator();
                $('#chat-box').append('<div class="bot-message">Sorry, there was an error processing your request.</div>');
                scrollChatToBottom();
            }
        });
    }

    function uploadFile(file, message) {
        var formData = new FormData();
        formData.append('file', file);
        formData.append('message', message);

        showTypingIndicator();

        $.ajax({
            url: '{{ route("chatbot.upload") }}',
            method: 'POST',
            data: formData,
            contentType: false,
            processData: false,
            success: function(response) {
                console.log("File upload response: ", response);
                hideTypingIndicator();
                $('#chat-box').append('<img src="' + response.uploaded_image_url + '" class="max-w-full h-auto rounded-lg shadow-md mb-2" alt="Uploaded Image">');
                $('#chat-box').append('<div class="bot-message">' + response.message + '</div>');
                checkForPrince(response.message);
                scrollChatToBottom();
            },
            error: function(xhr, status, error) {
                hideTypingIndicator();
                console.error('Error uploading file:', xhr.responseJSON);
                let errorMessage = xhr.responseJSON?.error || 'Sorry, there was an error uploading your file.';
                $('#chat-box').append('<div class="bot-message">' + errorMessage + '</div>');
                scrollChatToBottom();
            }
        });
    }

    function checkForPrince(message) {
    console.log("Checking message for details: ", message);

    // Define regex patterns for each field
    const firstNameRegex = /~\s*first_name:\s*([^~\n]+)/i;
    const middleNameRegex = /~\s*middle_name:\s*([^~\n]*)/i; // Middle name is nullable
    const lastNameRegex = /~\s*last_name:\s*([^~\n]+)/i;
    const emailRegex = /~\s*email:\s*([^~\n]+)/i;
    const passwordRegex = /~\s*pword:\s*([^~\n]+)/i;
    const kraPinRegex = /~\s*kra_pin:\s*([^~\n]+)/i;
    const phoneRegex = /~\s*phone:\s*([^~\n]+)/i;
    const dobRegex = /~\s*dob:\s*([^~\n]+)/i;
    const packageRegex = /~\s*package:\s*([^~\n]+)/i;
    const amountRegex = /~\s*amount:\s*([^~\n]+)/i;

    // Initialize variables to hold extracted values
    let firstName = '';
    let middleName = '';
    let lastName = '';
    let email = '';
    let password = '';
    let kraPin = '';
    let phone = '';
    let dob = '';
    let packageName = '';
    let amount = '';

    // Extract values using regex
    const firstNameMatch = message.match(firstNameRegex);
    const middleNameMatch = message.match(middleNameRegex);
    const lastNameMatch = message.match(lastNameRegex);
    const emailMatch = message.match(emailRegex);
    const passwordMatch = message.match(passwordRegex);
    const kraPinMatch = message.match(kraPinRegex);
    const phoneMatch = message.match(phoneRegex);
    const dobMatch = message.match(dobRegex);
    const packageMatch = message.match(packageRegex);
    const amountMatch = message.match(amountRegex);

    if (firstNameMatch) firstName = firstNameMatch[1].trim();
    if (middleNameMatch) middleName = middleNameMatch[1].trim();
    if (lastNameMatch) lastName = lastNameMatch[1].trim();
    if (emailMatch) email = emailMatch[1].trim();
    if (passwordMatch) password = passwordMatch[1].trim();
    if (kraPinMatch) kraPin = kraPinMatch[1].trim();
    if (phoneMatch) phone = phoneMatch[1].trim();
    if (dobMatch) dob = dobMatch[1].trim();
    if (packageMatch) packageName = packageMatch[1].trim();
    if (amountMatch) amount = amountMatch[1].trim();

    console.log("Extracted details:", {
        firstName, middleName, lastName, email, password, kraPin, phone, dob, packageName, amount
    });

    // Validate extracted details
    if (firstName && lastName && email && password && kraPin && phone && dob && packageName && amount) {
        $.ajax({
            url: '/register',
            method: 'POST',
            data: {
                first_name: firstName,
                middle_name: middleName,
                last_name: lastName,
                email: email,
                password: password,
                kra_pin: kraPin,
                phone: phone,
                dob: dob,
                package: packageName,
                amount: amount
            },
            success: function(response) {
                console.log("User registered successfully: ", response);
                $('#chat-box').append(`<div class="bot-message">User registered successfully: ${response.message}</div>`);
                // Redirect to /dashboard
                window.location.href = '/userdetails';
            },
            error: function(xhr) {
                console.error("Error registering user: ", xhr);
                let errorMessage = xhr.responseJSON?.errors ? JSON.stringify(xhr.responseJSON.errors) : 'An error occurred while registering the user';
                $('#chat-box').append(`<div class="bot-message">Error: ${errorMessage}</div>`);
            }
        });
    } else {
        console.log("Insufficient details to register user");
    }
}

    function scrollChatToBottom() {
        $('#chat-box').scrollTop($('#chat-box')[0].scrollHeight);
    }

    function showTypingIndicator() {
        $('#chat-box').append('<div class="typing-indicator"><span></span><span></span><span></span></div>');
        scrollChatToBottom();
    }

    function hideTypingIndicator() {
        $('.typing-indicator').remove();
    }

    $(document).on('click', '.option-button', function() {
        var option = $(this).text();
        $('#userMessage').val(option);
        sendMessage();
        $(this).remove();
    });
});

    </script>
</body>
</html>



