
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Chat Interface</title>
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css">
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.7.1/dist/leaflet.css" />
    <script src="https://unpkg.com/leaflet@1.7.1/dist/leaflet.js"></script>
    <link rel="stylesheet" href="https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.css" />
    <script src="https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.js"></script>
    <style>
        body {
            font-family: 'Open Sans', sans-serif;
            background-color: #ffffff;
            display: flex;
            flex-direction: column;
            height: 100vh;
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            align-items: center;
            justify-content: center;
        }

        .header {
            height: 101px;
            background-color: white;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            padding: 0 20px;
            box-sizing: border-box;
            position: sticky;
            top: 0;
            z-index: 2;
        }

        .header .logo {
            display: flex;
            align-items: center;
            justify-content: center;
            background-color: white;
        }

        .header .logo img {
            width: 100px;
            height: 100px;
            margin-right: 5px;
        }

        .chat-content {
            flex-grow: 1;
            overflow-y: auto;
            padding: 20px;
            box-sizing: border-box;
            padding-bottom: 80px;
        }

        .profile {
            display: flex;
            flex-direction: column;
            align-items: center;
            margin-top: 20px;
            box-sizing: border-box;
        }

        .profile img {
            width: 100px;
            height: 100px;
            border-radius: 50%;
        }

        .profile-name {
            font-weight: bold;
            margin-top: 10px;
        }

        .profile-title {
            color: #888;
            font-size: 14px;
        }

        .chat-messages {
            margin-top: 20px;
        }

        .message {
            display: flex;
            margin-bottom: 20px;
        }

        .message img {
            width: 50px;
            height: 50px;
            border-radius: 50%;
            margin-right: 10px;
        }

        .message-content {
            background-color: #f0f0f0;
            border-radius: 18px;
            padding: 10px 15px;
            max-width: 70%;
            font-size: 14px;
            font-family: 'Open Sans', sans-serif;
        }

        .message.bot-message {
            justify-content: flex-start;
        }

        .message.bot-message .message-content {
            background-color: #e4e2dd;
        }

        .message.user-message {
            justify-content: flex-end;
        }

        .message.user-message .message-content {
            background-color: #e6d0de;
        }

        .message.user-message img {
            order: 2;
            margin-right: 0;
            margin-left: 10px;
        }

        .chat-input {
            position: fixed;
            bottom: 0;
            left: 0;
            width: 100%;
            height: 60px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 0 10px;
            background-color: #d9d9d9;
            box-sizing: border-box;
            z-index: 1000;
            border-radius: 20px; /* Adjust this value to control the roundness */
        }

        .chat-input button {
            background: none;
            border: none;
            font-size: 24px;
            color: #FF69B4;
            cursor: pointer;
            padding: 0;
            margin: 0 5px;
        }

        .chat-input .bi-upload {
            color: #FF69B4;
        }

        .chat-input .bi-camera {
            color: #FF69B4;
        }

        .chat-input .bi-mic {
            color: #FF69B4;
        }

        .chat-input .bi-send {
            color: #FF69B4;
        }

        .chat-input input {
            flex-grow: 1;
            border: none;
            padding: 0 10px;
            height: 30px;
            border-radius: 15px;
            margin: 0 5px;
        }

        .chat-input input:focus {
            outline: none;
        }

        .continue-cancel-buttons,
        .yes-no-buttons,
        .response-buttons,
        .restart-button {
            display: flex;
            justify-content: left;
            margin-left: 10px;
            margin-top: 10px;
        }

        .continue-cancel-buttons button,
        .yes-no-buttons button,
        .response-buttons button,
        .restart-button button {
            background-color: rgba(255, 105, 180, 0.3);
            color: #202124;
            border: none;
            padding: 8px 16px;
            border-radius: 10px;
            cursor: pointer;
            font-family: Arial, sans-serif;
            font-size: 12px;
            transition: background-color 0.3s;
        }

        .date-picker {
            display: flex;
            justify-content: center;
            margin-top: 10px;
        }

        .date-picker input[type="date"] {
            padding: 5px;
            border-radius: 5px;
            border: 1px solid #ccc;
        }

        @media (max-width: 768px) {
            .phone-frame {
                width: calc(100% - 20px);
                height: calc(100% - 20px);
                border-radius: 20px;
            }
            .chat-input {
                padding: 0 5px;
            }
            .chat-input button {
                font-size: 20px;
            }
            .chat-input input {
                height: 25px;
                font-size: 14px;
            }
        }

        @media (min-width: 1024px) {
            .phone-frame {
                width: 60%;
                margin: 0 auto;
            }
            .chat-input {
                width: 60%;
                left: 20%;
            }

            .chat-content {
                padding-bottom: 70px;
            }
        }
        .typing-indicator {
                display: flex;
                align-items: center;
            }

            .typing-image {
                width: 50px; /* Match the width of other profile images */
                height: 50px; /* Match the height of other profile images */
                border-radius: 50%; /* Ensure it's circular like other profile images */
                margin-right: 10px; /* Spacing between image and dots */
            }

        .loading {
            display: flex;
            align-items: center;
            margin-bottom: 20px;
        }

        .loading img {
            width: 30px;
            height: 40px;
            border-radius: 50%;
            margin-right: 10px;
        }

        .loading-dots {
            display: flex;
        }

        .loading-dot {
            width: 25px;
            height: 25px;
            border-radius: 50%;
            background-color: #000;
            margin-right: 4px;
            animation: pulse 1.5s infinite;
        }

        .loading-dot:nth-child(2) {
            animation-delay: 0.5s;
        }

        .loading-dot:nth-child(3) {
            animation-delay: 1s;
        }

        @keyframes pulse {
            0% { opacity: 0.3; }
            50% { opacity: 1; }
            100% { opacity: 0.3; }
        }

        #map-container {
            width: 100%;
            height: 250px;
            max-width: 350px;
            margin: 10px auto;
            display: none;
        }

        #map {
            width: 100%;
            height: 100%;
            border-radius: 10px;
            border: 2px solid #ccc;
        }

        .confirm-button {
            margin-top: 10px;
            text-align: center;
        }

        .confirm-button button {
            background-color: rgba(255, 105, 180, 0.3);
            color: #202124;
            border: none;
            padding: 8px 16px;
            border-radius: 10px;
            cursor: pointer;
            font-family: Arial, sans-serif;
            font-size: 12px;
            transition: background-color 0.3s;
        }

        .confirm-button button:hover {
            background-color: rgba(255, 105, 180, 0.5);
        }

        #fileInput {
            display: none;
        }
        .header {
    position: relative; /* Ensure the child elements are positioned relative to this */
}

.close-icon {
    position: absolute;
    top: 0px; /* Adjust as needed */
    right: -15px; /* Adjust as needed */
    font-size: 37px;
    color: #AB1F74; /* Adjust color as needed */
    text-decoration: none;
    cursor: pointer;
}

.close-icon:hover {
    color: #AB1F74; /* Adjust hover color as needed */
}

    </style>
</head>
<body>
<div class="phone-frame">
    <div class="header">
        <div class="status-bar">
            <!-- Status bar content -->
        </div>
        <div class="logo">
            <img src="{{ asset('landing/Dogo_logo_white.png') }}" alt="Logo">
        </div>
        <a href="/dashboard" class="close-icon">
        <i class="bi bi-x"></i>
    </a>
    </div>
    <div class="chat-content">
        <div class="profile">
            <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
            <button id="clear-history-button" class="bg-red-100 text-red-800 px-4 py-2 rounded-lg">Clear History</button>

            <div class="profile-name">Prince</div>
            <div class="profile-title">Personal insurance assistant</div>
        </div>
        <div class="chat-messages" id="chat-messages">
            <div class="message bot-message">
                <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
                <div class="message-content">
Hi, user               </div>
            </div>
            <div class="message bot-message">
                <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
                <div class="message-content">
                    lets go!
                </div>
            </div>
        </div>
    </div>
    <div class="chat-input">
        <input type="file" id="fileInput" accept="image/*">
        <button id="uploadButton"><i class="bi bi-upload"></i></button>
        <input type="text" id="userMessage" placeholder="Type something" style="height: 40px;">
        <button id="cameraButton"><i class="bi bi-camera"></i></button>
        <button id="micButton"><i class="bi bi-mic"></i></button>
        <button id="sendButton"><i class="bi bi-send"></i></button>
    </div>
</div>


    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script>
    $(document).ready(function() {
        // Ensure CSRF token is set for all AJAX requests
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });

        

        let recordedText = ''; // Variable to store text from voice recognition

        function sendMessage() {
            var message = $('#userMessage').val().trim();
            var file = $('#fileInput')[0].files[0];
            
            // Use recordedText if available, otherwise use text input
            var finalMessage = recordedText || message;

            if (!finalMessage && !file) return;

            if (file) {
                uploadFile(file, finalMessage);
            } else {
                sendTextMessage(finalMessage);
            }

            // Clear inputs after sending
            $('#userMessage').val('');
            $('#fileInput').val('');
            recordedText = ''; // Clear recorded text after sending
        }


        function sendTextMessage(message) {
            appendUserMessage(message);
            showTypingIndicator();

            $.ajax({
                url: '{{ route("chatbott.send") }}',
                method: 'POST',
                data: { message: message },
                success: function(response) {
                    hideTypingIndicator();
                    appendBotMessage(response.message);
                    checkForPrince(response.message); // Call function here
                    if (response.options) {
                        response.options.forEach(option => {
                            $('#chat-messages').append('<button class="bg-blue-100 text-blue-800 px-2 py-1 rounded-full text-sm mr-2 mb-2 option-button">' + option + '</button>');
                        });
                    }
                },
                error: function() {
                    hideTypingIndicator();
                    appendBotMessage('Sorry, there was an error processing your request.');
                }
            });
        }

        function uploadFile(file, message) {
            var formData = new FormData();
            formData.append('file', file);
            if (message) formData.append('message', message);

            appendUserMessage('Uploading file: ' + file.name);
            showTypingIndicator();

            $.ajax({
                url: '{{ route("chatbott.upload") }}',
                method: 'POST',
                data: formData,
                processData: false,
                contentType: false,
                success: function(response) {
                    hideTypingIndicator();
                    $('#chat-messages').append('<img src="' + response.uploaded_image_url + '" class="max-w-full h-auto rounded-lg shadow-md mb-2" alt="Uploaded Image">');
                    appendBotMessage(response.message);

                },
                error: function(xhr, status, error) {
                    hideTypingIndicator();
                    let errorMessage = xhr.responseJSON?.error || 'Sorry, there was an error uploading your file.';
                    appendBotMessage(errorMessage);
                }
            });
        }

        function appendUserMessage(message) {
        scrollChatToBottom();

        // Use Blade syntax to insert the PHP variables into the JavaScript function
        let userImagePath = `{{ $selfieExists ? asset($selfiePath) : asset('user-profile.png') }}`;

        $('#chat-messages').append(`
            <div class="message user-message">
                <div class="message-content">${message}</div>
                <img src="${userImagePath}" alt="User">
            </div>
        `);
    }

        function appendBotMessage(message) {
            $('#chat-messages').append(`
                <div class="message bot-message">
                    <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
                    <div class="message-content">${message}</div>
                </div>
            `);
            scrollChatToBottom();
        }



        function scrollChatToBottom() {
            window.scrollTo(0, document.body.scrollHeight);
        }

        function showTypingIndicator() {
            scrollChatToBottom();
                const imageUrl = "{{ asset('landing/Prince_avatar.png') }}"; // Assuming the image is stored in the 'public/storage' directory

                $('#chat-messages').append(`
                    <div class="typing-indicator">
                        <img src="${imageUrl}" alt="Typing" class="typing-image">
                        <div class="loading-dots">
                            <div class="loading-dot"></div>
                            <div class="loading-dot"></div>
                            <div class="loading-dot"></div>
                        </div>
                    </div>
                `);
                scrollChatToBottom();
            }

            function hideTypingIndicator() {
                $('.typing-indicator').remove();
            }


        // Event listeners
        $('#userMessage').on('keypress', function(e) {
            if (e.which == 13) {
                e.preventDefault();
                sendMessage();
            }
        });

        $('#sendButton').click(function() {
            sendMessage();
        });

        $('#uploadButton').click(function() {
            $('#fileInput').click();
        });

        $('#fileInput').change(function() {
            var fileName = $(this).val().split('\\').pop();
            if (fileName) {
                appendUserMessage("Uploaded file: " + fileName);
                // Here you would typically upload the file to your server
            }
        });

        $('#cameraButton').click(function() {
            appendUserMessage("Camera button clicked");
            // Implement camera functionality
        });
        const SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;
        const recognition = new SpeechRecognition();
        recognition.lang = 'en-US';
        recognition.interimResults = false;

        let isRecording = false;
        let recordingTimeout;

        $('#micButton').on('mousedown touchstart', function(e) {
        e.preventDefault();
        isRecording = true;
        $(this).addClass('recording');
        recognition.start();
        });

        $('#micButton').on('mouseup mouseleave touchend', function() {
        if (isRecording) {
            isRecording = false;
            $(this).removeClass('recording');
            
            // Set a timeout to stop recording after 1 second
            clearTimeout(recordingTimeout);
            recordingTimeout = setTimeout(() => {
                recognition.stop();
            }, 2000);
        }
        });

        recognition.onresult = function(event) {
        clearTimeout(recordingTimeout); // Clear the timeout if we get a result
        recordedText = event.results[0][0].transcript;
        sendMessage(); // Call sendMessage to send the recorded text
        };

        recognition.onerror = function(event) {
        console.error('Speech recognition error:', event.error);
        $('#chat-messages').append('<div class="bot-message">Error in speech recognition. Please try again.</div>');
        scrollChatToBottom();
        };

    function checkForPrince(message) {
    console.log("Checking message for details: ", message);

    // Regex patterns to extract phone number and amount to be paid
    const phoneRegex = /~\s*pnumber:\s*([^\s~]+)/i;
    const amountRegex = /~\s*amount:\s*([^\s~]+)/i;

    let phoneno = '';
    let amount = '';

    const phoneMatch = message.match(phoneRegex);
    const amountMatch = message.match(amountRegex);

    if (phoneMatch) phoneno = phoneMatch[1].trim();
    if (amountMatch) amount = amountMatch[1].trim();

    console.log("Extracted details - Phone Number:", phoneno, "Amount not paid to activate", amount);

    if (phoneno && amount) {
        $.ajax({
            url: 'api/stkpush',
            method: 'POST',
            data: {
                phoneno: phoneno,
                amount: amount
            },
            success: function(response) {
                console.log("STK Push initiated successfully: ", response);
                appendBotMessage(`STK Push initiated successfully: ${response.message}`);
            },
            error: function(xhr) {
                console.error("Error initiating STK Push: ", xhr);
                let errorMessage = xhr.responseJSON?.errors ? JSON.stringify(xhr.responseJSON.errors) : 'An error occurred while initiating the STK Push';
                appendBotMessage(`Error: ${errorMessage}`);
            }
        });
    } else {
        console.log("Insufficient details to initiate STK Push");
    }
}


$('#clear-history-button').click(function() {
        $.ajax({
            url: '{{ route("chatbot.clearHistory") }}',
            method: 'POST',
            success: function(response) {
                $('#chat-messages').empty(); // Clear chat messages from the interface
                appendBotMessage(response.message);
                setTimeout(function() {
                    location.reload();
                }, 2000); // Refresh page after 2 seconds
            },
            error: function() {
                appendBotMessage('Sorry, there was an error clearing the chat history.');
            }
        });
    });

    });
    </script>
</body>

</html>
