<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Golfers Overview</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Open+Sans:wght@500&family=Lato:wght@400;700&display=swap">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-icons/1.10.5/font/bootstrap-icons.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">

    <style>
        body {
            background-color: #000;
            color: #fff;
            font-family: Lato, sans-serif;
        }
        .container {
            padding-top: 10px;
            width: 100%;
            max-width: 600px; /* Adjust max-width for mobile */
            margin: 0 auto; /* Center the container on larger screens */
        }
        @media (min-width: 768px) {
            .container {
                width: 65%; /* Adjust for PC with 65% width */
            }
        }
        .header {
            margin-bottom: 30px;
            position: relative; /* Relative positioning for the back button */
        }
        .logo {
            text-align: center;
        }
        .logo img {
            height: 80px;
        }
        .back-button {
            position: absolute;
            top: 20px;
            right: 20px; /* Change left to right */
            background-color: white;
            color: black;
            border: none;
            border-radius: 50%;
            width: 50px;
            height: 50px;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            text-align: center;
            font-size: 40px;
            box-shadow: none;
        }

        .back-button i {
            margin: 0; /* Ensure the icon is centered properly */
        }

        .back-button:hover {
            background-color: #ceb78d;
        }
        .golf-image {
            text-align: center;
            margin-bottom: 30px;
        }
        .golf-image img {
            width: 150px;
            height: 150px;
        }
       
        .info {
            margin-bottom: 15px;
            font-size: 15px; /* Adjusted for body font size */
            line-height: 2.1em;
            padding-left: 30px; /* Moves content 30px from the left */
        }
        .report-button {
            background-color: #AB1F74;
            color: #fff;
            border: none;
            border-radius: 20px; /* Rounded edges */
            padding: 10px 20px;
            font-size: 18px;
            font-weight: 700;
            position: fixed;
            bottom: 20px;
            cursor: pointer;
            text-align: center;
        }
        .report-button:hover {
            background-color: #ceb78d;
        }
        .avatar {
            width: 40px;
            height: 40px;
            border-radius: 50%;
            position: fixed;
            bottom: 20px;
            right: 20px;
            overflow: hidden;
        }
        .avatar img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }
        .tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #333;
        }
        .tab {
            flex: 1;
            text-align: center;
            padding: 10px 0;
            font-size: 14px;
            color: #888;
        }
        .tab.active {
            color: #ab1f74;
            border-bottom: 2px solid #ab1f74;
        }
        .download-links {
            font-size: 12px;
            margin-bottom: 30px;
        }
        .download-links a {
            color: #4a90e2;
            text-decoration: none;
            margin-right: 15px;
        }
        .content-wrapper {
            flex-grow: 1;
            overflow-y: auto;
            padding-bottom: 80px; /* Adjust based on your button height */
        }
        .coverage-item, .exclusion-item {
            margin-bottom: 30px;
            text-align: center;
        }
        .coverage-item img, .exclusion-item img {
            width: 100px;
            height: 100px;
            margin-bottom: 10px;
        }
        .coverage-item h3, .exclusion-item h3 {
            margin: 0;
            font-size: 22px;
            font-weight: normal;
        }
        .coverage-item p {
            margin: 5px 0;
            font-size: 14px;
        }
        .coverage-item p:first-of-type {
            color: #fff;
            font-size: 18px;
            font-weight: bold;
        }
        .coverage-item p:last-of-type, .exclusion-item p {
            color: #888;
        }
        .page {
            display: none;
        }
        .page.active {
            display: block;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
        <button class="back-button" onclick="window.location.href='{{ url('activecovers') }}'">
        <i class="fas fa-arrow-left"></i> </button>

            <div class="logo">
                <img src="{{ asset('images/Dogo Final logo.png') }}" alt="logo">
            </div>
        </div>
        <div class="tabs">
            <div class="tab" onclick="showPage('overview')">Overview</div>
            <div class="tab active" onclick="showPage('details')">Details of cover</div>
            <div class="tab" onclick="showPage('exclusions')">Exclusions</div>
        </div>
        
        <div id="overview" class="page">
            <div class="golf-image">
                <img src="{{ asset('images/Icon_for_golfers_on_dashboard.png') }}" alt="Golf image">
            </div>
            @if ($package)
            <div class="info">Package: {{ $package }}</div>
            <div class="info">Premium: Ksh {{ number_format($premium, 2) }} Annual</div>
            <div class="info">Expires: {{ $expiry_date }}</div>
            <div class="info">
                Autorenew? {{ $autorenew ? 'On' : 'Off' }}
                <a href="activecovers" style="color: #ab1f74;">
                    (turn {{ $autorenew ? 'off' : 'on' }})
                </a>
            </div>
            @else
            <div class="info">No package selected</div>
            @endif
        </div>

        <div id="details" class="page active">
            <div class="download-links">
                <a href="#">Download receipt</a>
                <a href="#">Download schedule of benefits</a>
            </div>
            @foreach ($coverages as $coverage)
    <div class="coverage-item">
        
        <img src="{{ asset($coverage->file_path) }}" alt="coverage">
        <h3>{{ $coverage->coverage_name }}</h3>
        <p>{{ $coverage->amount }}</p>
        <p>{{ $coverage->description }}</p>
    </div>
@endforeach
        </div>

        <div id="exclusions" class="page">
            

                <div class="exclusion-item">
                
                    <img src="{{ asset('golfers/Exclusions/Cash .png') }}" alt="">
                    <h3>cash</h3>
                    <p>Loose cash or change isn’t covered
                    if it gets lost or stolen on the course</p>
                </div>
                <div class="exclusion-item">
                     
                    <img src="{{ asset('golfers/Exclusions/wear and tear.png') }}" alt="">
                    <h3>Natural wear and tear</h3>
                    <p>Things may deteriorate over time. 
Which is why you can’t claim back
for new items when this happens.</p>
                </div>
           
        </div>
    </div>

    <div class="report-claim-container">
    <a href="/chatbot" class="make-claim-link">
        <button class="report-button">Report claim</button>
        </a>
        <img src="{{ asset('images/Prince AI avatar.png') }}" alt="User Avatar" class="avatar">
    </div>

    <script>
        function showPage(pageId) {
            const pages = document.querySelectorAll('.page');
            pages.forEach(page => page.classList.remove('active'));
            document.getElementById(pageId).classList.add('active');

            const tabs = document.querySelectorAll('.tab');
            tabs.forEach(tab => tab.classList.remove('active'));
            event.target.classList.add('active');
        }
    </script>
</body>
</html>
