<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login</title>
    <link href="https://fonts.googleapis.com/css2?family=Open+Sans:wght@500&family=Lato:wght@400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Lato', sans-serif;
            font-size: 15px;
            line-height: 2.1em;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            background-color: #000000;
            color: #FFFFFF;
        }
        .container {
            width: 100%;
            max-width: 100%;
            padding: 20px;
            box-sizing: border-box;
        }
        @media (min-width: 992px) { /* Large screens */
            .container {
                width: 60%;
                margin: 0 auto; /* Center the container */
            }
        }
        .logo {
            text-align: center;
        }
        .logo img {
            width: 200px;
            height: auto;
            margin-bottom: 20px;
        }
        .form-group {
            margin-bottom: 15px;
            width: 100%;
        }
        .form-group input,
        .btn {
            width: 100%;
            box-sizing: border-box;
        }
        .form-group input {
            padding: 10px;
            font-size: 15px;
            line-height: 2.1em;
            border: none;
            border-radius: 4px;
            background-color: #ffffff;
            color: #000000;
        }
        .btn {
            padding: 10px;
            font-family: 'Lato', sans-serif;
            font-size: 18px;
            font-weight: 700;
            color: #fff;
            background-color: #AB1F74;
            border: 10px;
            border-radius: 40px;
            cursor: pointer;
            transition: background-color 0.3s;
            position: relative;
        }
        .btn:hover {
            background-color: #8e1960;
        }
        .btn .loader {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            width: 24px;
            height: 24px;
            border: 3px solid rgba(255, 255, 255, 0.3);
            border-radius: 50%;
            border-top: 3px solid #fff;
            animation: spin 1s linear infinite;
            display: none;
        }
        .btn.loading .loader {
            display: block;
        }
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        .links {
            margin-top: 15px;
            text-align: center;
        }
        .links a {
            color: #AB1F74;
            text-decoration: none;
            font-size: 14px;
        }
        .links p {
            margin: 0; /* Remove the default margin from paragraphs */
        }

        .links a:hover {
            text-decoration: underline;
        }
        .auth-options {
            display: flex;
            justify-content: space-between;
            margin-top: 15px;
        }
        .auth-option {
            width: 48%;
            padding: 10px;
            border: none;
            border-radius: 4px;
            background-color: #ffffff;
            cursor: pointer;
            color: #000000;
            display: flex;
            justify-content: center;
            align-items: center;
        }
        .auth-option img {
            width: 20px;
            height: 20px;
            vertical-align: middle;
        }
        .custom-status, .custom-errors {
            color: #FFFFFF;
            background-color: #333333;
            padding: 10px;
            border-radius: 4px;
            text-align: left;
            margin-bottom: 15px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="logo">
            <img src="{{ asset('landing/Dogo_logo.png') }}" alt="Crownscope Logo">
        </div>
        <x-auth-session-status class="mb-4 custom-status" :status="session('status')"/>

        <x-auth-validation-errors class="mb-4 custom-errors" :errors="$errors"/>

        <form id="loginForm" method="POST" action="{{ route('login') }}">
            @csrf
            <div class="form-group">
                <input type="email" id="email" name="email" placeholder="Email" required>
            </div>
            <div class="form-group">
                <input type="password" id="password" name="password" placeholder="Password" required>
            </div>
            <button type="submit" class="btn">
                <span class="loader"></span>
                Sign in
            </button>
        </form>
        <div class="links">
        <p>Don't have an account? <a href="/register" class="sign-in-link">Register now</a></p>
        <p>Having trouble signing in? <a href="/forgot-password" class="sign-in-link">Reset your password</a></p>
        </div>
        
    </div>
    <script>
        document.getElementById('loginForm').addEventListener('submit', function() {
            const btn = document.querySelector('.btn');
            btn.classList.add('loading');
        });
    </script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-icons/1.10.5/font/bootstrap-icons.min.css">
</body>
</html>
