<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
    <title>Verification</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <style>
        body, html {
            height: 100%;
            background-color: #000;
            color: #fff;
            font-family: Arial, sans-serif;
        }
        .container {
            height: 100%;
            display: flex;
            flex-direction: column;
            justify-content: center;
            padding: 20px;
            box-sizing: border-box;
        }
        .content {
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            justify-content: center;
        }
        .logo {
            text-align: center;
            margin-bottom: 40px;
        }
        .logo img {
            width: 60%;
            max-width: 200px;
        }
        .logo p {
            font-size: 12px;
            margin: 5px 0;
        }
        h2 {
            font-size: 18px;
            margin-bottom: 30px;
            text-align: center;
        }
        .verification-code {
            display: flex;
            justify-content: center;
            margin-bottom: 20px;
        }
        .verification-code input {
            width: 40px;
            height: 40px;
            text-align: center;
            font-size: 18px;
            border: 1px solid #fff;
            background-color: #fff;
            color: #000;
            margin: 0 5px;
        }
        .btn-submit, .btn-resend {
            font-family: "Lato", Sans-serif;
            font-size: 18px;
            font-weight: 700;
            background-color: #AB1F74;
            border: none;
            border-radius: 25px;
            padding: 12px;
            width: 100%;
            max-width: 300px;
            margin: 0 auto;
            display: block;
            transition: background-color 0.3s ease;
        }
        .btn-submit:hover, .btn-resend:hover {
            background-color: #ceb78d;
        }
        .success-icon {
            text-align: center;
        }
        .success-icon svg {
            width: 100px;
            height: 100px;
        }
    </style>
</head>
<body>
    <div class="container" id="verificationScreen">
        <div class="content">
            <div class="logo">
                <img src="landing/Dogo_logo.png" alt="Dogo Logo">
            </div>
            <h2>Enter verification code</h2>
            <form action="{{ route('verify.code') }}" method="POST">
                @csrf
                <div class="verification-code">
    @for ($i = 0; $i < 6; $i++)
        <input type="tel" name="verification_code[]" maxlength="1" pattern="[0-9]*" inputmode="numeric" oninput="moveToNext(this, {{ $i + 1 }})">
    @endfor
</div>

                <button type="submit" class="btn btn-primary btn-submit">Submit</button>
            </form>
            <form action="{{ route('resend.code') }}" method="POST" class="mt-3">
                @csrf
                <button type="submit" class="btn btn-secondary btn-resend">Resend Code</button>
            </form>
        </div>
    </div>

    <div class="container" id="successScreen" style="display: none;">
        <div class="content">
            <div class="logo">
                <img src="landing/Dogo_logo.png" alt="Dogo Logo">
            </div>
            <div class="success-icon">
                <svg viewBox="0 0 24 24" fill="#b5289d">
                    <path d="M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm-2 15l-5-5 1.41-1.41L10 14.17l7.59-7.59L19 8l-9 9z"/>
                </svg>
            </div>
        </div>
    </div>

    <script>
        function moveToNext(current, nextIndex) {
            if (current.value.length === current.maxLength) {
                const nextInput = document.querySelector(`input[name="verification_code[]"]:nth-child(${nextIndex + 1})`);
                if (nextInput) {
                    nextInput.focus();
                }
            }
        }

        @if(session('success'))
            Swal.fire({
                title: 'Success!',
                text: "{{ session('success') }}",
                icon: 'success',
                confirmButtonColor: '#b5289d',
                timer: 3000,
                showConfirmButton: false
            }).then(() => {
                document.getElementById('verificationScreen').style.display = 'none';
                document.getElementById('successScreen').style.display = 'flex';
                
                setTimeout(() => {
                    window.location.href = '';
                }, 3000);
            });
        @endif

        @if(session('error'))
            Swal.fire({
                title: 'Error!',
                text: "{{ session('error') }}",
                icon: 'error',
                confirmButtonColor: '#b5289d',
            });
        @endif

        @if ($errors->any())
            Swal.fire({
                title: 'Error!',
                text: "{{ $errors->first() }}",
                icon: 'error',
                confirmButtonColor: '#b5289d',
            });
        @endif
    </script>
</body>
</html>
