<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Renter's Insurance</title>
    <style>
        /* Your existing CSS */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        body, html {
            font-family: Arial, sans-serif;
            height: 100%;
            background-color: #ffffff;
        }
        .container {
            width: 100%;
            height: 100%;
            padding: 20px;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
            align-items: center;
        }
        .content {
            width: 100%;
            max-width: 320px;
            display: flex;
            flex-direction: column;
            align-items: center;
            flex-grow: 1;
        }
        .logo {
            text-align: center;
            margin-bottom: 20px;
        }
        .logo img {
            width: 40px;
            height: 40px;
        }
        h1 {
            font-size: 24px;
            margin-bottom: 10px;
            font-weight: normal;
            text-align: center;
        }
        .address {
            font-size: 14px;
            color: #666;
            margin-bottom: 30px;
            text-align: center;
        }
        .circle {
            width: 200px;
            height: 200px;
            background-color: #c5007b;
            border-radius: 50%;
            display: flex;
            justify-content: center;
            align-items: center;
            margin-bottom: 30px;
        }
        .circle p {
            color: white;
            font-size: 18px;
            text-align: center;
        }
        .date {
            width: 100%;
            margin-bottom: 30px;
        }
        .date p {
            margin: 0;
            font-size: 14px;
            text-align: center;
        }
        .date hr {
            border: none;
            border-top: 1px solid #000;
            margin-top: 5px;
        }
        .details {
            width: 100%;
            background-color: #f7f7f7;
            padding: 15px;
            margin-bottom: 30px;
        }
        .details h2 {
            margin: 0;
            font-size: 18px;
            font-weight: normal;
            text-align: center;
        }
        .buy-now {
            width: 100%;
            background-color: #c5007b;
            color: white;
            text-align: center;
            padding: 15px;
            font-size: 18px;
            cursor: pointer; /* Make button look clickable */
        }
        @media (min-width: 768px) {
            .content {
                max-width: 60%;
            }
        }
        #map {
            height: 200px;
            width: 100%;
            margin-bottom: 30px;
            display: none; /* Hiding the map initially */
        }
    </style>
    <link rel="stylesheet" href="https://unpkg.com/leaflet/dist/leaflet.css" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css" />
</head>
<body>
    <div class="container">
        <div class="content">
            <div class="logo">
                <img src="{{ asset('crownscope-logo.png') }}" alt="Logo">
            </div>
            <h1>Renter's insurance</h1>
            <div class="address" id="address"></div>
            <div id="map"></div>
            <div class="circle">
                <p>Ksh <span id="amount"></span> per month</p>
            </div>
            <div class="date">
                <p>Start date: <span id="startDate"></span></p>
                <hr>
            </div>
            <div class="details">
            <p><strong>Ownership Status:</strong> {{ $rent->ownership_status }}</p>
            <p><strong>Cohabitants:</strong> {{ $rent->cohabitants }}</p>
            <p><strong>Valuables:</strong> {{ $rent->valuables }}</p>
          
            
            </div>
        </div>

        <form id="paymentForm" action="{{ route('stkpush') }}" method="POST">
    @csrf
    <input type="hidden" name="phoneno" value="{{ $phoneNumber }}">
    <input type="hidden" name="amount" value="26000">
</form>

<div class="buy-now" id="buyNowButton">Buy now</div>

<script src="https://unpkg.com/leaflet/dist/leaflet.js"></script>
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
<script>
    // Extract latitude and longitude from the homeAddress string
    const homeAddress = @json($homeAddress);
    let latitude = 0;
    let longitude = 0;

    if (homeAddress) {
        // Use regular expressions to extract latitude and longitude
        const latMatch = homeAddress.match(/Latitude:\s*([\d.-]+)/);
        const lonMatch = homeAddress.match(/Longitude:\s*([\d.-]+)/);

        if (latMatch && lonMatch) {
            latitude = parseFloat(latMatch[1]);
            longitude = parseFloat(lonMatch[1]);
        }
    }

    // Initialize Leaflet map if latitude and longitude are valid
    if (latitude && longitude) {
        const map = L.map('map').setView([latitude, longitude], 13);

        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            attribution: '© OpenStreetMap contributors'
        }).addTo(map);

        L.marker([latitude, longitude]).addTo(map);

        // Fetch address using Nominatim API
        async function fetchAddress() {
            try {
                const response = await fetch(`https://nominatim.openstreetmap.org/reverse?lat=${latitude}&lon=${longitude}&format=json`);
                const data = await response.json();
                if (data && data.address) {
                    document.getElementById('address').textContent = `${data.address.road || ''}, ${data.address.city || ''}, ${data.address.state || ''}, ${data.address.country || ''}`;
                } else {
                    document.getElementById('address').textContent = 'Address not found';
                }
            } catch (error) {
                document.getElementById('address').textContent = 'Error fetching address';
            }
        }

        // Fetch the address on page load
        fetchAddress();
    }

    // Hardcoded values for other elements
    document.getElementById('amount').textContent = '5,000';
    document.getElementById('startDate').textContent = '21/07/2024';

    // Function to show success SweetAlert2
    function showSuccessAlert() {
        Swal.fire({
            title: "Payment request sent",
            icon: "success"
        });
    }

    // Function to show auto-close SweetAlert2
    function showAutoCloseAlert() {
        let timerInterval;
        Swal.fire({
            title: "crown scope!",
            html: "Payments are processed by crown scope.<br><br> Please enter your M-Pesa PIN to complete the payment.",
            timer: 6000,
            timerProgressBar: true,
            didOpen: () => {
                Swal.showLoading();
                const timer = Swal.getPopup().querySelector("b");
                timerInterval = setInterval(() => {
                    timer.textContent = `${Swal.getTimerLeft()}`;
                }, 100);
            },
            willClose: () => {
                clearInterval(timerInterval);
                showSuccessAlert(); // Call showSuccessAlert() when the alert closes

                // Submit the form and redirect after a delay
                document.getElementById('paymentForm').submit(); // Submit the form first

                // Redirect after a delay
                setTimeout(() => {
                    window.location.href = '/dashboard';
                }, 3000); // Delay for 6 seconds (6000 milliseconds)
            }
        });
    }

    // Handling button click event
    document.getElementById('buyNowButton').addEventListener('click', function(event) {
        event.preventDefault(); // Prevent default button action
        showAutoCloseAlert();
    });
</script>