<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <title>Chat Interface</title>
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css">
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.7.1/dist/leaflet.css" />
    <script src="https://unpkg.com/leaflet@1.7.1/dist/leaflet.js"></script>
    <link rel="stylesheet" href="https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.css" />
    <script src="https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.js"></script>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <style>
        body {
            font-family: 'Open Sans', sans-serif;
            background-color: #ffffff;
            display: flex;
            flex-direction: column; /* Changed to column for better layout management */
            height: 100vh;
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            align-items: center;
            justify-content: center;
        }

        .header {
            height: 101px;
            background-color: white;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            padding: 0 20px;
            box-sizing: border-box;
            position: sticky;
            top: 0;
            z-index: 2;
        }

.header .logo {
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: white;
}

.header .logo img {
    width: 150px;
    margin-right: 5px;
}

.chat-content {
    flex-grow: 1;
    overflow-y: auto;
    padding: 20px;
    box-sizing: border-box;
    padding-bottom: 80px; /* Add padding to account for the chat input */
}

.profile {
    display: flex;
    flex-direction: column;
    align-items: center;
    margin-top: 20px;
    box-sizing: border-box;
}

.profile img {
    width: 100px;
    height: 100px;
    border-radius: 50%;
}

.profile-name {
    font-weight: bold;
    margin-top: 10px;
}

.profile-title {
    color: #C18AB2;
    font-size: 14px;
}

.chat-messages {
    margin-top: 20px;
}

.message {
    display: flex;
    margin-bottom: 20px;
}

.message img {
    width: 50px;
    height: 50px;
    border-radius: 50%;
    margin-right: 10px;
}

.message-content {
    background-color: #f0f0f0;
    border-radius: 18px;
    padding: 10px 15px;
    max-width: 70%;
    font-size: 14px;
    font-family: 'Lato', sans-serif; /* Changed from Open Sans to Lato */
    display: flex;
    align-items: center; /* Vertically centers the content */
    justify-content: center; /* Horizontally centers the content */
    
    line-height: 1.7; /* Added line spacing */
    
}

.message.bot-message {
    justify-content: flex-start;
}

.message.bot-message .message-content {
    background-color: #e4e2dd;
}

.message.user-message {
    justify-content: flex-end;
}

.message.user-message .message-content {
    background-color: #e6d0de;
}

.chat-input {
    position: fixed; /* Fixed positioning */
    bottom: 0; /* Align to the bottom of the viewport */
    left: 0; /* Align to the left edge */
    width: 100%; /* Full width */
    height: 60px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 0 10px;
    background-color: #545454;
    box-sizing: border-box;
    z-index: 1000; /* Ensure it is above other content */
    border-radius: 20px; /* Adjust this value to control the roundness */
}

.chat-input button {
    background: none;
    border: none;
    font-size: 24px;
    color: #FF69B4;
    cursor: pointer;
    padding: 0;
    margin: 0 5px;
}

.chat-input .bi-plus {
    color: #E4E2DD;
}

.chat-input .bi-camera {
    color: #E4E2DD;
}

.chat-input .bi-mic {
    color: #E4E2DD;
}

.chat-input .bi-send {
    color: #E4E2DD;
    display: none;
}

.chat-input input {
    flex-grow: 1;
    border: none;
    padding: 0 10px;
    height: 30px;
    background-color: #E4E2DD;
    border-radius: 15px;
    margin: 0 5px;
}

.chat-input input:focus {
    outline: none;
}

.continue-cancel-buttons,
.yes-no-buttons,
.response-buttons,
.restart-button,
.checkbox-btns-container {
    display: flex;
    justify-content: center;
    margin-left: 10px;
    margin-top: 10px;
}

.continue-cancel-buttons button,
.yes-no-buttons button,
.response-buttons button,
.restart-button button,
.checkbox-btns-container button {
    background-color: rgba(171, 131, 116, 0.3);
    color: #202124;
    border: none;
    padding: 8px 16px;
    border-radius: 10px;
    cursor: pointer;
    font-family: Arial, sans-serif;
    font-size: 12px;
    gap: 10px;
    transition: background-color 0.3s;
}

.checkboxes-container {
    margin-bottom: 10px;
}

.checkbox-label {
    display: block;
    margin: 5px 0;
}

.chat-checkbox {
    margin-right: 10px;
}

.date-picker {
    display: flex;
    justify-content: center;
    margin-top: 10px;
}

.date-picker input[type="date"] {
    padding: 5px;
    border-radius: 5px;
    border: 1px solid #ccc;
}

@media (max-width: 768px) {
    .phone-frame {
        width: calc(100% - 20px);
        height: calc(100% - 20px);
        border-radius: 20px;
    }
    .chat-input {
        padding: 0 5px;
    }
    .chat-input button {
        font-size: 20px;
    }
    .chat-input input {
        height: 25px;
        font-size: 14px;
    }
}

@media (min-width: 1024px) {
    .phone-frame {
        width: 60%; /* Takes up 3/4 of the screen width */
        margin: 0 auto; /* Centers the frame */
    }
    .chat-input {
        width: 60%; /* Takes up 3/4 of the screen width */
        left: 20%; /* Centers the input box */
    }

    .chat-content {
        padding-bottom: 70px; /* Adjust padding for the input box */
    }
}

.loading {
    display: flex;
    align-items: center;
    margin-bottom: 20px;
}

.loading img {
    width: 50px;
    height: 50px;
    border-radius: 50%;
    margin-right: 10px;
}

.loading-dots {
    display: flex;
}

.loading-dot {
    width: 25px;
    height: 25px;
    border-radius: 50%;
    background-color: #000;
    margin-right: 4px;
    animation: pulse 1.5s infinite;
}

.loading-dot:nth-child(2) {
    animation-delay: 0.5s;
}

.loading-dot:nth-child(3) {
    animation-delay: 1s;
}

@keyframes pulse {
    0% { opacity: 0.3; }
    50% { opacity: 1; }
    100% { opacity: 0.3; }
}

#map-container {
    width: 100%;
    height: 250px;
    max-width: 350px;
    margin: 10px auto;
    display: none;
}

#map {
    width: 100%;
    height: 100%;
    border-radius: 10px;
    border: 2px solid #ccc;
}

.confirm-button {
    margin-top: 10px;
    text-align: center;
}

.confirm-button button {
    background-color: rgba(255, 105, 180, 0.3);
    color: #202124;
    border: none;
    padding: 8px 16px;
    border-radius: 10px;
    cursor: pointer;
    font-family: Arial, sans-serif;
    font-size: 12px;
    transition: background-color 0.3s;
}

.confirm-button button:hover {
    background-color: rgba(255, 105, 180, 0.5);
}
.close-icon {
    position: absolute;
    top: 0px; /* Adjust as needed */
    right: -15px; /* Adjust as needed */
    font-size: 37px;
    color: #AB1F74; /* Adjust color as needed */
    text-decoration: none;
    cursor: pointer;
}

.close-icon:hover {
    color: #AB1F74; /* Adjust hover color as needed */
}
.input-list {
            display: flex;
            flex-direction: column;
            gap: 10px;
            margin-bottom: 20px;
        }
        .input-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .input-item input {
            width: 100px;
            padding: 5px;
            border-radius: 5px;
            border: 1px solid #000;
            background-color: transparent;
        }
        .submit-button {
            background-color: rgba(171, 131, 116, 0.3);
            color: #202124;
            border: none;
            padding: 8px 16px;
            border-radius: 10px;
            cursor: pointer;
            font-family: Arial, sans-serif;
            font-size: 12px;
            margin-top: 10px;
        }

    </style>
</head>
<body>
    <div class="phone-frame">
        <div class="header">
            <div class="status-bar">
                <!-- Status bar content -->
            </div>
            <div class="logo">
                <img src="{{ asset('landing/Dogo_logo_white.png') }}" alt="Logo">
            </div>
            <a href="/dashboard" class="close-icon">
        <i class="bi bi-x"></i>
    </a>
        </div>
        <div class="chat-content">
            <div class="profile">
                <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
                <div class="profile-name">Prince</div>
                <div class="profile-title">Personal insurance concierge</div>
            </div>
            <div class="chat-messages">
                
            </div>
            <div id="map-container">
                <div id="map"></div>
                <div class="confirm-button">
                    <button onclick="confirmLocation()">Confirm Location</button>
                </div>
        </div>

        </div>
        <div class="chat-input">
            <button><i class="bi bi-plus"></i></button>
            <input type="text" placeholder="type something" oninput="toggleSendButton()"  style="height: 40px;">
            <button class="bi-camera-mic-buttons"><i class="bi bi-camera" onclick="openCamera()"></i></button>
            <button class="bi-camera-mic-buttons"><i class="bi bi-mic"></i></button>
            <button class="send-button"><i class="bi bi-send"></i></button>
        </div>
    </div>

    <script>
// Global variables
let currentStep = 1;
let userResponses = {};
let waitingForInput = false;
let currentInputHandler = null;

// Initialize the chat
function initChat() {
    const firstName = @json($user->first_name);
    const latitude = @json($latitude);
    const longitude = @json($longitude);
    
    addBotMessage(`Hello ${firstName}! I see you'd like to insure your residential property. Is this at:`, () => {
        showMap(latitude, longitude);
    });
}

function showMap(lat, lng) {
    const mapContainer = document.createElement('div');
    mapContainer.id = 'map';
    mapContainer.style.height = '200px';
    mapContainer.style.marginBottom = '10px';
    appendToChat(mapContainer);

    if (lat && lng) {
        const map = L.map('map').setView([lat, lng], 13);
        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            attribution: '© OpenStreetMap contributors'
        }).addTo(map);

        const marker = L.marker([lat, lng]).addTo(map);
    } else {
        console.error('Latitude and Longitude are not provided');
    }

    const yesNoButtons = createYesNoButtons(handleLocationResponse);
    appendToChat(yesNoButtons);
}

function handleLocationResponse(response) {
    addUserMessage(response ? 'Yes' : 'No');
    if (response) {
        addBotMessage("Excellent. Grevelia Grove is the place to be these days!", () => {
            askOwnershipStatus();
        });
    } else {
        addBotMessage("I see. Let's update your location then.", () => {
            // Here you could add logic to allow the user to update their location
            askOwnershipStatus();
        });
    }
}

function askOwnershipStatus() {
    addBotMessage("Let's get a few details in then. Firstly, do you own the property or are you renting?", () => {
        const buttons = createButtons(['Owning', 'Renting'], handleOwnershipResponse);
        appendToChat(buttons);
    });
}

function handleOwnershipResponse(response) {
    userResponses.ownershipStatus = response;
    addUserMessage(response);
    if (response === 'Renting') {
        addBotMessage("Noted.", () => {
            askRentAmount();
        });
    } else {
        addBotMessage("Great. And are you Occupying there or have you rented it out?", () => {
            const buttons = createButtons(['Occupying', 'Rented out'], handleOccupancyStatus);
            appendToChat(buttons);
        });
    }
}

function handleOccupancyStatus(status) {
    userResponses.occupancyStatus = status;
    addUserMessage(status);
    if (status === 'Occupying') {
        askPropertyValue();
    } else {
        askPropertyValue(() => askAboutLiabilityIncrease());
    }
}

function askPropertyValue(callback = askAboutHouseholdItems) {
    addBotMessage("Could you tell me how much you paid for the property? For example, if you've bought a flat, how much did you buy it for? And if you're building a property, what's the cost of the actual building (not including workman wages) in Ksh", () => {
        waitForInput((value) => {
            userResponses.propertyValue = value;
            addUserMessage(value);
            addBotMessage("Thanks.", () => {
                callback();
            });
        });
    });
}

function askRentAmount() {
    addBotMessage("And how much do you pay in rent on a monthly basis? in Ksh", () => {
        waitForInput(handleRentAmount);
    });
}

function handleRentAmount(amount) {
    userResponses.rentAmount = amount;
    addUserMessage(amount);
    addBotMessage("Got it.", () => {
        askAboutHouseholdItems();
    });
}

function askAboutHouseholdItems() {
    const items = [
        "Furniture, fixtures and fittings",
        "Electrical appliances (washing machine etc)",
        "Paintings and valuable artefacts",
        "Cutlery, glass- and kitchenware",
        "Household linen",
        "Photography equipment",
        "Jewellery and valuables like luxury watches"
    ];
    addBotMessage("Take a look at the following list and let me know the estimated value of each please:", () => {
        createInputList(items, handleHouseholdItemsValues);
    });
}

function handleHouseholdItemsValues(values) {
    userResponses.householdItems = values;
    addUserMessage(Object.entries(values).map(([item, value]) => `${item}: ${value}`).join(', '));
    addBotMessage("Cheers.", () => {
        askAboutElectronics();
    });
}

function askAboutElectronics() {
    const items = [
        "Phones (up to 3)",
        "Laptops (up to 2)",
        "Tablets",
        "Music Players",
        "Cameras"
    ];
    addBotMessage("And what about these? Do you have any of them in your house? Please enter the quantity for each:", () => {
        createInputList(items, handleElectronicsQuantities);
    });
}

function handleElectronicsQuantities(quantities) {
    userResponses.electronics = quantities;
    addUserMessage(Object.entries(quantities).map(([item, quantity]) => `${item}: ${quantity}`).join(', '));
    addBotMessage("Great.", () => {
        askAboutElectronicsDetails('Phones', 0);
    });
}

function askAboutElectronicsDetails(itemType, index) {
    const itemLimits = {
        'Phones': 3,
        'Laptops': 2,
        'Tablets': 5,
        'Music Players': 5,
        'Cameras': 5
    };

    const exampleModels = {
        'Phones': 'iPhone 14 Pro',
        'Laptops': 'MacBook Air M2',
        'Tablets': 'iPad Pro 12.9-inch',
        'Music Players': 'Sony Walkman',
        'Cameras': 'Sony Alpha A7 IV'
    };

    const maxCount = itemLimits[itemType] || 1;
    const quantity = parseInt(userResponses.electronics[`${itemType} (up to ${maxCount})`] || userResponses.electronics[itemType]) || 0;

    if (index < quantity) {
        const exampleModel = exampleModels[itemType] || 'your device';
        addBotMessage(`What make and model is your ${itemType.slice(0, -1)} ${index + 1}? For example, ${exampleModel}`, () => {
            waitForInput((model) => handleElectronicsModel(itemType, index, model));
        });
    } else {
        const nextItemType = getNextItemType(itemType);
        if (nextItemType) {
            askAboutElectronicsDetails(nextItemType, 0);
        } else {
            askAboutHouseholdEmployees();
        }
    }
}

function handleElectronicsModel(itemType, index, model) {
    if (!userResponses[itemType]) userResponses[itemType] = [];
    userResponses[itemType][index] = { model: model };
    addUserMessage(model);
    addBotMessage(`Thanks. And how much did you pay for this ${itemType.slice(0, -1)}?`, () => {
        waitForInput((value) => handleElectronicsValue(itemType, index, value));
    });
}

function handleElectronicsValue(itemType, index, value) {
    userResponses[itemType][index].value = value;
    addUserMessage(value);
    addBotMessage("Thanks.", () => {
        askAboutElectronicsDetails(itemType, index + 1);
    });
}

function getNextItemType(currentItemType) {
    const itemOrder = ['Phones', 'Laptops', 'Tablets', 'Music Players', 'Cameras'];
    const currentIndex = itemOrder.indexOf(currentItemType);
    return currentIndex >= 0 && currentIndex < itemOrder.length - 1 ? itemOrder[currentIndex + 1] : null;
}

function askAboutHouseholdEmployees() {
    const employees = [
        "Gardener",
        "Indoor workers including maids and cooks",
        "Watchman"
    ];
    addBotMessage("Do you employ any of the following in your household? Indicate how many of each please.", () => {
        createInputList(employees, handleHouseholdEmployeesCount);
    });
}

function handleHouseholdEmployeesCount(counts) {
    userResponses.householdEmployees = counts;
    addUserMessage(Object.entries(counts).map(([employee, count]) => `${employee}: ${count}`).join(', '));
    const employeesWithCount = Object.entries(counts).filter(([_, count]) => parseInt(count) > 0);
    if (employeesWithCount.length > 0) {
        askAboutEmployeeSalaries(employeesWithCount, 0);
    } else {
        addBotMessage("Alright, no household employees.", () => {
            askAboutLiabilityIncrease();
        });
    }
}

function askAboutEmployeeSalaries(employees, index) {
    if (index < employees.length) {
        const [employee, count] = employees[index];
        addBotMessage(`How much are you paying your ${employee}${count > 1 ? 's' : ''} annually?`, () => {
            waitForInput((salary) => handleEmployeeSalary(employee, salary, employees, index));
        });
    } else {
        addBotMessage("Perfect, thanks.", () => {
            askAboutLiabilityIncrease();
        });
    }
}

function handleEmployeeSalary(employee, salary, employees, index) {
    if (!userResponses.employeeSalaries) userResponses.employeeSalaries = {};
    userResponses.employeeSalaries[employee] = salary;
    addUserMessage(salary);
    askAboutEmployeeSalaries(employees, index + 1);
}

function askAboutLiabilityIncrease() {
    addBotMessage("Finally, something may happen in your household that racks up legal fees. It could be an injury to a neighbour or something else.", () => {
        addBotMessage("You're covered for up to 2 million shillings on owner's and occupier's liability, however you can add additional cover on either or both if you like - at an additional premium", () => {
            addBotMessage("Would you like to increase the limit for either or both?", () => {
                const buttons = createButtons(['Owners liability', 'Occupiers liability', 'Both', 'Neither'], handleLiabilityIncreaseChoice);
                appendToChat(buttons);
            });
        });
    });
}

function handleLiabilityIncreaseChoice(choice) {
    userResponses.liabilityIncreaseChoice = choice;
    addUserMessage(choice);
    if (choice === 'Both') {
        askAboutOwnersLiability();
    } else if (choice === 'Owners liability') {
        askAboutOwnersLiability();
    } else if (choice === 'Occupiers liability') {
        askAboutOccupiersLiability();
    } else {
        askAboutAdditionalCover();
    }
}

function askAboutOwnersLiability() {
    addBotMessage("Okay. Let's start with owner's liability. How much cover would you like?", () => {
        const buttons = createButtons(['3 million', '5 million'], handleOwnersLiabilityAmount);
        appendToChat(buttons);
    });
}

function handleOwnersLiabilityAmount(amount) {
    userResponses.ownersLiabilityAmount = amount;
    addUserMessage(amount);
    addBotMessage("Got it.", () => {
        if (userResponses.liabilityIncreaseChoice === 'Both') {
            askAboutOccupiersLiability();
        } else {
            askAboutAdditionalCover();
        }
    });
}

function askAboutOccupiersLiability() {
    addBotMessage("And what about Occupier's?", () => {
        const buttons = createButtons(['3 million', '5 million'], handleOccupiersLiabilityAmount);
        appendToChat(buttons);
    });
}

function handleOccupiersLiabilityAmount(amount) {
    userResponses.occupiersLiabilityAmount = amount;
    addUserMessage(amount);
    addBotMessage("Noted.", () => {
        askAboutAdditionalCover();
    });
}

function askAboutAdditionalCover() {
    addBotMessage("Oh one more thing. Would you like to add any of the following to your cover?", () => {
        const options = [
            "Fire started by faulty electrical",
            "Architectural fee in case of damage",
            "Debris removal",
            "None thank you"
        ];
        const checkboxes = createCheckboxes(options, handleAdditionalCoverChoices);
        appendToChat(checkboxes);
    });
}

function handleAdditionalCoverChoices(choices) {
    userResponses.additionalCover = choices;
    addUserMessage(choices.join(", "));
    addBotMessage("Let me crunch some numbers, will only be a sec.", () => {
        setTimeout(() => {
            addBotMessage("I've worked it out and you're looking at 7,000 shillings a month for your domestic package cover. Would you like to purchase this now?", () => {
                const buttons = createYesNoButtons(handlePurchaseDecision);
                appendToChat(buttons);
            });
        }, 2000);
    });
}

function handlePurchaseDecision(decision) {
    addUserMessage(decision ? "Yes" : "No");
    if (decision) {
        addBotMessage("Processing payment...");
        // Add logic for payment processing
        saveUserResponses();
    } else {
        addBotMessage("No problem, I've saved your quote for you in case you change your mind.");
        saveUserResponses();
    }
}


function saveUserResponses() {
    const formData = new FormData();
    
    // Append all user responses to formData
    formData.append('ownership_status', userResponses.ownershipStatus);
    formData.append('occupancy_status', userResponses.occupancyStatus);
    formData.append('property_value', userResponses.propertyValue);
    formData.append('rent_amount', userResponses.rentAmount);
    
    // Household items
    formData.append('furniture_value', userResponses.householdItems['Furniture, fixtures and fittings']);
    formData.append('electrical_appliances_value', userResponses.householdItems['Electrical appliances (washing machine etc)']);
    formData.append('paintings_value', userResponses.householdItems['Paintings and valuable artefacts']);
    formData.append('kitchenware_value', userResponses.householdItems['Cutlery, glass- and kitchenware']);
    formData.append('household_linen_value', userResponses.householdItems['Household linen']);
    formData.append('photography_equipment_value', userResponses.householdItems['Photography equipment']);
    formData.append('jewellery_value', userResponses.householdItems['Jewellery and valuables like luxury watches']);

    // Electronics
    formData.append('phones_quantity', userResponses.electronics['Phones (up to 3)']);
    formData.append('laptops_quantity', userResponses.electronics['Laptops (up to 2)']);
    formData.append('tablets_quantity', userResponses.electronics['Tablets']);
    formData.append('music_players_quantity', userResponses.electronics['Music Players']);
    formData.append('cameras_quantity', userResponses.electronics['Cameras']);

    // Electronic details (assuming up to 3 phones and 2 laptops)
    for (let i = 0; i < 3; i++) {
        if (userResponses.Phones && userResponses.Phones[i]) {
            formData.append(`phone_${i+1}_model`, userResponses.Phones[i].model);
            formData.append(`phone_${i+1}_value`, userResponses.Phones[i].value);
        }
    }
    for (let i = 0; i < 2; i++) {
        if (userResponses.Laptops && userResponses.Laptops[i]) {
            formData.append(`laptop_${i+1}_model`, userResponses.Laptops[i].model);
            formData.append(`laptop_${i+1}_value`, userResponses.Laptops[i].value);
        }
    }

    // Household employees
    formData.append('gardeners_count', userResponses.householdEmployees['Gardener']);
    formData.append('indoor_workers_count', userResponses.householdEmployees['Indoor workers including maids and cooks']);
    formData.append('watchmen_count', userResponses.householdEmployees['Watchman']);

    // Employee salaries
    if (userResponses.employeeSalaries) {
        formData.append('gardener_salary', userResponses.employeeSalaries['Gardener']);
        formData.append('indoor_workers_salary', userResponses.employeeSalaries['Indoor workers including maids and cooks']);
        formData.append('watchman_salary', userResponses.employeeSalaries['Watchman']);
    }

    // Liability increase
    formData.append('liability_increase_choice', userResponses.liabilityIncreaseChoice);
    formData.append('owners_liability_amount', userResponses.ownersLiabilityAmount);
    formData.append('occupiers_liability_amount', userResponses.occupiersLiabilityAmount);

    // Additional cover
    formData.append('additional_cover', JSON.stringify(userResponses.additionalCover));

    // Purchase decision
    formData.append('purchase_decision', userResponses.purchaseDecision);

    // Log the data being saved
    for (let [key, value] of formData.entries()) {
        console.log(key, value);
    }

    fetch('/residentialproperty/save', {
    method: 'POST',
    body: formData,
    headers: {
        'X-CSRF-TOKEN': document.querySelector('meta[name="csrf-token"]').getAttribute('content')
    }
})
.then(response => {
    if (!response.ok) {
        return response.text().then(text => { throw new Error(text); });
    }
    return response.json();
})
.then(data => {
    console.log('Success:', data);
    addBotMessage('Your details have been saved successfully. Redirecting you to the dashboard...');
    setTimeout(() => {
        window.location.href = '/dashboard';
    }, 3000);
})
.catch((error) => {
    console.error('Error:', error);
    addBotMessage('There was an error saving your details. Please try again.');
});


}







function createInputList(items, callback) {
    const listContainer = document.createElement('div');
    listContainer.className = 'input-list';

    items.forEach(item => {
        const itemContainer = document.createElement('div');
        itemContainer.className = 'input-item';

        const label = document.createElement('label');
        label.textContent = item;
        label.setAttribute('for', item);

        const input = document.createElement('input');
        input.type = 'number';
        input.min = '0';
        input.id = item; // Set the id for the input field

        itemContainer.appendChild(label);
        itemContainer.appendChild(input);
        listContainer.appendChild(itemContainer);
    });

    const submitButton = document.createElement('button');
    submitButton.textContent = 'Submit';
    submitButton.className = 'submit-button';
    submitButton.onclick = () => {
        const values = {};
        items.forEach(item => {
            const input = document.getElementById(item); // Use the id to select the input field
            values[item] = input.value || '0';
        });
        listContainer.remove();
        callback(values);
    };
    listContainer.appendChild(submitButton);

    appendToChat(listContainer);
}

// Helper functions for creating UI elements
function createYesNoButtons(callback) {
    return createButtons(['Yes', 'No'], (response) => callback(response === 'Yes'), 'continue-cancel-buttons');
}

function createButtons(options, callback) {
    const buttonsContainer = document.createElement('div');
    buttonsContainer.className = 'continue-cancel-buttons';
    options.forEach(option => {
        const button = document.createElement('button');
        button.textContent = option;
        button.className = 'continue-cancel-buttons';
        button.onclick = () => {
            buttonsContainer.remove();
            callback(option);
        };
        buttonsContainer.appendChild(button);
    });
    return buttonsContainer;
}


function createCheckboxes(options, callback) {
    const checkboxesContainer = document.createElement('div');
    checkboxesContainer.className = 'checkboxes-container';
    options.forEach(option => {
        const label = document.createElement('label');
        label.className = 'checkbox-label';
        const checkbox = document.createElement('input');
        checkbox.type = 'checkbox';
        checkbox.value = option;
        checkbox.className = 'chat-checkbox';
        label.appendChild(checkbox);
        label.appendChild(document.createTextNode(option));
        checkboxesContainer.appendChild(label);
    });

    const confirmButtonContainer = document.createElement('div');
    confirmButtonContainer.className = 'checkbox-btns-container';
    const confirmButton = document.createElement('button');
    confirmButton.textContent = 'Confirm';
    confirmButton.className = 'checkbox-btns';
    confirmButton.onclick = () => {
        const selectedOptions = Array.from(checkboxesContainer.querySelectorAll('input:checked')).map(cb => cb.value);
        checkboxesContainer.remove();
        callback(selectedOptions);
    };
    confirmButtonContainer.appendChild(confirmButton);
    checkboxesContainer.appendChild(confirmButtonContainer);

    return checkboxesContainer;
}

function createButton(text, callback) {
    const button = document.createElement('button');
    button.textContent = text;
    button.className = 'continue-cancel-buttons';
    button.onclick = () => {
        button.remove();
        callback();
    };
    return button;
}


// Functions for adding messages to the chat
function addUserMessage(message) {
        const chatMessages = document.querySelector('.chat-messages');

        // Use Blade syntax to insert the PHP variables into the JavaScript function
        let userImagePath = `{{ $selfieExists ? asset($selfiePath) : asset('images/default-avatar.png') }}`;

        const userMessage = document.createElement('div');
        userMessage.classList.add('message', 'user-message');
        userMessage.innerHTML = `
            <div class="message-content">
                ${message}
            </div>
            <img src="${userImagePath}" alt="User">
        `;
        chatMessages.appendChild(userMessage);
        scrollToBottom();
    }

function addLoadingDots(callback) {
        const chatMessages = document.querySelector('.chat-messages');
        const loadingContainer = document.createElement('div');
        loadingContainer.classList.add('message', 'bot-message', 'loading');
        loadingContainer.innerHTML = `
            <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
            <div class="loading-dots">
                <div class="loading-dot"></div>
                <div class="loading-dot"></div>
                <div class="loading-dot"></div>
            </div>
        `;
        chatMessages.appendChild(loadingContainer);
        scrollToBottom();

        setTimeout(() => {
            loadingContainer.remove();
            callback();
        }, 2000);
    }

    function addBotMessage(message, callback) {
        addLoadingDots(() => {
            const chatMessages = document.querySelector('.chat-messages');
            const botMessage = document.createElement('div');
            botMessage.classList.add('message', 'bot-message');
            botMessage.innerHTML = `
                <img src="{{ asset('landing/Prince_avatar.png') }}" alt="Prince">
                <div class="message-content">
                    ${message}
                </div>
            `;
            chatMessages.appendChild(botMessage);
            scrollToBottom();
            if (callback) callback();
        });
    }



function appendToChat(element) {
    document.querySelector('.chat-messages').appendChild(element);
    scrollToBottom();
}

function scrollToBottom() {
    window.scrollTo(0, document.body.scrollHeight)
}

// Functions for handling user input
function waitForInput(callback) {
    waitingForInput = true;
    currentInputHandler = callback;
    
}

function handleUserInput() {
    if (!waitingForInput) return;

    const inputField = document.querySelector('.chat-input input');
    const userInput = inputField.value.trim();
    if (userInput === '') return;

    addUserMessages(userInput);
    inputField.value = '';
    toggleSendButton();

    waitingForInput = false;
    const handler = currentInputHandler;
    currentInputHandler = null;
    handler(userInput);
}
// Functions for adding messages to the chat
function addUserMessages(message) {
    const chatMessages = document.querySelector('.chat-messages');
    const userMessage = document.createElement('div');
    userMessage.classList.add('message', 'user-message');
    userMessage.innerHTML = `
        <div class="message-content">
            ${message}
        </div>
        <img src="user-profile.png" alt="User">
    `;
    //chatMessages.appendChild(userMessage);
    scrollToBottom();
}

function toggleSendButton() {
    const inputField = document.querySelector('.chat-input input');
    const sendButton = document.querySelector('.bi-send');
    const cameraMicButtons = document.querySelectorAll('.bi-camera-mic-buttons');

    if (inputField.value.trim() !== '' || waitingForInput) {
        sendButton.style.display = 'block';
        cameraMicButtons.forEach(button => button.style.display = 'none');
    } else {
        sendButton.style.display = 'none';
        cameraMicButtons.forEach(button => button.style.display = 'block');
    }
}

// Event listeners
document.querySelector('.chat-input input').addEventListener('input', toggleSendButton);
document.querySelector('.send-button').addEventListener('click', handleUserInput);
document.querySelector('.chat-input input').addEventListener('keypress', function(e) {
    if (e.key === 'Enter') {
        e.preventDefault(); // Prevent default form submission
        handleUserInput();
    }
});



// Initialize the chat when the page loads
window.onload = initChat;
    </script>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
</body>
</html>