<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Medical Insurance Rate Calculator</title>
    <link href="https://fonts.googleapis.com/css2?family=Open+Sans:wght@500&family=Lato:wght@400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: "Lato", Sans-serif;
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            margin: 0;
            background-color: black;
            color: white;
            font-size: 15px;
            line-height: 2.1em;
            font-weight: 400;
        }
        .calculator {
            background-color: #1a1a1a;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(255,255,255,0.1);
            width: 100%;
            max-width: 1000px;
        }
        h1 {
            font-family: "Open Sans", Sans-serif;
            font-size: 24px;
            line-height: 2.1em;
            font-weight: 500;
            text-align: center;
            margin-bottom: 20px;
        }
        .row {
            display: flex;
            justify-content: space-between;
            gap: 10px;
            margin-bottom: 20px;
        }
        select {
            flex: 1;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-family: "Lato", Sans-serif;
            font-size: 15px;
            line-height: 2.1em;
            background-color: #2a2a2a;
            color: white;
        }
        #result {
            font-size: 24px;
            font-weight: bold;
            text-align: center;
            margin-bottom: 20px;
        }
        button, .button {
            display: block;
            width: 100%;
            padding: 10px;
            background-color: #AB1F74;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-family: "Lato", Sans-serif;
            font-size: 18px;
            font-weight: 700;
            transition: background-color 0.3s ease;
            text-align: center;
            text-decoration: none;
        }
        button:hover, .button:hover {
            background-color: #ceb78d;
        }
    </style>
</head>
<body>
    <div class="calculator">
        <h1>Medical Insurance</h1>
        <div class="row">
            <select id="coverage">
                <option value="">How much cover do you want?</option>
                <option value="250,000">250,000</option>
                <option value="500,000">500,000</option>
                <option value="1M">1M</option>
                <option value="2M">2M</option>
                <option value="2.5M">2.5M</option>
                <option value="3M">3M</option>
                <option value="4M">4M</option>
                <option value="5M">5M</option>
                <option value="6M">6M</option>
                <option value="7M">7M</option>
                <option value="8M">8M</option>
                <option value="9M">9M</option>
                <option value="10M">10M</option>
            </select>
            <select id="over19">
                <option value="">How many people over 19 on your cover?</option>
                <option value="0">0</option>
                <option value="1">1</option>
                <option value="2">2</option>
                <option value="3">3</option>
                <option value="4">4</option>
                <option value="5">5</option>
                <option value="6">6</option>
            </select>
            <select id="under19">
                <option value="">How many people under 19 on your cover?</option>
                <option value="0">0</option>
                <option value="1">1</option>
                <option value="2">2</option>
                <option value="3">3</option>
                <option value="4">4</option>
                <option value="5">5</option>
                <option value="6">6</option>
            </select>
        </div>
        <div class="container">
    <div id="result">Ksh 0</div>
    <div>
        <a href="/register" id="buyNowLink" class="button">Buy now</a>
    </div>
    <div>
        <a href="/golfers" class="button" id="golfersButton">Go to golfers</a>
    </div>
</div>


    <script>
       const rateTable = {
            '250,000': [14715, 19865, 25825, 32281, 38737, 46485, 55782],
            '500,000': [20574, 27775, 36107, 45134, 54161, 64993, 77992],
            '1M': [27698, 37392, 48610, 60762, 72915, 87498, 104998],
            '2M': [29499, 39824, 51771, 64713, 77656, 93187, 111825],
            '2.5M': [30230, 40811, 53054, 66317, 79580, 95497, 114596],
            '3M': [32127, 43371, 56383, 70478, 84574, 101489, 121786],
            '4M': [35340, 47708, 62021, 77526, 93031, 111638, 133965],
            '5M': [38873, 52479, 68223, 85279, 102334, 122801, 147362],
            '6M': [42761, 57727, 75045, 93807, 112568, 135081, 162098],
            '7M': [44899, 60613, 78797, 98497, 118196, 141835, 170203],
            '8M': [47144, 63644, 82737, 103422, 124106, 148927, 178713],
            '9M': [49501, 66826, 86874, 108593, 130311, 156374, 187648],
            '10M': [51976, 70168, 91218, 114022, 136827, 164192, 197031]
        };

        const coverageSelect = document.getElementById('coverage');
        const over19Select = document.getElementById('over19');
        const under19Select = document.getElementById('under19');
        const resultDiv = document.getElementById('result');
        const buyNowLink = document.getElementById('buyNowLink');

        function calculateRate() {
            const coverage = coverageSelect.value;
            const over19 = parseInt(over19Select.value);
            const under19 = parseInt(under19Select.value);

            if (coverage && !isNaN(over19) && !isNaN(under19)) {
                const rateIndex = Math.min(over19, 6);
                const rate = rateTable[coverage][rateIndex];
                resultDiv.textContent = `Ksh${rate.toLocaleString()}`;
                updateBuyNowLink(coverage, over19, under19, rate);
            } else {
                resultDiv.textContent = 'Ksh0';
                updateBuyNowLink('', '', '', 0);
            }
        }

        function updateBuyNowLink(coverage, over19, under19, amount) {
            const params = new URLSearchParams({
                coverage: coverage,
                over19: over19,
                under19: under19,
                amount: amount
            });
            buyNowLink.href = `/register?${params.toString()}`;
        }

        coverageSelect.addEventListener('change', calculateRate);
        over19Select.addEventListener('change', calculateRate);
        under19Select.addEventListener('change', calculateRate);

        // Console logging for form submission (assuming there's a form on the /register page)
        buyNowLink.addEventListener('click', function(e) {
            e.preventDefault();
            console.log('Selected options:');
            console.log('Coverage:', coverageSelect.value);
            console.log('Over 19:', over19Select.value);
            console.log('Under 19:', under19Select.value);
            console.log('Amount:', resultDiv.textContent);
            window.location.href = this.href;
        });
    </script>
</body>
</html>