<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Crownscope Insurance Dashboard</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/3.7.0/chart.min.js"></script>
    <style>
        body, html {
            margin: 0;
            padding: 0;
            font-family: Lato, sans-serif;
            background-color: #f0f0f0;
            height: 100%;
        }
        .container {
            min-height: 100%;
            display: flex;
            flex-direction: column;
            background-color: white;
        }
     
        
        /* Update the .kpi-section class */
        .kpi-section {
            display: flex;
            flex-direction: column;
            gap: 20px;
            height: calc(100% - 40px); /* Subtract padding to align with charts */
        }

        
        /* Update the .kpi-item class */
        .kpi-item {
            background-color: #f1f1f1;
            border-radius: 8px;
            padding: 20px;
            height: calc(15% - 16px); /* Equal height distribution with gap consideration */
            min-height: 100px; /* Minimum height to prevent squishing */
            font-size: 14px;
        }
        .kpi-item:first-child {
            font-size: 12px;
        }
        .kpi-title {
            font-size: 12px;
            color: black;
        }
        .kpi-value {
        font-size: 24px;
        font-weight: bold;
        color: #8d779C;
        display: flex;
        justify-content: center; /* Horizontal centering */
        align-items: center;     /* Vertical centering */
        height: 100%;            /* Ensure the content takes full height of its parent */
        }

        /* Update the .charts class */
.charts {
    display: grid;
    grid-template-columns: repeat(2, 1fr);
    grid-template-rows: repeat(2, 1fr);
    gap: 20px;
    height: 100%;
}

/* Update the .chart-container class */
.chart-container {
    background-color: #f1f1f1;
    border-radius: 10px;
    padding: 20px;
    height: auto;
    min-height: 200px;
}

/* Update the .sidebar class */
/* Update the existing sidebar styles */
.sidebar {
    background-color: #f1f1f1;
    padding: 20px;
    border-radius: 5px;
    text-align: center;
    height: calc(100% - 40px);
    overflow-y: auto;
}

/* Add styles for the header section */
.sidebar > p {
    font-weight: bold;
    padding-bottom: 15px;
}

/* Update the update-link styles */
.update-link {
    text-decoration: none;
    color: inherit;
    display: block;
    position: relative;
    margin-bottom: -1px;
}

/* Line above each item */
.update-link::before {
    content: '';
    position: absolute;
    top: 0;
    left: 50%;
    transform: translateX(-50%);
    width: 80%;
    height: 1px;
    background-color: #8D779C;
}

/* Line below the last item */
.update-link:last-child::after {
    content: '';
    position: absolute;
    bottom: 10;
    left: 50%;
    transform: translateX(-50%);
    width: 80%;
    height: 1px;
    background-color: #8D779C;
}

/* Update the update-item styles */
.update-item {
    display: flex;
    align-items: center;
    padding: 10px 0; /* Add padding above and below content */
    cursor: pointer;
    text-align: left;
}

/* Hover effect */
.update-link:hover {
    background-color: #f8f8f8;
}

/* Remove border from the last item */
.update-link:last-child {
    border-bottom: none;
}
/* Targeting the hover state for the 'update-link' class */
.update-link:hover .update-text p strong {
    color: #ab1f74; /* Pink color on hover */
}


        .profile-pic {
            width: 50%;
            max-width: 100px;
            border-radius: 50%;
            margin-bottom: -10%;
        }


    


        .update-item {
            display: flex;
            align-items: center;
            margin-bottom: 5px;
            cursor: pointer;
            text-align: left; /* Align content to the left */
        }

        
        .update-item img.profile {
            width: 40px;
            height: 40px;
            margin-right: 15px;
        }
        
        .update-text {
            display: flex;
            flex-direction: column;
        }
        /* Adjust the font size of the text inside the update items */
        .update-text p {
            font-size: 12px; /* Reduced font size */
            margin: 2px 0; /* Adjusts the spacing between lines */
        }
        
        .update-text p strong {
            font-size: 14px; /* Slightly larger for emphasis */
        }
        
        .update-link {
            text-decoration: none;
            color: inherit; /* Keeps text color consistent */
        }
        
        .update-link:hover {
            background-color: #f0f0f0; /* Optional hover effect */
        }
        
        
        @media (min-width: 1440px) {
        .kpi-section {
                gap: 55px; /* Increase gap for a more spacious layout */
            }
            nav a {
            font-size: 28px;
            }
            .profile-pic {
            margin-bottom: 0%;
        }

    }
    </style>
</head>
<body>
    <div class="container">
        
    <?php echo $__env->make('admin.partials.header', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
                <?php
        // Helper function to format numbers
        function formatNumber($number, $noDecimal = false) {
            if ($number >= 1000000) {
                return number_format($number / 1000000, $noDecimal ? 0 : 2) . 'M';
            } elseif ($number >= 1000) {
                return number_format($number / 1000, $noDecimal ? 0 : 2) . 'K';
            } else {
                return number_format($number, $noDecimal ? 0 : 2);
            }
        }
        ?>
        
        <div class="content">
            <div class="kpi-section">
                <div class="kpi-item">
                    <div class="kpi-title">Gross premium</div>
                    <div class="kpi-value"><?php echo e(formatNumber($totalGrossPremium)); ?></div>
                </div>
                <div class="kpi-item">
                    <div class="kpi-title">Claims settled</div>
                    <div class="kpi-value"><?php echo e(formatNumber($claimsSettledCount, true)); ?></div> <!-- No decimal -->
                </div>
                <div class="kpi-item">
                    <div class="kpi-title">Claim settlement amount</div>
                    <div class="kpi-value"><?php echo e(formatNumber($totalClaimSettlement)); ?></div>
                </div>
                <div class="kpi-item">
                    <div class="kpi-title">Net premium</div>
                    <div class="kpi-value"><?php echo e(formatNumber($netPremium)); ?></div>
                </div>
                <div class="kpi-item">
                    <div class="kpi-title">Total policies issued</div>
                    <div class="kpi-value"><?php echo e(formatNumber(5, true)); ?></div> <!-- No decimal -->
                </div>
            </div>


            <div class="charts">
                <div class="chart-container">
                    <canvas id="salesPerformanceChart"></canvas>
                </div>
                <div class="chart-container">
                    <canvas id="monthlySalesChart"></canvas>
                </div>
                <div class="chart-container">
                    <canvas id="claimsChart"></canvas>
                </div>
                <div class="chart-container">
                    <canvas id="claimsOpenClosedChart"></canvas>
                </div>
            </div>
            <div class="sidebar">
    <img src="<?php echo e(asset('landing/Prince_avatar.png')); ?>" alt="Prince Avatar" class="profile-pic">
    <p>Latest from Prince</p>

    <?php $__currentLoopData = $latestClaims; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $claim): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    <a href="/claims/<?php echo e($claim->claim_number); ?>" class="update-link">
        <div class="update-item">
            <img src="<?php echo e(asset('landing/Prince_avatar.png')); ?>" alt="Profile picture" class="profile" />
            <div class="update-text">
                <p><strong><?php echo e($claim->status === 'pending' ? 'Pending Claim' : 'New claim'); ?></strong></p>
                <p><?php echo e($claim->claim_number); ?></p>
                <p><?php echo e($claim->date_filed->format('d F Y | H:i')); ?></p>
            </div>
        </div>
    </a>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

    <?php if($claimsPendingSummary->count()): ?>
    <a href="/claims/pending" class="update-link">
        <div class="update-item">
            <img src="<?php echo e(asset('landing/Prince_avatar.png')); ?>" alt="Profile picture" class="profile" />
            <div class="update-text">
                <p><strong><?php echo e($claimsPendingSummary->count()); ?> claims pending</strong></p>
                <?php $__currentLoopData = $claimsPendingSummary; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $policy => $count): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <p><?php echo e($count); ?> <?php echo e($policy); ?> claim<?php echo e($count > 1 ? 's' : ''); ?></p>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
        </div>
    </a>
    <?php endif; ?>
</div>

        </div>
    </div>

    <script>
    function calculatePercentages(values) {
        // Convert all values to numbers to ensure accurate calculations
        const numericValues = values.map(value => Number(value));
        
        const total = numericValues.reduce((acc, val) => acc + val, 0);
        
        // Handle cases where the total is zero
        if (total === 0) {
            return numericValues.map(() => "0.00"); 
        }
        
        return numericValues.map(value => ((value / total) * 100).toFixed(2));
    }

    const salesPerformanceData = <?php echo json_encode(array_values($salesPerformanceData), 15, 512) ?>;
    console.log('Original Sales Performance Data:', salesPerformanceData); 

    const salesLabels = ['Residential Property', 'Golfers', 'Accident', 'Travel', 'Medical'];

    const salesPercentages = calculatePercentages(salesPerformanceData);
    console.log('Sales Percentages:', salesPercentages); 

    new Chart(document.getElementById('salesPerformanceChart'), {
        type: 'doughnut',
        data: {
            labels: salesLabels,
            datasets: [{
                label: 'Sales Performance',
                data: salesPerformanceData,
                backgroundColor: ['#ceb78d', '#351c43', '#7f6561', '#ab1f74', '#c18ab2'],
                borderWidth: 0
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                title: {
                    display: true,
                    text: 'Sales Performance by Policy (in %)',
                    padding: 1
                },
                legend: {
                    display: true,
                    position: 'top',
                    labels: {
                        padding: 5,
                        font: {
                            size: 10
                        }
                    }
                },
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            const index = context.dataIndex;
                            const percentage = salesPercentages[index];
                            return context.label + ': ' + percentage + '%';
                        }
                    }
                }
            }
        }
    });




   // Monthly Sales Performance Line Chart
const monthlySalesData = <?php echo json_encode(array_values($monthlySalesData), 15, 512) ?>;
const months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];

// Calculate max dynamically
const maxSalesValue = Math.max(...monthlySalesData);
const yAxisMax = Math.ceil((maxSalesValue + 10000) / 10000) * 10000; // Round to nearest 10,000

new Chart(document.getElementById('monthlySalesChart'), {
    type: 'line',
    data: {
        labels: months,
        datasets: [{
            label: 'Monthly Sales',
            data: monthlySalesData,
            backgroundColor: '#1FAB56',
            borderColor: '#1FAB56',
            borderWidth: 1,
            fill: false
        }]
    },
    options: {
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
            title: {
                display: true,
                text: 'Monthly Sales Performance'
            },
            legend: {
                display: false
            }
        },
        elements: {
            point: {
                radius: 0, // Hide points by default
                hoverRadius: 6, // Show points on hover
                hitRadius: 8 // Increase hit area for better hover detection
            },
            line: {
                tension: 0.4 // Optional: makes the line slightly curved
            }
        },
        interaction: {
            intersect: false, // Makes it easier to hover
            mode: 'index' // Shows tooltip for the nearest point
        },
        scales: {
            x: {
                grid: {
                    display: false // Hide grid lines on x-axis
                }
            },
            y: {
                beginAtZero: true,
                max: yAxisMax, // Use the dynamically calculated max value
                grid: {
                    display: false // Hide grid lines on y-axis
                },
                ticks: {
                    callback: function(value) {
                        if (value >= 1000000) {
                            return value / 1000000 + 'M'; // Format millions
                        } else if (value >= 1000) {
                            return value / 1000 + 'K'; // Format thousands
                        }
                        return value; // Return value as is
                    }
                }
            }
        }
    }
});



   // Claims by Cover Type Pie Chart
const claimsByPolicyData = <?php echo json_encode(array_values($claimsByPolicyData), 15, 512) ?>;
const totalClaims = claimsByPolicyData.reduce((sum, value) => sum + value, 0);  // Calculate total claims
const claimsPercentages = claimsByPolicyData.map(value => (value / totalClaims) * 100); // Calculate percentages

new Chart(document.getElementById('claimsChart'), {
    type: 'pie',
    data: {
        labels: salesLabels, // Assuming you have defined `salesLabels` somewhere before this
        datasets: [{
            label: 'Claims',
            data: claimsByPolicyData,
            backgroundColor: ['#617b7f', '#8da4ce', '#8d779c', '#ab1f74', '#8ac199'],
            borderWidth: 0 // Removed borders
        }]
    },
    options: {
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
            title: {
                display: true,
                text: 'Claims by Cover Type (in %)',
                padding: 1
            },
            legend: {
                display: true,
                position: 'top', // Moves legend to the top
                
                labels: {
                    
                    padding: 5,   // Padding between items
                    font: {
                        size: 10 // Reduced legend font size
                    }
                }
            },
            tooltip: {
                callbacks: {
                    label: function(context) {
                        // Get the index of the data point being hovered
                        const index = context.dataIndex;
                        // Ensure the percentage is correctly fetched
                        const percentage = claimsPercentages[index];
                        if (percentage !== undefined) {
                            // Format the tooltip text to show the label and percentage
                            return context.label + ': ' + percentage.toFixed(2) + '%';
                        } else {
                            return context.label;  // Fallback if percentage is undefined
                        }
                    }
                },
                bodyFont: {
                    size: 12 // Reduced tooltip font size
                }
            }
        }
    }
});


    // Claims Open vs Closed Bar Chart
    new Chart(document.getElementById('claimsOpenClosedChart'), {
        type: 'bar',
        data: {
            labels: months,
            datasets: [{
                label: 'Open Claims',
                data: <?php echo json_encode(array_values($openClaims), 15, 512) ?>,
                backgroundColor: '#1fab56',
                borderWidth: 0 // Transparent borders
            }, {
                label: 'Closed Claims',
                data: <?php echo json_encode(array_values($closedClaims), 15, 512) ?>,
                backgroundColor: '#ab1f74',
                borderWidth: 0 // Transparent borders
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                title: {
                    display: true,
                    text: 'Claims Open vs Closed Monthly',
                    padding: -1
                },
                legend: {
                    display: true,
                    position: 'top',
                    
                labels: {
                    
                    
                    font: {
                        size: 10 // Reduced legend font size
                    }
                }
                }
            },
            scales: {
                y: {
                    beginAtZero: true,
                    grid: {
                        display: false // Remove grid lines
                    }
                }
            }
        }
    });
    </script>
</body>
</html>
<?php /**PATH /home/joqo64qe/public_html/crownscope.dogo-tech.com/resources/views/admin/index.blade.php ENDPATH**/ ?>