<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Notification Centre</title>
    <style>
        /* General Styles */
        body, html {
            margin: 0;
            padding: 0;
            height: 100%;
            font-family: 'Lato', sans-serif;
            background-color: #000;
            color: #fff;
        }

        /* Container */
        .content {
            padding: 20px;
            max-width: 100%;
            width: 65%;
            margin: 0 auto;
        }

        @media (max-width: 768px) {
            .content {
                width: 100%;
                max-width: none;
                padding: 10px;
            }
        }

        /* Logo */
        .logo {
            text-align: center;
            margin-bottom: 20px;
        }

        .logo img {
            height: 100px;
        }

        /* Heading Styles */
        .notification-title {
            font-family: 'Open Sans', sans-serif;
            font-size: 24px;
            line-height: 2.1em;
            font-weight: 500;
            margin-bottom: 10px;
        }

        /* Notification Box */
        .notification {
            background-color: #222;
            border-radius: 10px;
            padding: 15px;
            display: flex;
            flex-direction: column;
            margin-bottom: 15px;
        }

        .notification-content {
            display: flex;
            align-items: flex-start;
        }

        .notification-icon {
            width: 50px;
            height: 50px;
            background-color: #444;
            border-radius: 50%;
            margin-right: 15px;
            overflow: hidden;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .notification-icon img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }

        .notification-text {
            flex-grow: 1;
        }

        .notification-text h3 {
            margin: 0 0 5px 0;
            font-size: 18px;
            font-family: 'Open Sans', sans-serif;
            font-weight: 500;
        }

        .notification-text p {
            margin: 0;
            font-size: 15px;
            line-height: 2.1em;
            font-weight: 400;
            color: #aaa;
        }

        .notification-date {
            font-size: 12px;
            color: #888;
            margin-top: 10px;
            align-self: flex-end;
        }

        /* Buttons */
        .button {
            font-family: 'Lato', sans-serif;
            font-size: 18px;
            font-weight: 700;
            background-color: #AB1F74;
            color: #fff;
            padding: 10px 20px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            text-align: center;
            display: inline-block;
            margin-top: 10px;
        }

        .button:hover {
            background-color: #ceb78d;
        }

        .notification-link {
    text-decoration: none; /* Removes underline from links */
    color: inherit; /* Inherits color from parent element */
    display: block; /* Makes the link behave like a block element */
}
    </style>
</head>
<body>
    <div class="content">
        <div class="logo">
            <img src="<?php echo e(asset('images/Dogo Final logo.png')); ?>" alt="Logo">
        </div>
        <div class="notification-title">Notification Centre</div>
        
        <?php
            $notificationCount = 0;
        ?>

        <!-- Pending Upload Notification -->
        <a href="<?php echo e(route('profile')); ?>" class="notification-link">
            <div class="notification">
                <div class="notification-content">
                    <div class="notification-icon">
                        <img src="<?php echo e(asset('images/Prince AI avatar.png')); ?>" alt="Default Avatar">
                    </div>
                    <div class="notification-text">
                        <?php if(count($missingFields) > 0): ?>
                            <h3>Pending Upload:</h3>
                            <p>Hi, <?php echo e($user->first_name); ?>! Please upload the following missing information:</p>
                            <ul>
                                <?php $__currentLoopData = $missingFields; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $field): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <li><?php echo e($field); ?></li>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </ul>
                            <?php
                                $notificationCount++;
                            ?>
                        <?php else: ?>
                            <h3>All Information Complete</h3>
                            <p>Thank you for providing all the necessary information!</p>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="notification-date">2 August 2024</div>
            </div>
        </a>

        <!-- Pending Payments Notification -->
        <?php
            $pendingItems = [];
            foreach ($paymentStatuses as $coverType => $status) {
                if ($status === 'pending') {
                    $pendingItems[] = $coverType;
                }
            }
        ?>

        <?php if(count($pendingItems) > 0): ?>
            <a href="<?php echo e(route('billing.index')); ?>" class="notification-link">
                <div class="notification">
                    <div class="notification-content">
                        <div class="notification-icon">
                            <img src="<?php echo e(asset('images/Prince AI avatar.png')); ?>" alt="Default Avatar">
                        </div>
                        <div class="notification-text">
                            <h3>Pending Payments:</h3>
                            <p>Hi, <?php echo e($user->first_name); ?>! Please complete the following payments:</p>
                            <ul>
                                <?php $__currentLoopData = $pendingItems; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <li><?php echo e($item); ?></li>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </ul>
                        </div>
                    </div>
                    <div class="notification-date"><?php echo e(\Carbon\Carbon::now()->format('j F Y')); ?></div>
                </div>
            </a>
        <?php else: ?>
            <p>All payments are complete.</p>
        <?php endif; ?>

        <!-- Policy Expiration Notification -->
        <?php if($daysRemaining !== null && $daysRemaining <= 2): ?>
            <div class="notification">
                <div class="notification-content">
                    <div class="notification-icon">
                        <img src="<?php echo e(asset('images/Prince AI avatar.png')); ?>" alt="Default Avatar">
                    </div>
                    <div class="notification-text">
                        <h3>Your <?php echo e($coverType); ?> policy is about to expire</h3>
                        <?php if($autorenew === 'on'): ?>
                            <p>Since auto-renew is on, you don't need to do anything.</p>
                        <?php else: ?>
                            <p>You've chosen not to auto-renew. Click <a href="<?php echo e(route('user.toggleAutoRenew')); ?>">here</a> to renew now or your policy will be cancelled for the following term.</p>
                        <?php endif; ?>
                        <p>Days remaining: <?php echo e($daysRemaining); ?></p> <!-- Display the countdown -->
                        <?php
                            $notificationCount++;
                        ?>
                    </div>
                </div>
                <div class="notification-date">31 July 2024</div>
            </div>
        <?php endif; ?>


        <?php
                            $notificationCount++;
                        ?>
        <!-- Display total number of notifications -->
        <div class="notification-summary">
            <h3>You have <?php echo e($notificationCount); ?> notifications</h3>
        </div>
    </div>
</body>
<script>
   document.addEventListener('DOMContentLoaded', function() {
    var notificationCount = <?php echo e($notificationCount); ?>;

    // Send the update request once when the page is loaded
    fetch('/update-notification-count', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'X-CSRF-TOKEN': '<?php echo e(csrf_token()); ?>'
        },
        body: JSON.stringify({ count: notificationCount })
    })
    .then(response => response.json())
    .then(data => {
        console.log('Notification count updated successfully:', data);
    })
    .catch(error => {
        console.error('Error updating notification count:', error);
    });
});

</script>
</html>
<?php /**PATH /home/joqo64qe/public_html/crownscope.dogo-tech.com/resources/views/user/notifications.blade.php ENDPATH**/ ?>