<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Conversation - <?php echo e($conversation->claim_type); ?></title>
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css">
    <style>
        body {
            font-family: 'Lato', sans-serif;
            background-color: #ffffff;
            display: flex;
            flex-direction: column;
            height: 100vh;
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        .header {
            height: 101px;
            background-color: white;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            padding: 0 20px;
            box-sizing: border-box;
            position: sticky;
            top: 0;
            z-index: 2;
        }

        .header .logo {
            display: flex;
            align-items: center;
            justify-content: center;
            background-color: white;
        }

        .header .logo img {
            width: 100px;
            height: 100px;
            margin-right: 5px;
        }

        .profile {
            display: flex;
            flex-direction: column;
            align-items: center;
            margin-top: 20px;
            box-sizing: border-box;
        }

        .profile img {
            width: 100px;
            height: 100px;
            border-radius: 50%;
        }

        .profile-name {
            font-weight: bold;
            margin-top: 10px;
        }

        .profile-title {
            color: #888;
            font-size: 14px;
        }

        .message {
            display: flex;
            margin-bottom: 20px;
        }

        .message img {
            width: 50px;
            height: 50px;
            border-radius: 50%;
            margin-right: 10px;
        }

        .message-content {
            background-color: #f0f0f0;
            border-radius: 18px;
            padding: 10px 15px;
            max-width: 65%;
            max-height: 95%;
            font-size: 14px;
        }

        .message.bot-message {
            justify-content: flex-start;
        }

        .message.bot-message .message-content {
            background-color: #e4e2dd;
        }

        .message.user-message {
            justify-content: flex-end;
        }

        .message.user-message .message-content {
            background-color: #e6d0de;
        }

        .message.user-message img {
            order: 2;
            margin-right: 0;
            margin-left: 10px;
        }

        .chat-input {
            position: fixed;
            border-radius: 20px;
            bottom: 0;
            left: 0;
            width: 100%;
            height: 60px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 0 10px;
            background-color: #d9d9d9;
            box-sizing: border-box;
            z-index: 1000;
        }

        .chat-input button {
            background: none;
            border: none;
            font-size: 24px;
            color: #FF69B4;
            cursor: pointer;
            padding: 0;
            margin: 0 5px;
        }

        .chat-input input {
            flex-grow: 1;
            border: none;
            padding: 0 10px;
            height: 40px;
            border-radius: 15px;
            margin: 0 5px;
        }

        .chat-input input:focus {
            outline: none;
        }

        .close-icon {
            position: absolute;
            top: 10px;
            right: 10px;
            font-size: 24px;
            color: #AB1F74;
            text-decoration: none;
            cursor: pointer;
        }

        @media (max-width: 768px) {
            .chat-input {
                padding: 0 5px;
            }
            .chat-input button {
                font-size: 20px;
            }
            .chat-input input {
                height: 35px;
                font-size: 14px;
            }
        }

        @media (min-width: 1024px) {
            .container {
                width: 60%;
                margin: 0 auto;
            }
            .chat-input {
                width: 60%;
                left: 20%;
            }
        }
    </style>
</head>
<body class="bg-white">
    <div class="container mx-auto p-4 max-w-2xl">
        <div class=" overflow-hidden">
            <div class="header">
                <div class="logo">
                    <img src="<?php echo e(asset('landing/Dogo_logo_white.png')); ?>" alt="Logo">
                </div>
                <a href="javascript:history.back()" class="close-icon">
                    <i class="bi bi-x"></i>
                </a>
            </div>
            <div class="profile">
                <img src="<?php echo e(asset('landing/Prince_avatar.png')); ?>" alt="Prince">
                <div class="profile-name">Prince</div>
                <div class="profile-title">Personal insurance assistant</div>
                <h1 class="text-lg font-semibold">Claim Type: <?php echo e($conversation->claim_type); ?></h1>
                <p class="text-sm"><?php echo e($conversation->created_at->format('F j, Y g:i A')); ?></p>
            </div>
            <div class="p-4  overflow-y-auto bg-white" id="chat-messages">
                <?php $__currentLoopData = $conversation->conversation; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $message): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <div class="message <?php echo e($message['sender'] === 'bot' ? 'bot-message' : 'user-message'); ?>">
                        <img src="<?php echo e($message['sender'] === 'bot' ? asset('landing/Prince_avatar.png') : asset('user-profile.png')); ?>" alt="<?php echo e($message['sender'] === 'bot' ? 'Prince' : 'User'); ?>">
                        <div class="message-content">
                            <?php echo e($message['message']); ?>

                            <div class="text-xs text-gray-500 mt-1">
                                <?php echo e(\Carbon\Carbon::parse($message['timestamp'])->format('g:i A')); ?>

                            </div>
                        </div>
                    </div>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
        </div>
    </div>
    <div class="chat-input">
        <input type="file" id="fileInput" accept="image/*" style="display: none;">
        <button id="uploadButton"><i class="bi bi-upload"></i></button>
        <input type="text" id="userMessage" placeholder="Type something" style="height: 40px;">
        <button id="cameraButton"><i class="bi bi-camera"></i></button>
        <button id="micButton"><i class="bi bi-mic"></i></button>
        <button id="sendButton"><i class="bi bi-send"></i></button>
    </div>
</body>
</html><?php /**PATH /home/joqo64qe/public_html/crownscope.dogo-tech.com/resources/views/admin/conversations.blade.php ENDPATH**/ ?>