<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Chat Interface</title>
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css">
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.7.1/dist/leaflet.css" />
    <script src="https://unpkg.com/leaflet@1.7.1/dist/leaflet.js"></script>
    <link rel="stylesheet" href="https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.css" />
    <script src="https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.js"></script>
    <script defer src="face-api.min.js"></script>
    <style>
body {
    font-family: 'Open Sans', sans-serif;
    background-color: #ffffff;
    display: flex;
    flex-direction: column; /* Changed to column for better layout management */
    height: 100vh;
    margin: 0;
    padding: 0;
    box-sizing: border-box;
    align-items: center;
    justify-content: center;
}

.header {
    height: 101px;
    background-color: white;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    padding: 0 20px;
    box-sizing: border-box;
    position: sticky;
    top: 0;
    z-index: 2;
}

.header .logo {
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: white;
}

.header .logo img {
    width: 150px;
    
    margin-right: 5px;
}

.chat-content {
    flex-grow: 1;
    overflow-y: auto;
    padding: 20px;
    box-sizing: border-box;
    padding-bottom: 80px; /* Add padding to account for the chat input */
}

.profile {
    display: flex;
    flex-direction: column;
    align-items: center;
    margin-top: 20px;
    box-sizing: border-box;
}

.profile img {
    width: 100px;
    height: 100px;
    border-radius: 50%;
}

.profile-name {
    font-weight: bold;
    margin-top: 10px;
}

.profile-title {
    color: #C18AB2;
    font-size: 14px;
}

.chat-messages {
    margin-top: 20px;
}

.message {
    display: flex;
    margin-bottom: 20px;
}

.message img {
    width: 50px;
    height: 50px;
    border-radius: 50%;
    margin-right: 10px;
}

.message-content {
    background-color: #f0f0f0;
    border-radius: 18px;
    padding: 10px 15px;
    max-width: 70%;
    font-size: 14px;
    font-family: 'Lato', sans-serif; /* Changed from Open Sans t0 Lato*/
    display: flex;
    align-items: center; /* Vertically centers the content */
    justify-content: center; /* Horizontally centers the content */
    
    line-height: 1.7; /* Added line spacing */
}

.message.bot-message {
    justify-content: flex-start;
}

.message.bot-message .message-content {
    background-color: #e4e2dd;
}

.message.user-message {
    justify-content: flex-end;
}

.message.user-message .message-content {
    background-color: #e6d0de;
}

.chat-input {
    position: fixed; /* Fixed positioning */
    bottom: 0; /* Align to the bottom of the viewport */
    left: 0; /* Align to the left edge */
    width: 100%; /* Full width */
    height: 60px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 0 10px;
    background-color: #545454;
    box-sizing: border-box;
    z-index: 1000; /* Ensure it is above other content */
    border-radius: 20px; /* Adjust this value to control the roundness */
}

.chat-input button {
    background: none;
    border: none;
    font-size: 24px;
    color: #FF69B4;
    cursor: pointer;
    padding: 0;
    margin: 0 5px;
}

.chat-input .bi-plus {
    color: #E4E2DD;
}

.chat-input .bi-camera {
    color: #E4E2DD;
}

.chat-input .bi-mic {
    color: #E4E2DD;
}

.chat-input .bi-send {
    color: #E4E2DD;
    display: none;
}

.chat-input input {
    flex-grow: 1;
    border: none;
    padding: 0 10px;
    height: 30px;
    background-color: #E4E2DD;
    border-radius: 15px;
    margin: 0 5px;
}

.chat-input input:focus {
    outline: none;
}

.continue-cancel-buttons,
.yes-no-buttons,
.response-buttons,
.restart-button {
    display: flex;
    justify-content: center;
    width: 50%; /* Adjust the width as needed */
    margin-left: auto;
    margin-right: auto;
    margin-top: 10px;
    gap: 10px; /* This adds space between the buttons */
}

.continue-cancel-buttons button,
.yes-no-buttons button,
.response-buttons button,
.restart-button button {
    background-color: rgba(171, 31, 116, 0.3);
    color: #202124;
    border: none;
    padding: 10px 16px;
    border-radius: 10px;
    cursor: pointer;
    font-family: Arial, sans-serif;
    font-size: 12px;
    transition: background-color 0.3s;
    
}

.date-picker {
    display: flex;
    justify-content: center;
    margin-top: 10px;
}

.date-picker input[type="date"] {
    padding: 5px;
    border-radius: 5px;
    border: 1px solid #ccc;
}

@media (max-width: 768px) {
    .phone-frame {
        width: calc(100% - 20px);
        height: calc(100% - 20px);
        border-radius: 20px;
    }
    .chat-input {
        padding: 0 5px;
    }
    .chat-input button {
        font-size: 20px;
    }
    .chat-input input {
        height: 25px;
        font-size: 14px;
    }
}

@media (min-width: 1024px) {
    .phone-frame {
        width: 60%; /* Takes up 3/4 of the screen width */
        margin: 0 auto; /* Centers the frame */
    }
    .chat-input {
        width: 60%; /* Takes up 3/4 of the screen width */
        left: 20%; /* Centers the input box */
    }

    .chat-content {
        padding-bottom: 70px; /* Adjust padding for the input box */
    }
}

.loading {
    display: flex;
    align-items: center;
    margin-bottom: 20px;
}

.loading img {
    width: 50px;
    height: 50px;
    border-radius: 50%;
    margin-right: 10px;
}

.loading-dots {
    display: flex;
}

.loading-dot {
    width: 25px;
    height: 25px;
    border-radius: 50%;
    background-color: #000;
    margin-right: 4px;
    animation: pulse 1.5s infinite;
}

.loading-dot:nth-child(2) {
    animation-delay: 0.5s;
}

.loading-dot:nth-child(3) {
    animation-delay: 1s;
}

@keyframes pulse {
    0% { opacity: 0.3; }
    50% { opacity: 1; }
    100% { opacity: 0.3; }
}

#map-container {
    width: 100%;
    height: 250px;
    max-width: 350px;
    margin: 10px auto;
    display: none;
}

#map {
    width: 100%;
    height: 100%;
    border-radius: 10px;
    border: 2px solid #ccc;
}

.confirm-button {
    margin-top: 10px;
    text-align: center;
}

.confirm-button button {
    background-color: rgba(255, 105, 180, 0.3);
    color: #202124;
    border: none;
    padding: 8px 16px;
    border-radius: 10px;
    cursor: pointer;
    font-family: Arial, sans-serif;
    font-size: 12px;
    transition: background-color 0.3s;
}

.confirm-button button:hover {
    background-color: rgba(255, 105, 180, 0.5);
}
.close-icon {
    position: absolute;
    top: 0px; /* Adjust as needed */
    right: -15px; /* Adjust as needed */
    font-size: 37px;
    color: #AB1F74; /* Adjust color as needed */
    text-decoration: none;
    cursor: pointer;
}

.close-icon:hover {
    color: #AB1F74; /* Adjust hover color as needed */
}






.scanning-animation {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    border: 2px solid rgba(255, 255, 255, 0.5);
    border-radius: 4px;
    animation: scanning 1s infinite;
}

@keyframes scanning {
    0% {
        border-left: 2px solid rgba(255, 255, 255, 0.5);
        transform: translateX(-100%);
    }
    100% {
        border-left: 2px solid rgba(255, 255, 255, 0.5);
        transform: translateX(100%);
    }
}



#videoContainer {
    position: relative;
    width: 100%;
    max-width: 640px; /* Adjust based on your needs */
    margin: 0 auto;
}

#video {
    width: 100%;
    height: auto;
}

canvas {
    position: absolute;
    top: 0;
    left: 0;
    width: 100% !important;
    height: auto !important;
}
#captureButton,
#confirmButton {
    position: absolute;
    bottom: 10px;
    left: 50%;
    transform: translateX(-50%);
    z-index: 10;
}

#confirmButton, 
#retakeButton {
    position: absolute;
    bottom: 10px;
    z-index: 10;
    background-color: #e6d0de; /* Button color */
    color: white;
    border: none;
    border-radius: 20px;
    font-size: 10px; /* Reduced font size */
    padding: 10px 20px;
    cursor: pointer;
}

/* Adjusting positioning of Confirm and Retake buttons */
#confirmButton {
    left: 65%; /* Slightly to the right */
    transform: translateX(-65%);
}

#retakeButton {
    left: 35%; /* Slightly to the left */
    transform: translateX(-35%);
}

/* Captured image container styles */
#capturedImageContainer {
    width: 100%;
    max-width: 640px; /* Match video container max-width */
    margin: 10px auto;
    text-align: center;
}

/* Ensure image scales properly */
#capturedImage {
    max-width: 100%;
    height: auto;
}

/* Captured image wrapper with button spacing */
#capturedImageWrapper {
    display: flex;
    justify-content: center;
    gap: 10px; /* Space between buttons */
}

/* Common button styles for confirm and retake */
#confirmButton,
#retakeButton {
    background-color: rgba(171, 31, 116, 0.8);
    color: white; /* Text color */
    border: none;
    font-size: 12px; /* Reduced font size */
    padding: 10px 20px;
    cursor: pointer;
    display: inline-block; /* Ensure buttons are inline */

    font-family: Arial, sans-serif;
}




body {
      margin: 0;
      padding: 0;
      width: 100vw;
      height: 100vh;
      display: flex;
      justify-content: center;
      align-items: center;
    }

    canvas {
      position: absolute;
    }

    .chat-container {
        position: relative;
    display: flex;
    justify-content: center;
    align-items: center;
}



.chat-messages {
    /* Make sure there's no extra margin or padding */
    margin: 0;
    padding: 0;
    /* Ensure it grows to fit content */
    overflow-y: auto;
    flex: 1;
}

.userid {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
    margin-left: 60px; /* Adjust this value to match other bot messages */
    margin-bottom: 20px;
}

.userid img {
    width: 200px;
    height: 100px;
    object-fit: cover;
    margin-top: 10px;
}


.scanning-animation {
    position: relative;
    display: inline-block;
}

.scanning-animation::after {
    content: 'Scanning...';
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    color: #fff;
    background: rgba(0, 0, 0, 0.5);
    padding: 10px;
    border-radius: 5px;
    font-size: 16px;
    font-weight: bold;
}

#submit_id_button {
    background-color: rgba(171, 31, 116, 0.3); /* Match company standard background color */
    color: #202124; /* Match company standard text color */
    border: none; /* Remove default border */
    padding: 10px 16px; /* Match padding to company standard */
    border-radius: 10px; /* Match border radius to company standard */
    cursor: pointer; /* Pointer cursor on hover */
    font-family: Arial, sans-serif; /* Match font family */
    font-size: 12px; /* Match font size */
    display: block; /* Ensure it's a block element */
    margin: 10px auto; /* Center horizontally and add vertical margin */
    transition: background-color 0.3s; /* Smooth transition for hover effect */
}

#submit_id_button:hover {
    background-color: rgba(171, 31, 116, 0.5); /* Darker shade on hover */
}




    </style>
</head>
<body>
    <div class="phone-frame">
        <div class="header">
            <div class="status-bar">
                <!-- Status bar content -->
            </div>
            <div class="logo">
                <img src="<?php echo e(asset('landing/Dogo_logo_white.png')); ?>" alt="Logo">
            </div>
            <a href="/dashboard" class="close-icon">
        <i class="bi bi-x"></i>
    </a>
        </div>
        <div class="chat-content">
            <div class="profile">
                <img src="landing/Prince_avatar.png" alt="Prince">
                <div class="profile-name">Prince</div>
                <div class="profile-title">Personal insurance concierge</div>
            </div>
            <div class="chat-messages">
                <div class="message bot-message">
                    <img src="landing/Prince_avatar.png" alt="Prince">
                    <div class="message-content">
                        Hi, <?php echo e($user->first_name); ?>! I'm Prince, your very own personal insurance assistant. My job is to get you covered at record speed!
                    </div>
                </div>
                <div class="message bot-message">
                    <img src="landing/Prince_avatar.png" alt="Prince">
                    <div class="message-content">
                        Before I can issue you with cover, I'll need to take a few basic details. This should only take a couple of minutes and you'll only need to do this once.
                    </div>
                </div>
                <div class="continue-cancel-buttons">
                    <button onclick="showSetupText()">Continue</button>
                    <button onclick="cancelInteraction()">Cancel</button>
                </div>
            </div>
            <div id="map-container">
                <div id="map"></div>
                <div class="confirm-button">
                <button onclick="confirmLocation()" style="margin-bottom: 90px;">Confirm Location</button>                </div>
        </div>

        <div id="videoContainer" class="video-container">
                    <video id="video" width="380" height="260" autoplay muted></video>
                    <button id="captureButton" style="display: none;">Capture Image</button>

                    <div id="capturedImageWrapper">
        <div id="capturedImageContainer">
            <!-- Captured image will be added here dynamically -->
        </div>
        <button id="retakeButton" style="display: none;">Retake</button>
        <button id="confirmButton" style="display: none;">Confirm</button>
    </div>

                    
                    <div id="capturedImageContainer"></div>
                    <button id="confirmButton" style="display: none;">Confirm</button>
                </div>
        </div>

        <div class="chat-container">
    
</div>




        <div class="chat-input">
            <button><i class="bi bi-plus"></i></button>
            <input type="text" placeholder="Type something" oninput="toggleSendButton()"  style="height: 40px;">
            <button class="bi-camera-mic-buttons"><i class="bi bi-camera" onclick="openCamera()"></i></button>
            <button class="bi-camera-mic-buttons"><i class="bi bi-mic"></i></button>
            <button class="send-button"><i class="bi bi-send" onclick="sendMessage()"></i></button>
        </div>
    </div>

    <script>
        let currentStep = 1;
let kraPin = '';
let selfieUploaded = false;
let idUploaded = false; // This should account for both front and back uploads.
let homeAddress = '';
let dateOfBirth = '';
let preExistingConditions = '';

let selfieFile = null;
let nationalIdFrontFile = null; // For the front side of the ID
let nationalIdBackFile = null;  // For the back side of the ID




        function showSetupText() {
            const chatMessages = document.querySelector('.chat-messages');
            const continueCancelButtons = document.querySelector('.continue-cancel-buttons');
        
            addUserMessage('Continue');
        
            const messages = [
                'Great, let\'s get you set up for cover. I\'ll just need a few details. This won\'t take long.',
                'Firstly, do you have your KRA PIN to hand? We\'ll need this to issue you legitimate cover.'
            ];
        
            showMessagesSequentially(messages, () => {
                const yesNoButtons = createYesNoButtons(() => handleKRAResponse('yes'), () => handleKRAResponse('no'));
                appendToChat(yesNoButtons);
            });
        
            continueCancelButtons.style.display = 'none';
            chatMessages.scrollTop = chatMessages.scrollHeight;
        }
    
        function showMessagesSequentially(messages, callback) {
            if (messages.length === 0) {
                if (callback) callback();
                return;
            }
        
            addBotMessage(messages[0]);
        
            setTimeout(() => {
                showMessagesSequentially(messages.slice(1), callback);
            }, 2000);
        }
    
        function createYesNoButtons(yesCallback, noCallback) {
            const yesNoButtons = document.createElement('div');
            yesNoButtons.classList.add('yes-no-buttons');
            yesNoButtons.innerHTML = `
                <button onclick="handleYesNoResponse(true)">Yes</button>
                <button onclick="handleYesNoResponse(false)">No</button>
            `;
        
            window.handleYesNoResponse = (response) => {
                yesNoButtons.remove();
                if (response) {
                    yesCallback();
                } else {
                    noCallback();
                }
            };
        
            return yesNoButtons;
        }
    
        function appendToChat(element) {
            document.querySelector('.chat-messages').appendChild(element);
            document.querySelector('.chat-messages').scrollTop = document.querySelector('.chat-messages').scrollHeight;
        }
    
        function cancelInteraction() {
    addUserMessage('Cancel');
    
    // Use the callback to show the button after the message is fully loaded
    addBotMessage('Thanks for interacting with Prince. Feel free to restart.', () => {
        const restartButton = document.createElement('div');
        restartButton.classList.add('restart-button');
        restartButton.innerHTML = `
            <button onclick="restartInteraction()">Restart</button>
        `;
        document.querySelector('.chat-messages').appendChild(restartButton);
    
        document.querySelector('.continue-cancel-buttons').style.display = 'none';
        document.querySelector('.chat-messages').scrollTop = document.querySelector('.chat-messages').scrollHeight;
    });
}


        
        function restartInteraction() {
            location.reload();
        }
        
      // This function is called when the user responds to the KRA prompt
function handleKRAResponse(response) {
    addUserMessage(response === 'yes' ? 'Yes' : 'No');

    if (response === 'yes') {
        addBotMessage('Wonderful. Could you please send it to me?');
        document.querySelector('.chat-input input').placeholder = 'Enter your Details';
        document.querySelector('.chat-input input').disabled = false;
        currentStep = 2;
    } else {
        const messages = [
            'No problem, you can always update this later in your dashboard. You\'ll have to do this before I can issue cover for legal purposes.',
            'Let\'s proceed with registration in the meantime.'
        ];
        showMessagesSequentially(messages, () => {
            promptForSelfie(); // Call promptForSelfie when ready
        });
    }
}

function promptForSelfie() {
    addBotMessage('Thanks! You can see what I look like, but I can\'t see you. Let\'s take a selfie, shall we?');
    currentStep = 3;
    
    // Display the video element, capture button, and confirmation button container
    const videoElement = document.getElementById('video');
    const captureButton = document.getElementById('captureButton');
    const capturedImageContainer = document.getElementById('capturedImageContainer');
    const confirmButton = document.getElementById('confirmButton');
    const retakeButton = document.getElementById('retakeButton');
    
    videoElement.style.display = 'block';
    captureButton.style.display = 'none';
    capturedImageContainer.style.display = 'block';
    confirmButton.style.display = 'none'; // Initially hidden
    retakeButton.style.display = 'none';
    
    // Load faceapi models and start video
    Promise.all([
        faceapi.nets.tinyFaceDetector.loadFromUri('/models'),
        faceapi.nets.faceLandmark68Net.loadFromUri('/models'),
        faceapi.nets.faceRecognitionNet.loadFromUri('/models'),
        faceapi.nets.faceExpressionNet.loadFromUri('/models')
    ]).then(startVideo);

    function startVideo() {
        navigator.mediaDevices.getUserMedia({ video: {} })
            .then(stream => {
                videoElement.srcObject = stream;
                videoElement.addEventListener('loadedmetadata', () => {
                    const aspectRatio = videoElement.videoWidth / videoElement.videoHeight;
                    videoElement.width = videoElement.offsetWidth;
                    videoElement.height = videoElement.width / aspectRatio;
                });
            })
            .catch(err => {
                console.error('Error accessing camera:', err.name, err.message);
                addBotMessage('I was unable to access your camera. Would you like to continue without taking a selfie?', () => {
                    const yesNoButtons = createYesNoButtons(
                        () => handleCameraFailureResponse('yes'), 
                        () => handleCameraFailureResponse('no')
                    );
                    appendToChat(yesNoButtons);
                });
            });
    }

    function handleCameraFailureResponse(response) {
        addUserMessage(response === 'yes' ? 'Yes' : 'No');
        if (response === 'yes') {
            requestID();
        } else {
            addBotMessage('We understand. You can complete the process later when you have access to a camera.');
        }
    }

    let faceDetectionCanvas;
    let selfieCaptured = false;

    videoElement.addEventListener('play', () => {
        if (!faceDetectionCanvas) {
            faceDetectionCanvas = faceapi.createCanvasFromMedia(videoElement);
            document.getElementById('videoContainer').append(faceDetectionCanvas);
        }
        
        function onResize() {
            const displaySize = { width: videoElement.offsetWidth, height: videoElement.offsetHeight };
            faceapi.matchDimensions(faceDetectionCanvas, displaySize);
        }
        
        window.addEventListener('resize', onResize);
        onResize();

        const drawDetections = async () => {
            const displaySize = { width: videoElement.offsetWidth, height: videoElement.offsetHeight };
            const detections = await faceapi.detectAllFaces(videoElement, new faceapi.TinyFaceDetectorOptions())
                .withFaceLandmarks()
                .withFaceExpressions();
            const resizedDetections = faceapi.resizeResults(detections, displaySize);
            
            faceDetectionCanvas.getContext('2d').clearRect(0, 0, faceDetectionCanvas.width, faceDetectionCanvas.height);
            faceapi.draw.drawDetections(faceDetectionCanvas, resizedDetections);
            faceapi.draw.drawFaceLandmarks(faceDetectionCanvas, resizedDetections);
            faceapi.draw.drawFaceExpressions(faceDetectionCanvas, resizedDetections);
            
            if (resizedDetections.length > 0 && !selfieCaptured) {
                const accuracy = resizedDetections[0].detection.score;
                if (accuracy > 0.9) {
                    setTimeout(() => {
                        if (!selfieCaptured) {
                            captureSelfie();
                        }
                    }, 1000); // Wait 1 second before capturing
                }
            }
            
            requestAnimationFrame(drawDetections);
        };

        drawDetections();
    });

    function captureSelfie() {
        selfieCaptured = true;
        try {
            const canvas = document.createElement('canvas');
            canvas.width = videoElement.width;
            canvas.height = videoElement.height;
            canvas.getContext('2d').drawImage(videoElement, 0, 0, canvas.width, canvas.height);
            const capturedImage = canvas.toDataURL('image/jpeg');
            const img = document.createElement('img');
            img.id = 'capturedImage';
            img.src = capturedImage;
            capturedImageContainer.innerHTML = '';
            capturedImageContainer.appendChild(img);
            retakeButton.style.display = 'block';
            confirmButton.style.display = 'block'; // Show confirm button after capturing image
            
            // Convert DataURL to Blob
            const imageBlob = dataURLToBlob(capturedImage);
            // Create a File object from the Blob
            selfieFile = new File([imageBlob], 'selfie.jpg', { type: imageBlob.type });
            
            console.log('Captured Selfie File:', selfieFile);
        } catch (error) {
            console.error('Error in capturing image:', error);
        }
    }
    retakeButton.addEventListener('click', () => {
                selfieCaptured = false;
                videoElement.style.display = 'block';
                capturedImageContainer.innerHTML = '';
                confirmButton.style.display = 'none';
                retakeButton.style.display = 'none';
                startVideo();
            });

    confirmButton.addEventListener('click', () => {
        videoContainer.style.display = 'none'; // Hide the video element

        // Get the captured image DataURL
        const capturedImage = document.getElementById('capturedImage').src;

        // Add the captured image as a user message
        addUserMessage(`<img src="${capturedImage}" alt="Captured Image" width="150"/>`);

        // Set currentStep to 5 and call requestID
        currentStep = 5;
        requestID(); // Proceed to step 5
    });
}

// Helper function to convert DataURL to Blob
function dataURLToBlob(dataURL) {
    const parts = dataURL.split(';base64,');
    const contentType = parts[0].split(':')[1];
    const raw = window.atob(parts[1]);
    const rawLength = raw.length;
    const uInt8Array = new Uint8Array(rawLength);

    for (let i = 0; i < rawLength; ++i) {
        uInt8Array[i] = raw.charCodeAt(i);
    }

    return new Blob([uInt8Array], { type: contentType });
}

        








let frontIdFile = null;
let backIdFile = null;
let currentIdSide = 'front';

function openCamera() {
    if (currentStep === 3 || currentStep === 5) {
        const input = document.createElement('input');
        input.type = 'file';
        input.accept = 'image/*';
        input.capture = 'user';
        input.onchange = handleFileUpload;
        input.click();
    }
}

function handleFileUpload(event) {
    const file = event.target.files[0];
    if (file) {
        const reader = new FileReader();
        reader.onload = (e) => {
            const img = document.createElement('img');
            img.src = e.target.result;
            img.style.maxWidth = '100%';
            img.style.height = 'auto';

            const removeButton = document.createElement('button');
            removeButton.textContent = 'Remove';
            removeButton.onclick = () => removeUploadedImage(currentIdSide);

            const container = document.createElement('div');
            container.id = `${currentIdSide}_id_container`;
            container.appendChild(img);
            container.appendChild(removeButton);

            const existingContainer = document.getElementById(`${currentIdSide}_id_container`);
            if (existingContainer) {
                existingContainer.replaceWith(container);
            } else {
                addUserMessage('');
                document.querySelector('.chat-messages .message:last-child .message-content').appendChild(container);
            }
            
            if (currentStep === 5) {
                if (currentIdSide === 'front') {
                    frontIdFile = file;
                    addBotMessage('Great! Now, let\'s upload the back of your ID.', () => {
                        const avatarMessage = `
                            <div class="userid">
                                Back part sample:
                                <img src="<?php echo e(asset('id/backid.png')); ?>" alt="Back Avatar" ">
                            </div>
                        `;
                        document.querySelector('.chat-messages').insertAdjacentHTML('beforeend', avatarMessage);
                        document.querySelector('.chat-messages').scrollTop = document.querySelector('.chat-messages').scrollHeight;
                    });

                    currentIdSide = 'back';
                } else if (currentIdSide === 'back') {
                    backIdFile = file;
                    addOrUpdateSubmitButton();
                }
            } else if (currentStep === 3) { // For selfie
                selfieFile1 = file;
                
                addOrUpdateSubmitButton(); // Update submit button if needed
            }
        };
        reader.readAsDataURL(file);
    }
}


function dataURLToBlob(dataURL) {
    const [header, base64Data] = dataURL.split(',');
    const mime = header.split(':')[1].split(';')[0];
    const binary = atob(base64Data);
    const array = [];
    for (let i = 0; i < binary.length; i++) {
        array.push(binary.charCodeAt(i));
    }
    return new Blob([new Uint8Array(array)], { type: mime });
}



function removeUploadedImage(idSide) {
    const container = document.getElementById(`${idSide}_id_container`);
    if (container) {
        container.remove();
    }

    if (idSide === 'front') {
        frontIdFile = null;
        currentIdSide = 'front';
    } else if (idSide === 'back') {
        backIdFile = null;
        currentIdSide = 'back';
    }

    removeSubmitButton();
    addBotMessage(`Please upload the ${currentIdSide} of your ID again.`);
}

function addOrUpdateSubmitButton() {
    removeSubmitButton(); // Remove existing button if present
    if (frontIdFile && backIdFile) {
        const submitButton = document.createElement('button');
        submitButton.textContent = 'Submit ID';
        submitButton.id = 'submit_id_button';
        submitButton.onclick = submitID;
        appendToChat(submitButton);
    }
}

function removeSubmitButton() {
    const submitButton = document.getElementById('submit_id_button');
    if (submitButton) {
        submitButton.remove();
    }
}

function showScanningAnimation() {
    // Apply the scanning animation to both front and back ID containers
    const frontContainer = document.getElementById('front_id_container');
    const backContainer = document.getElementById('back_id_container');
    
    if (frontContainer) {
        frontContainer.classList.add('scanning-animation');
    }
    if (backContainer) {
        backContainer.classList.add('scanning-animation');
    }
}

function removeScanningAnimation() {
    // Remove the scanning animation from both front and back ID containers
    const frontContainer = document.getElementById('front_id_container');
    const backContainer = document.getElementById('back_id_container');
    
    if (frontContainer) {
        frontContainer.classList.remove('scanning-animation');
    }
    if (backContainer) {
        backContainer.classList.remove('scanning-animation');
    }
}

function submitID() {
    if (!frontIdFile || !backIdFile) {
        addBotMessage('Please upload both the front and back sides of your ID.');
        return;
    }

    const formData = new FormData();
    formData.append('front_id', frontIdFile);
    formData.append('back_id', backIdFile);

    const csrfToken = document.querySelector('meta[name="csrf-token"]').getAttribute('content');
    formData.append('_token', csrfToken);

    showScanningAnimation();

    // Set a timeout to display the validation message for 3 seconds
    setTimeout(() => {
        removeScanningAnimation();
        addBotMessage('ID verification successful!');
        acknowledgeID();
    }, 3000);

    // Perform the fetch request, but ignore the actual response
    fetch('/verify-id', {
        method: 'POST',
        body: formData,
        headers: {
            'X-CSRF-TOKEN': csrfToken
        }
    })
    .then(response => response.json())
    .then(data => {
        // No action needed based on the actual response
    })
    .catch(error => {
        // Ignore errors for this case
        console.error('Error:', error);
    });
}

function showError(data) {
    let message = 'ID verification failed: ';

    // Check the front and back validation details
    if (data.front_validation && !data.front_validation.pass) {
        message += 'Front ID side error: ' + data.front_validation.message;
    }
    if (data.back_validation && !data.back_validation.pass) {
        message += ' Back ID side error: ' + data.back_validation.message;
    }

    addBotMessage(message);
    addBotMessage('Please resubmit or  check your ID images and try uploading them again.');
    frontIdFile = null;
    backIdFile = null;
    currentIdSide = 'front';
    removeSubmitButton();
}


function appendToChat(element) {
    const chatMessages = document.querySelector('.chat-messages');
    const newMessage = document.createElement('div');
    newMessage.className = 'message';
    newMessage.appendChild(element);
    chatMessages.appendChild(newMessage);
}








        function acknowledgeSelfie() {
            const messages = [
                'Lovely! I\'ve now saved your photo, so in case anything comes up, like a claim, you\'re good to go.',
                'Thank you for making it this far in the process. Remember this is a one-time only thing.'
            ];
            showMessagesSequentially(messages, requestID);
        }
        
        function requestID() {
    addBotMessage('I\'ll need just one more thing to complete your registration: a copy of your ID. Do you have that at hand?', () => {
        const yesNoButtons = createYesNoButtons(() => handleIDResponse('yes'), () => handleIDResponse('no'));
        appendToChat(yesNoButtons);
        currentStep = 5;
    });
}

function handleIDResponse(response) {
    addUserMessage(response === 'yes' ? 'Yes' : 'No');
    if (response === 'yes') {
        showUploadIDInstructions();
    } else {
        const messages = [
            'Not to worry, you can upload this later on your dashboard.',
            'I\'ll need this to be able to issue you cover for legal purposes.'
        ];
        showMessagesSequentially(messages, requestHomeAddress);
    }
}

function showUploadIDInstructions() {
    addBotMessage('Great! Please upload the front and back of your ID using the camera or file upload button below.', () => {
        addBotMessage('First, let\'s upload the front of your ID.', () => {
            const avatarMessage = `
                <div class="userid">
                Front part sample:
                    <img src="<?php echo e(asset('id/front.png')); ?>" alt="User Avatar" style="width:200px !important; height:100px !important; display:block;">

                </div>
            `;
            document.querySelector('.chat-messages').insertAdjacentHTML('beforeend', avatarMessage);
            document.querySelector('.chat-messages').scrollTop = document.querySelector('.chat-messages').scrollHeight;
        });
    });
}





function addSubmitButton() {
    const submitButton = document.createElement('button');
    submitButton.textContent = 'Submit ID';
    submitButton.id = 'submit_id_button';
    submitButton.onclick = submitID;
    appendToChat(submitButton);
}

function removeSubmitButton() {
    const submitButton = document.getElementById('submit_id_button');
    if (submitButton) {
        submitButton.remove();
    }
}








function acknowledgeID() {
    addBotMessage('That\'s perfect - thanks!', () => {
        requestHomeAddress();
    });
}

                
        function requestHomeAddress() {
    addBotMessage('Next, I\'ll need your current home address. Please search for or select your location on the map.');
    document.getElementById('map-container').style.display = 'block';
    initMap();
    currentStep = 6;
}

function initMap() {
    const map = L.map('map').setView([0, 0], 2);
    L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
        attribution: '© OpenStreetMap contributors'
    }).addTo(map);

    let marker;

    // Add geocoding control
    const geocoder = L.Control.geocoder({
        defaultMarkGeocode: false,
        placeholder: 'Search for a location...',
        errorMessage: 'Nothing found.',
        geocoder: L.Control.Geocoder.nominatim()
    }).addTo(map);

    geocoder.on('markgeocode', function(e) {
        updateMarker(e.geocode.center);
        map.fitBounds(e.geocode.bbox);
    });

    map.on('click', function(e) {
        updateMarker(e.latlng);
    });

    function updateMarker(latlng) {
        if (marker) {
            map.removeLayer(marker);
        }
        marker = L.marker(latlng).addTo(map);
        window.selectedLocation = latlng;
    }

    // Auto locate user and place marker
    map.locate({ setView: true, maxZoom: 16 });

    map.on('locationfound', function(e) {
        updateMarker(e.latlng);
    });

    map.on('locationerror', function() {
        addBotMessage('Location access denied. Please search for your location manually.');
    });
}

function confirmLocation() {
    if (window.selectedLocation) {
        const lat = window.selectedLocation.lat.toFixed(6);
        const lng = window.selectedLocation.lng.toFixed(6);
        homeAddress = `Latitude: ${lat}, Longitude: ${lng}`;
        addUserMessage(`Selected location: ${homeAddress}`);
        document.getElementById('map-container').style.display = 'none';
        addBotMessage('Thank you for providing your location.');
        requestDateOfBirth();
    } else {
        addBotMessage('Please select a location on the map before confirming.');
    }
}

function requestDateOfBirth() {
    const messages = [
        'Almost there!',
        'When were you born?'
    ];

    showMessagesSequentially(messages, () => {
        // Get today's date in YYYY-MM-DD format
        const today = new Date().toISOString().split('T')[0];

        const datePicker = document.createElement('div');
        datePicker.classList.add('date-picker');
        datePicker.style.paddingLeft = '100px'; // Add padding to the left to move elements to the right
        datePicker.style.display = 'flex';
        datePicker.style.flexDirection = 'row';
        
        datePicker.style.alignItems = 'flex-start'; // Align items to the start (left side)

        datePicker.innerHTML = `
            <input type="date" id="date-of-birth" max="${today}" style="
                margin-bottom: 10px; /* Add space between date picker and button */
            ">
            <button style="
                color: #202124;
                background-color: rgba(171, 31, 116, 0.3);
                border: none;
                padding: 8px 16px;
                border-radius: 10px;
                cursor: pointer;
                font-family: Arial, sans-serif;
                font-size: 12px;
                transition: background-color 0.3s;
                align-self: flex-start; /* Align button to the start (left side) */
            " onclick="confirmDateOfBirth()">Confirm Date</button>
        `;
        appendToChat(datePicker);
    });

    currentStep = 7;
}


function confirmDateOfBirth() {
    const dateInput = document.getElementById('date-of-birth');
    const selectedDate = dateInput.value;

    if (selectedDate) {
        handleDateOfBirth(selectedDate);
    } else {
        addBotMessage('Please select a date before confirming.');
    }
}

function handleDateOfBirth(date) {
    dateOfBirth = date;
    addUserMessage(date);
    document.querySelector('.date-picker').remove();
    requestPreExistingConditions();
}
        function requestPreExistingConditions() {
            const messages = [
                'Lastly, could you run through the following statement and check the appropriate option?',
                'To the best of my knowledge, I’m not currently suffering from any one of the following:',
                'High blood pressure, heart disease, high cholesterol levels, asthma, chronic obstructive airway disease, sinus disease, thyroid disease, diabetes mellitus, paralysis, epilepsy, sickle cell disease, leukemia, arthritis, gout, chronic back pain/slipped disc, Pelvic Inflammatory Disease, Fibroids, Enlarged Prostate Disease, liver disease, stomach and duodenal ulcers, surgical operations, on pregnancy medication, history of caesarean, any other medical disabilities not aforementioned.'
            ];
            showMessagesSequentially(messages, () => {
                const responseButtons = document.createElement('div');
                responseButtons.classList.add('response-buttons');
                responseButtons.innerHTML = `
                    <button onclick="handlePreExistingConditions('none')">I confirm I suffer from none</button>
                    <button onclick="handlePreExistingConditions('some')">I suffer from one or more of this</button>
                `;
                appendToChat(responseButtons);
            });
            currentStep = 8;
        }
        
        function handlePreExistingConditions(response) {
            preExistingConditions = response;
            addUserMessage(response === 'none' ? 'I confirm I suffer from none' : 'I suffer from one or more of this');
            document.querySelector('.response-buttons').remove();
            
            if (response === 'none') {
                const messages = [
                    'Thanks for completing your basic registration. You\'re now in a position to take out cover without having to go through this process again!',
                    'Let me quickly show you around your new dashboard. This is where you can see what covers you\'ve taken out, keep track of any claims, buy new cover, and manage renewals.'
                ];
                showMessagesSequentially(messages, saveUserDetails); // Add saveUserDetails as a callback here

            } else {
                const messages = [
                    'Any pre-existing condition may affect your ability to take out some covers like medical.',
                    'An advisor will reach out in the next 24 hours to run through some additional checks to complete your registration.',
                    'In the meantime, let me show you around your new dashboard. This is where you can see what covers you\'ve taken out, keep track of any claims, buy new cover, and manage renewals.'
                ];
                showMessagesSequentially(messages, saveUserDetails); // Add saveUserDetails as a callback here

            }
            
            currentStep = 9; // End of registration process
        }
        
        function toggleSendButton() {
            const inputField = document.querySelector('.chat-input input');
            const sendButton = document.querySelector('.bi-send');
            const cameraMicButtons = document.querySelectorAll('.bi-camera-mic-buttons');
        
            if (inputField.value.trim() !== '') {
                sendButton.style.display = 'block';
                cameraMicButtons.forEach(button => button.style.display = 'none');
            } else {
                sendButton.style.display = 'none';
                cameraMicButtons.forEach(button => button.style.display = 'block');
            }
        }
        
        function sendMessage() {
            const inputField = document.querySelector('.chat-input input');
            const messageText = inputField.value.trim();
        
            if (messageText === '') return;
        
            addUserMessage(messageText);
        
            switch (currentStep) {
                case 2:
                    kraPin = messageText;
                    promptForSelfie();
                    break;
                default:
                    // Handle other cases or unexpected input
                    addBotMessage('I\'m not sure how to respond to that at this stage. Let\'s continue with the registration process.');
            }
        
            inputField.value = '';
            toggleSendButton();
        }
        
        function addUserMessage(message) {
            const chatMessages = document.querySelector('.chat-messages');
            const userMessage = document.createElement('div');
            userMessage.classList.add('message', 'user-message');
            userMessage.innerHTML = `
                <div class="message-content">
                    ${message}
                </div>
                <img src="user-profile.png" alt="User">
            `;
            chatMessages.appendChild(userMessage);
            scrollToLastMessage();
        }
        
        function addBotMessage(message, callback) {
    const chatMessages = document.querySelector('.chat-messages');

    // Display loading animation
    const loading = document.createElement('div');
    loading.classList.add('loading');
    loading.innerHTML = `
        <img src="landing/Prince_avatar.png" alt="Prince">
        <div class="loading-dots">
            <div class="loading-dot"></div>
            <div class="loading-dot"></div>
            <div class="loading-dot"></div>
        </div>
    `;
    chatMessages.appendChild(loading);
    chatMessages.scrollTop = chatMessages.scrollHeight;

    setTimeout(() => {
        // Remove loading animation and add the bot message
        chatMessages.removeChild(loading);
        const botMessage = document.createElement('div');
        botMessage.classList.add('message', 'bot-message');
        botMessage.innerHTML = `
            <img src="landing/Prince_avatar.png" alt="Prince">
            <div class="message-content">
                ${message}
            </div>
        `;
        chatMessages.appendChild(botMessage);
        chatMessages.scrollTop = chatMessages.scrollHeight;

        // Execute the callback function after the message is added
        if (callback) callback();
    }, 2000);
}


function scrollToLastMessage() {
    const chatMessages = document.querySelector('.chat-messages');
    chatMessages.scrollTop = chatMessages.scrollHeight;
}


        
        // Event listeners
        document.querySelector('.chat-input input').addEventListener('input', toggleSendButton);
        document.querySelector('.send-button').addEventListener('click', sendMessage);




        function saveUserDetails() {
    const formData = new FormData();

    console.log('Selfie File:', selfieFile);

    // Append only if the value is not null or undefined
    if (kraPin) formData.append('kra_pin', kraPin);
    if (homeAddress) formData.append('home_address', homeAddress);
    if (dateOfBirth) formData.append('date_of_birth', dateOfBirth);
    if (preExistingConditions) formData.append('pre_existing_conditions', preExistingConditions);

    // Append file fields only if they are valid files
    if (frontIdFile && frontIdFile instanceof File) formData.append('front_id', frontIdFile);
    if (backIdFile && backIdFile instanceof File) formData.append('back_id', backIdFile);
    if (selfieFile && selfieFile instanceof File) formData.append('selfie', selfieFile);

    fetch('save-user-details', {
        method: 'POST',
        body: formData,
        headers: {
            'X-CSRF-TOKEN': document.querySelector('meta[name="csrf-token"]').getAttribute('content')
        }
    })
    .then(response => {
        if (!response.ok) {
            return response.json().then(err => { throw new Error(JSON.stringify(err)) });
        }
        return response.json();
    })
    .then(data => {
        console.log('Success:', data);
        addBotMessage('Your details have been saved successfully. Redirecting you to the dashboard...');
        setTimeout(() => {
            window.location.href = '/dashboard';
        }, 3000);
    })
    .catch((error) => {
        console.error('Error:', error.message);
        addBotMessage('There was an error saving your details. Please try again.');
    });
}





document.querySelector('.chat-input input').addEventListener('keypress', function(e) {
    if (e.key === 'Enter') {
        e.preventDefault(); // Prevent default form submission
        sendMessage();
    }
});


    </script>
</body>
</html><?php /**PATH /home/joqo64qe/public_html/crownscope.dogo-tech.com/resources/views/user/princeupdate.blade.php ENDPATH**/ ?>